!+
! Module: adapt_2000_mod
!
! Authors:  Steven L. Snowden - Goddard Space Flight Center (NASA)
!
! Description: Extended Source Analysis Software
!
! Comments:
!
! $Id: adapt_2000_mod.f90,v 1.4 2009/04/23 13:31:09 aibarra Exp $
!-
module adapt_2000_mod

  use dal
  use param
  use errorHandling

  implicit none

  private

  public adapt_2000

contains

  !---------------------------------------------------------------------
  subroutine adapt_2000
  !---------------------------------------------------------------------

    real :: SN, TEMSC
    integer, dimension(:), allocatable :: IEL, IEH
    integer :: i, nb, IBIN, IFILL
    logical :: IPART, ISOFT, ISWCX, IMASK
    character(len=132) :: INFILE

    SN = realParameter("smoothingcounts")
    TEMSC = realParameter("thresholdmasking")
    nb = intParameter("nbands")

    allocate(IEL(nb),IEH(nb))
    do i=1, parameterCount("elowlist")
      IEL(i) = intParameter("elowlist",i-1)
      IEH(i) = intParameter("ehighlist",i-1)
    end do

    IBIN = intParameter("binning")
    IPART = booleanParameter("withpartcontrol")
    ISOFT = booleanParameter("withsoftcontrol")
    ISWCX = booleanParameter("withswcxcontrol")
    IMASK = booleanParameter("withmaskcontrol")

    INFILE = stringParameter("maskfile")
    IFILL = intParameter("fill")

    call adapt_2000_sub(SN,TEMSC,nb,IEL,IEH,IBIN,IPART,ISOFT,ISWCX,IMASK,INFILE,IFILL)

    deallocate(IEL,IEH)
  end subroutine adapt_2000

end module adapt_2000_mod
