        subroutine comb_sub(xmmdir,ipart,iprot,iswcx,nbands,iel,ieh,
     +       imask,ndata,prefix,alpha)
c
c  SAS Version 0.9.8
c  Version 4.1  22 June 2010
c
c  Combines images from multiple exposures from a single observation
c
c  comb is part of the XMM-ESAS package and combines images from
c  different exposures and MOS instruments from the same observation
c  in preparation for adapt and other analysis.  Count, exposure,
c  background, soft proton, and charge exchange images are combined, 
c  although if the background, soft proton, charge exchange images 
c  are missing they are ignored.
c  Masking can be done at the same time using the cheese images.
c
c  Input:
c
c    CalDB directory
c    Particle background control
c    Soft proton background control
c    Number of bands to merge
c    Repeat for the number of bands
c        Lower energy limit for the energy band in eV
c        Upper energy limit for the energy band in eV
c    Masking control:
c        0 => no masking
c        1 =>  Point Source Masking - Use either output from cheese or 
c              the combined band output from cheese-bands
c        11 => Point Source Masking - Use the soft band output from 
c              cheese-bands
c        12 => Point Source Masking - Use the hard band output from 
c              cheese-bands
c        2 => masking using the normal mask images produced by
c              eexpmap
C        3 =>  Point Source Masking - Use the full band output from 
C              make-mask-merge
C        31 => Point Source Masking - Use the soft band output from 
C              make-mask-merge
C        32 => Point Source Masking - Use the hard band output from 
C              make-mask-merge
c    Number of data exposures (i.e., number of prefixes)
c    List of prefixes (e.g., 1S001, 2U002)
c
c    Example: comb 1 1 1 350 1250 0 2 1S001 2S002
c             comb 1 0 2 350 800 800 1250 1 3 1S001 2S002 S003
c
c  Output:
c    Merged count and exposure images with merged backgorund
c    and soft proton images if they exist.
c
        implicit none
c
        integer*2 i2array(900,900)
        integer bitpix, block, clobber, ebmax, ebmin, ehigh, elow, 
     +      err, gcount, group, i4array(900,900), 
     +      i, ib, idet, ieh(20), iel(20), ihigh, ii, ilow, 
     +      imask, ipart, iprot, islow, ishigh, iswcx, 
     +      lun, luna, lunb, n, naxes(3), naxis, 
     +      nbands, ndata, nn, noff, pcount, status
c
        real alpha, fscal, image(900,900), mask(900,900,10), ootsca, 
     +      outim(900,900), totcou, totback, totexp, 
     +      totprot, totswcx, ttot
c
        DOUBLE PRECISION cdelt(2), crpix(2), crval(2)
c
        character*1 pr(4), pre(5)
        character*4 filt, pref
        character*5 prefi, prefix(10)
        character*8 ctype(2), filter
        character*20 chname
        character*25 mode
        character*80 com, xmmdir
        character*132 im_name, im_nameo, imo_name
c
        logical doit
c
        equivalence (filter,filt)
        equivalence (pref,pr)
        equivalence (prefi,pre)
c
        data clobber /1/
        data doit /.TRUE./
        data err /0/
        data status /0/
        data totcou, totback, totexp, totprot, totswcx 
     +          /0.0, 0.0, 0.0, 0.0, 0.0/
c
        ebmin = 100000
        ebmax = 0
        do ib=1,nbands
            noff = (ib - 1)*2
            nn = 4 + noff + 1
            nn = 4 + noff + 2
            print *, 'Band: ', ib,'  Energy Limits: ',
     +                  iel(ib), ieh(ib)
            if(iel(ib) .lt. ebmin) ebmin = iel(ib)
            if(ieh(ib) .gt. ebmax) ebmax = ieh(ib)
        enddo
        ilow = ebmin
        ihigh = ebmax
        ib = 0
c
c  Set the band
c
        islow = (ilow + 25)/50
        ishigh = (ihigh + 25)/50
c
        nn = nn + 1
        nn = nn + 1
        print *, 'Particle background control: ', ipart
        print *, 'Soft proton background control: ', iprot
        print *, 'Masking control: ', imask
        print *, 'Exposure sets: ', ndata
        print *, 'Scaling spectral index: ', alpha
        do i=1,ndata
            print *, 'prefix: ', prefix(i)
        enddo
c
c  If masking is desired, read in the masks
c
        if((imask .eq. 1) .or. (imask .eq. 11) .or.  
     +          (imask .eq. 12)) then
            if(imask .eq. 1) then
                chname = '-cheese.fits'
            elseif(imask .eq. 11) then
                chname = '-cheese-s.fits'
            elseif(imask .eq. 12) then
                chname = '-cheese-h.fits'
            endif
            do n=1,ndata
                prefi = prefix(n)
                if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                    write(im_name,2999) prefix(n), chname
 2999               format('mos',a5,a20)
                    if(pre(1) .eq. '1') idet = 1
                    if(pre(1) .eq. '2') idet = 2
                else
                    idet = 3
                    do i=1,4
                        pr(i) = pre(i)
                    enddo
                    write(im_name,3000) pref, chname
 3000               format('pn',a4,a20)
                endif
                print *, prefi, '  ', pre(1), idet
                print *, im_name
                call retfit(im_name,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS RETFIT =', status
                    print *, 'COMB POSITION 01'
                    print *, 'Missing a cheese mask'
                    print *, im_name
                   stop
                endif
                do i=1,900
                    do ii=1,900
                        mask(i,ii,n) = image(i,ii)
                    enddo
                enddo
            enddo
        elseif(imask .eq. 2) then
            do n=1,ndata
                prefi = prefix(n)
                if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                    if(iel(1) .ge. 1000) then
                        if(ieh(1) .ge. 10000) then
                            write(im_name,3001) prefix(n),
     +                              iel(1), ieh(1)
 3001                       format('mos',a5,'-mask-im-',i4,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3002) prefix(n),
     +                              iel(1), ieh(1)
 3002                       format('mos',a5,'-mask-im-',i4,'-',
     +                              i4,'.fits')
                        endif
                    elseif(ieh(1) .lt. 1000) then
                        write(im_name,3003) prefix(n), iel(1), ieh(1)
 3003                   format('mos',a5,'-mask-im-',i3,'-',i3,'.fits')
                    elseif(ieh(1) .ge. 10000) then
                        write(im_name,3004) prefix(n), iel(1), ieh(1)
 3004                   format('mos',a5,'-mask-im-',i3,'-',i5,'.fits')
                    else
                        write(im_name,3005) prefix(n), iel(1), ieh(1)
 3005                   format('mos',a5,'-mask-im-',i3,'-',i4,'.fits')
                    endif
                    print *, im_name
                else
                    do i=1,4
                        pr(i) = pre(i)
                    enddo
                    if(iel(1) .ge. 1000) then
                        if(ieh(1) .ge. 10000) then
                            write(im_name,3006) pref, iel(1), ieh(1)
 3006                       format('pn',a4,'-mask-im-',i4,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3007) pref, iel(1), ieh(1)
 3007                       format('pn',a4,'-mask-im-',i4,'-',
     +                              i4,'.fits')
                        endif
                    elseif(ieh(1) .lt. 1000) then
                        write(im_name,3008) pref, iel(1), ieh(1)
 3008                   format('pn',a4,'-mask-im-',i3,'-',i3,'.fits')
                    elseif(ieh(1) .ge. 10000) then
                        write(im_name,3009) pref, iel(1), ieh(1)
 3009                   format('pn',a4,'-mask-im-',i3,'-',i5,'.fits')
                    else
                        write(im_name,3010) pref, iel(1), ieh(1)
 3010                   format('pn',a4,'-mask-im-',i3,'-',i4,'.fits')
                    endif
                endif
                print *, im_name

                call retfit(im_name,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS RETFIT =', status
                    print *, 'COMB POSITION 02'
                    print *, 'Missing a normal mask'
                    print *, im_name
                   stop
                endif
                do i=1,900
                    do ii=1,900
                        mask(i,ii,n) = image(i,ii)
                    enddo
                enddo
            enddo
        elseif((imask .eq. 3) .or. (imask .eq. 31) 
     +          .or. (imask .eq. 32)) then
            if(imask .eq. 3) then
                chname = '-msl-cheese.fits'
            elseif(imask .eq. 31) then
                chname = '-msl-cheese-s.fits'
            elseif(imask .eq. 32) then
                chname = '-msl-cheese-h.fits'
            endif
            do n=1,ndata
                prefi = prefix(n)
                if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                    write(im_name,3011) prefix(n), chname
 3011               format('mos',a5,a20)
                else
                    do i=1,4
                        pr(i) = pre(i)
                    enddo
                    write(im_name,3016) pref, chname
 3016               format('pn',a4,a20)
                endif
                print *, im_name
                call retfit(im_name,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS RETFIT =', status
                    print *, 'COMB POSITION 03'
                    print *, 'Missing a make-mask modified mask'
                    print *, im_name
                   stop
                endif
                do i=1,900
                    do ii=1,900
                        mask(i,ii,n) = image(i,ii)
                    enddo
                enddo
            enddo
        elseif(imask .eq. 0) then
c
c  Make full-field masks
c
            do n=1,ndata
                do i=1,900
                    do ii=1,900
                        mask(i,ii,n) = 1.0
                    enddo
                enddo
            enddo
        endif
c
c  Zero the output images
c
        do i=1,900
            do ii=1,900
                outim(i,ii) = 0.0
            enddo
        enddo
c
c  Read in the count images
c
        do n=1,ndata
            do ib=1,nbands
                elow = iel(ib)
                ehigh = ieh(ib)
                prefi = prefix(n)
                if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                    if(elow .ge. 1000) then
                        if(ehigh .ge. 10000) then
                            write(im_name,3031) prefix(n), elow, ehigh
 3031                       format('mos',a5,'-obj-im-',i4,'-',
     +                               i5,'.fits')
                        else
                            write(im_name,3032) prefix(n), elow, ehigh
 3032                       format('mos',a5,'-obj-im-',i4,'-',
     +                               i4,'.fits')
                        endif
                    elseif(ehigh .lt. 1000) then
                        write(im_name,3033) prefix(n), elow, ehigh
 3033                   format('mos',a5,'-obj-im-',i3,'-',i3,'.fits')
                    elseif(ehigh .ge. 10000) then
                        write(im_name,3034) prefix(n), elow, ehigh
 3034                   format('mos',a5,'-obj-im-',i3,'-',i5,'.fits')
                    else
                        write(im_name,3035) prefix(n), elow, ehigh
 3035                   format('mos',a5,'-obj-im-',i3,'-',i4,'.fits')
                    endif
                else
                    do i=1,4
                        pr(i) = pre(i)
                    enddo
                    if(iel(1) .ge. 1000) then
                        if(ehigh .ge. 10000) then
                            write(im_name,3036) pref, elow, ehigh
 3036                       format('pn',a4,'-obj-im-',i4,'-',
     +                               i5,'.fits')
                            write(im_nameo,2936) pref, elow, ehigh
 2936                       format('pn',a4,'-obj-im-',i4,'-',
     +                               i5,'-oot.fits')
                        else
                            write(im_name,3037) pref, elow, ehigh
 3037                       format('pn',a4,'-obj-im-',i4,'-',
     +                               i4,'.fits')
                            write(im_nameo,2937) pref, elow, ehigh
 2937                       format('pn',a4,'-obj-im-',i4,'-',
     +                               i4,'-oot.fits')
                        endif
                    elseif(ehigh .lt. 1000) then
                        write(im_name,3038) pref, elow, ehigh
 3038                   format('pn',a4,'-obj-im-',i3,'-',i3,'.fits')
                        write(im_nameo,2938) pref, elow, ehigh
 2938                   format('pn',a4,'-obj-im-',i3,'-',i3,'-oot.fits')
                    elseif(ehigh .ge. 10000) then
                        write(im_name,3039) pref, elow, ehigh
 3039                   format('pn',a4,'-obj-im-',i3,'-',i5,'.fits')
                        write(im_nameo,2939) pref, elow, ehigh
 2939                   format('pn',a4,'-obj-im-',i3,'-',i5,'-oot.fits')
                    else
                        write(im_name,3040) pref, elow, ehigh
 3040                   format('pn',a4,'-obj-im-',i3,'-',i4,'.fits')
                        write(im_nameo,2940) pref, elow, ehigh
 2940                   format('pn',a4,'-obj-im-',i3,'-',i4,'-oot.fits')
                    endif
                endif
c                print *, im_name
                call retfit(im_name,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS RETFIT =', status
                    print *, 'COMB POSITION 04'
                    print *, 'Missing a count image'
                    print *, im_name
                    stop
                endif
c
c  Combine the images with masking
c
                ttot = 0.0
                do i=1,900
                    do ii=1,900
                        outim(i,ii) = outim(i,ii) +
     +                          image(i,ii)*mask(i,ii,n)
                        ttot = ttot + image(i,ii)*mask(i,ii,n)
                    enddo
                enddo
                print *, 'Number of counts: ', ttot
                totcou = totcou + ttot
                if((pre(1) .ne. '1') .and. (pre(1) .ne. '2')) then
                    ttot = 0.0
c                    print *, im_nameo
                    call retfit(im_nameo,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
c
c  This is a bit painful, but we need to know the SUBMODE
c  keyword for the proper scaling of the OOT events
c
c  Get an unused lun
c
                    call ftgiou(lun,status)
                    if(status .ne. 0) then
                        print *, 'STATUS FTGIOU =', status
                        print *, 'COMB POSITION 05'
                    endif
c
c  Open the FITS file
c
                    call ftopen (lun,im_nameo,0,block,status)
                    if(status .ne. 0) then
                        print *, 'STATUS FTOPEN =', status
                        print *, 'COMB POSITION 06'
                        print *, im_nameo
                    endif
c
c  Read in the mode information if a PN observation
c
                    call ftgkys (lun,'SUBMODE',mode,com,status)
                    if(status .ne. 0) then
                        print *, 'Missing SUBMODE keyword'
                        status = 0
                        ootsca = 0.0
                    else
                        if(mode .eq. 'PrimeFullWindow') ootsca = 0.063
                        if(mode .eq. 'PrimeFullWindowExtended')
     +                          ootsca = 0.023
                        if(mode .eq. 'PrimeFullWindowExtended5')
     +                          ootsca = 0.013
                    endif
                    print *, 'OOT scale factor: ', ootsca
c
c  Close the FITS file
c
                    call ftclos(lun,status)
                    if(status .ne. 0) then
                        print *, 'STATUS FTCLOS =', status
                        print *, 'COMB POSITION 07'
                        print *, im_nameo
                    endif
c
                    do i=1,900
                        do ii=1,900
                            outim(i,ii) = outim(i,ii) -
     +                              ootsca*image(i,ii)*mask(i,ii,n)
                            ttot = ttot + image(i,ii)*mask(i,ii,n)
                        enddo
                    enddo
                    totcou = totcou - ttot
                    print *, ' Number of OOT counts: ', ootsca*ttot
                endif
            enddo
        enddo
c
c  Now write out the merged count file, first get two unused luns
c
        call ftgiou(luna,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'COMB POSITION 08'
            stop
        endif
        call ftgiou(lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'COMB POSITION 09'
            stop
        endif
c
c  Open the old image FITS file
c
        call ftopen (luna,im_name,0,block,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTOPEN =', status
            print *, 'COMB POSITION 10'
            print *, im_name
            stop
        endif
c
c  Create the output file name
c
        if(ebmin .ge. 1000) then
            if(ebmax .ge. 10000) then
                write(imo_name,3041) ebmin, ebmax
 3041           format('comb-obj-im-',i4,'-',i5,'.fits')
            else
                write(imo_name,3042) ebmin, ebmax
 3042           format('comb-obj-im-',i4,'-',i4,'.fits')
            endif
        elseif(ebmax .lt. 1000) then
            write(imo_name,3043) ebmin, ebmax
 3043       format('comb-obj-im-',i3,'-',i3,'.fits')
        elseif(ebmax .ge. 10000) then
            write(imo_name,3044) ebmin, ebmax
 3044       format('comb-obj-im-',i3,'-',i5,'.fits')
        else
            write(imo_name,3045) ebmin, ebmax
 3045       format('comb-obj-im-',i3,'-',i4,'.fits')
        endif
        print *, 'Output file name'
        print *, imo_name
c
c  Check to see if there is an existing file
c
        call ftopen (lunb,imo_name,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                call ftdelt(lunb,status)
            else
                print *, 'Will not clobber file'
                print *, 'COMB POSITION 11'
                stop
            endif
        endif
        status = 0
        call ftinit (lunb,imo_name,2880,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTINIT =', status
            print *, 'COMB POSITION 12'
            stop
        endif
c
c  Copy the fits header information from the old to new files
c
        call ftcphd (luna,lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTCPHD =', status
            print *, 'COMB POSITION 13'
            stop
        endif
c
        bitpix = -32
        naxis = 2
        naxes(1) = 900
        naxes(2) = 900
        pcount = 0
        gcount = 1
        group = 1
        call ftpdef (lunb,bitpix,naxis,naxes,pcount,
     +          gcount,.FALSE.,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTPDEF =', status
            print *, 'COMB POSITION 14'
            stop
        endif
        call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTMKYJ =', status
            print *, 'COMB POSITION 15'
            stop
        endif
        if(err .eq. 0) then
c
c  Write the output image
c
            call ftp2de (lunb,group,naxes(1),naxes(1),naxes(2),
     +              outim,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTP2DE =', status
                print *, 'COMB POSITION 16'
                print *, 'Could not write the merged count image'
                stop
            endif
c
c  Close the output file
c
            call ftclos(luna,status)
            call ftclos(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTCLOS =', status
                print *, 'COMB POSITION 17'
                print *, 'Could not close the output file'
                stop
            endif
        endif
        call ftfiou (luna,status)
        call ftfiou (lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTFIOU =', status
            print *, 'COMB POSITION 18'
            print *, 'Could not close the output file'
            stop
        endif
            print *, '  '
c
c  Zero the output images
c
        do i=1,900
            do ii=1,900
                outim(i,ii) = 0.0
            enddo
        enddo
c
c  Read in the exposure images
c
        do n=1,ndata
            do ib=1,nbands
                elow = iel(ib)
                ehigh = ieh(ib)
                prefi = prefix(n)
                if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                    if(pre(1) .eq. '1') idet = 1
                    if(pre(1) .eq. '2') idet = 2
                else
                    idet = 3
                    do i=1,4
                        pr(i) = pre(i)
                    enddo
                endif
                if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                    if(elow .ge. 1000) then
                        if(ehigh .ge. 10000) then
                            write(im_name,3051) prefix(n), elow, ehigh
 3051                       format('mos',a5,'-exp-im-',i4,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3052) prefix(n), elow, ehigh
 3052                       format('mos',a5,'-exp-im-',i4,'-',
     +                              i4,'.fits')
                        endif
                    elseif(ehigh .lt. 1000) then
                        write(im_name,3053) prefix(n), elow, ehigh
 3053                   format('mos',a5,'-exp-im-',i3,'-',i3,'.fits')
                    elseif(ehigh .ge. 10000) then
                        write(im_name,3054) prefix(n), elow, ehigh
 3054                   format('mos',a5,'-exp-im-',i3,'-',i5,'.fits')
                    else
                        write(im_name,3055) prefix(n), elow, ehigh
 3055                   format('mos',a5,'-exp-im-',i3,'-',i4,'.fits')
                    endif
                else
                    do i=1,4
                        pr(i) = pre(i)
                    enddo
                    if(elow .ge. 1000) then
                        if(ehigh .ge. 10000) then
                            write(im_name,3056) pref, elow, ehigh
 3056                       format('pn',a4,'-exp-im-',i4,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3057) pref, elow, ehigh
 3057                       format('pn',a4,'-exp-im-',i4,'-',
     +                              i4,'.fits')
                        endif
                    elseif(ehigh .lt. 1000) then
                        write(im_name,3058) pref, elow, ehigh
 3058                   format('pn',a4,'-exp-im-',i3,'-',i3,'.fits')
                    elseif(ehigh .ge. 10000) then
                        write(im_name,3059) pref, elow, ehigh
 3059                   format('pn',a4,'-exp-im-',i3,'-',i5,'.fits')
                    else
                        write(im_name,3060) pref, elow, ehigh
 3060                   format('pn',a4,'-exp-im-',i3,'-',i4,'.fits')
                    endif
                endif
c
                call retfit(im_name,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
c
c  This is a bit painful, but we need to know the FILTER
c  keyword for the proper scaling of the OOT events
c
c  Get an unused lun
c
                call ftgiou(lun,status)
                if(status .ne. 0) then
                    print *, 'STATUS FTGIOU =', status
                    print *, 'COMB POSITION 19'
                endif
c
c  Open the FITS file
c
                call ftopen (lun,im_name,0,block,status)
                if(status .ne. 0) then
                    print *, 'STATUS FTOPEN =', status
                    print *, 'COMB POSITION 20'
                    print *, im_nameo
                endif
c
c  Get the filter and then the filter scale factor
c
                call ftgkys (lun,'FILTER',filter,com,status)
                if(status .ne. 0) then
                    print *, 'Missing FILTER keyword'
                    status = 0
                    fscal = 1.0
                else
                    call hard_scale (xmmdir,alpha,idet,
     +                      filt,islow,ishigh,fscal)
                    print *, 'Detector, Filter: ', idet, '  ',
     +                      filt
                endif
                print *, 'Filter scale factor: ', fscal
c
c  Close the FITS file
c
                call ftclos(lun,status)
                if(status .ne. 0) then
                    print *, 'STATUS FTCLOS =', status
                    print *, 'COMB POSITION 21'
                    print *, im_nameo
                endif
c
c                print *, im_name
                call retfit(im_name,image,i2array,i4array,
     +                  1,900,900,ctype,crval,cdelt,crpix,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS RETFIT =', status
                    print *, 'COMB POSITION 22'
                    print *, 'Missing an exposure image'
                    stop
                endif
c
c  Combine and mask the images
c
                ttot = 0.0
                do i=1,900
                    do ii=1,900
                        outim(i,ii) = outim(i,ii) +
     +                          fscal*image(i,ii)*mask(i,ii,n)
                        ttot = ttot + image(i,ii)
                    enddo
                enddo
                totexp = totexp + ttot
                print *, 'Exposure: ', ttot
            enddo
        enddo
c
c  Now write out the merged count file, first get two unused luns
c
        call ftgiou(luna,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'COMB POSITION 23'
            stop
        endif
        call ftgiou(lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'COMB POSITION 24'
            stop
        endif
c
c  Open the old image FITS file
c
        call ftopen (luna,im_name,0,block,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTOPEN =', status
            print *, 'COMB POSITION 25'
            print *, im_name
            stop
        endif
c
c  Create the output exposure file name
c
        if(ebmin .ge. 1000) then
            if(ebmax .ge. 10000) then
                write(imo_name,3061) ebmin, ebmax
 3061           format('comb-exp-im-',i4,'-',i5,'.fits')
            else
                write(imo_name,3062) ebmin, ebmax
 3062           format('comb-exp-im-',i4,'-',i4,'.fits')
            endif
        elseif(ebmax .lt. 1000) then
            write(imo_name,3063) ebmin, ebmax
 3063       format('comb-exp-im-',i3,'-',i3,'.fits')
        elseif(ebmax .ge. 10000) then
            write(imo_name,3064) ebmin, ebmax
 3064       format('comb-exp-im-',i3,'-',i5,'.fits')
        else
            write(imo_name,3065) ebmin, ebmax
 3065       format('comb-exp-im-',i3,'-',i4,'.fits')
        endif
        print *, ' '
        print *, 'Output file name'
        print *, imo_name
c
c  Check to see if there is an existing file
c
        call ftopen (lunb,imo_name,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                print *, '  '
                call ftdelt(lunb,status)
            else
                print *, 'Will not clobber file'
                print *, 'COMB POSITION 26'
                stop
            endif
        endif
        status = 0
c
        call ftinit (lunb,imo_name,2880,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTINIT =', status
            print *, 'COMB POSITION 27'
            stop
        endif
c
c  Copy the fits header information from the old to new files
c
        call ftcphd (luna,lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTCPHD =', status
            print *, 'COMB POSITION 28'
            stop
        endif
c
        bitpix = -32
        naxis = 2
        naxes(1) = 900
        naxes(2) = 900
        pcount = 0
        gcount = 1
        group = 1
        call ftpdef (lunb,bitpix,naxis,naxes,pcount,
     +          gcount,.FALSE.,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTPDEF =', status
            print *, 'COMB POSITION 29'
            stop
        endif
        call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTMKYJ =', status
            print *, 'COMB POSITION 30'
            stop
        endif
        if(err .eq. 0) then
c
c  Write the output image
c
            call ftp2de (lunb,group,naxes(1),naxes(1),naxes(2),
     +              outim,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTP2DE =', status
                print *, 'COMB POSITION 31'
                print *, 'Could not write the merged exposure image'
                stop
            endif
c
c  Close the output file
c
            call ftclos(luna,status)
            call ftclos(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTCLOS =', status
                print *, 'COMB POSITION 32'
                print *, 'Could not close the output file'
                stop
            endif
        endif
        call ftfiou (luna,status)
        call ftfiou (lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTFIOU =', status
            print *, 'COMB POSITION 33'
            print *, 'Could not close the output file'
            stop
        endif
c
c
c
        if(ipart .eq. 1) then
c
c  Zero the output images
c
            do i=1,900
                do ii=1,900
                    outim(i,ii) = 0.0
                enddo
            enddo
c
c  Read in the background images
c
            do n=1,ndata
                do ib=1,nbands
                    elow = iel(ib)
                    ehigh = ieh(ib)
                    if(doit .eqv. .TRUE.) then
                        prefi = prefix(n)
                        if((pre(1) .eq. '1') .or.
     +                          (pre(1) .eq. '2')) then
                            if(elow .ge. 1000) then
                                if(ehigh .ge. 10000) then
                                    write(im_name,3071) prefix(n),
     +                                  elow, ehigh
 3071                               format('mos',a5,'-back-im-sky-',i4,
     +                                      '-',i5,'.fits')
                                else
                                    write(im_name,3072) prefix(n),
     +                                      elow, ehigh
 3072                               format('mos',a5,'-back-im-sky-',i4,
     +                                      '-',i4,'.fits')
                                endif
                            elseif(ehigh .lt. 1000) then
                                write(im_name,3073) prefix(n),elow,ehigh
 3073                           format('mos',a5,'-back-im-sky-',i3,'-',
     +                                  i3,'.fits')
                            elseif(ehigh .ge. 10000) then
                                write(im_name,3074) prefix(n),elow,ehigh
 3074                           format('mos',a5,'-back-im-sky-',i3,'-',
     +                                  i5,'.fits')
                            else
                                write(im_name,3075) prefix(n),elow,ehigh
 3075                           format('mos',a5,'-back-im-sky-',i3,'-',
     +                              i4,'.fits')
                            endif
                        else
                            do i=1,4
                                pr(i) = pre(i)
                            enddo
                            if(elow .ge. 1000) then
                                if(ehigh .ge. 10000) then
                                    write(im_name,3076) prefix(n),
     +                                      elow, ehigh
 3076                               format('pn',a4,'-back-im-sky-',i4,
     +                                      '-',i5,'.fits')
                                else
                                    write(im_name,3077) prefix(n),
     +                                      elow, ehigh
 3077                               format('pn',a4,'-back-im-sky-',i4,
     +                                  '-',i4,'.fits')
                                    endif
                            elseif(ehigh .lt. 1000) then
                                write(im_name,3078) prefix(n),elow,ehigh
 3078                           format('pn',a4,'-back-im-sky-',i3,'-',
     +                                  i3,'.fits')
                            elseif(ehigh .ge. 10000) then
                                write(im_name,3079) prefix(n),elow,ehigh
 3079                           format('pn',a4,'-back-im-sky-',i3,'-',
     +                                  i5,'.fits')
                            else
                                write(im_name,3080) prefix(n),elow,ehigh
 3080                           format('pn',a4,'-back-im-sky-',i3,'-',
     +                              i4,'.fits')
                            endif
                        endif
c
c                        print *, im_name
                        call retfit(im_name,image,i2array,i4array,
     +                        1,900,900,ctype,crval,cdelt,crpix,status)
                        if((status .ne. 0) .and. (err .eq. 0)) then
                            print *, 'Missing background images'
                            print *, 'Not a problem but do not select '
                            print *, 'to include background images in ',
     +                               'adapt-900'
                            doit = .FALSE.
                        endif
c
c  Combine the images
c
                        ttot = 0.0
                        do i=1,900
                            do ii=1,900
                                outim(i,ii) = outim(i,ii) +
     +                                  image(i,ii)*mask(i,ii,n)
                                ttot = ttot + image(i,ii)
                            enddo
                        enddo
                        totback = totback + ttot
                        print *, 'Background counts: ', ttot
                    endif
                enddo
            enddo
c
c  Now write out the merged count file, first get two unused luns
c
            if(doit .eqv. .TRUE.) then
                call ftgiou(luna,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTGIOU =', status
                    print *, 'COMB POSITION 34'
                    stop
                endif
                call ftgiou(lunb,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTGIOU =', status
                    print *, 'COMB POSITION 35'
                    stop
                endif
c
c  Open the old image FITS file
c
                call ftopen (luna,im_name,0,block,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTOPEN =', status
                    print *, 'COMB POSITION 36'
                    print *, im_name
                    stop
                endif
c
c  Create the output particle background file name
c
                if(ebmin .ge. 1000) then
                    if(ebmax .ge. 10000) then
                        write(imo_name,3081) ebmin, ebmax
 3081                   format('comb-back-im-sky-',i4,'-',i5,'.fits')
                    else
                        write(imo_name,3082) ebmin, ebmax
 3082                   format('comb-back-im-sky-',i4,'-',i4,'.fits')
                    endif
                elseif(ebmax .lt. 1000) then
                    write(imo_name,3083) ebmin, ebmax
 3083               format('comb-back-im-sky-',i3,'-',i3,'.fits')
                elseif(ebmax .ge. 10000) then
                    write(imo_name,3084) ebmin, ebmax
 3084               format('comb-back-im-sky-',i3,'-',i5,'.fits')
                else
                    write(imo_name,3085) ebmin, ebmax
 3085               format('comb-back-im-sky-',i3,'-',i4,'.fits')
                endif
                print *, ' '
                print *, 'Output file name'
                print *, imo_name
c
c  Check to see if there is an existing file
c
                call ftopen (lunb,imo_name,0,block,status)
                if(status .eq.  0) then
                    print *, 'File exists with output file name'
                    if(clobber .eq.  1) then
                        print *, 'Clobber the file and continue'
                        call ftdelt(lunb,status)
                    else
                        print *, 'Will not clobber file'
                        print *, 'COMB POSITION 37'
                        stop
                    endif
                endif
                status = 0
c
                call ftinit (lunb,imo_name,2880,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTINIT =', status
                    print *, 'COMB POSITION 38'
                    stop
                endif
c
c  Copy the fits header information from the old to new files
c
                call ftcphd (luna,lunb,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTCPHD =', status
                    print *, 'COMB POSITION 39'
                    stop
                endif
c
                bitpix = -32
                naxis = 2
                naxes(1) = 900
                naxes(2) = 900
                pcount = 0
                gcount = 1
                group = 1
                call ftpdef (lunb,bitpix,naxis,naxes,pcount,
     +                  gcount,.FALSE.,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTPDEF =', status
                    print *, 'COMB POSITION 40'
                    stop
                endif
                call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTMKYJ =', status
                    print *, 'COMB POSITION 41'
                    stop
                endif
                if(err .eq. 0) then
c
c  Write the output image
c
                    call ftp2de (lunb,group,naxes(1),naxes(1),
     +                      naxes(2),outim,status)
                    if((status .ne. 0) .and. (err .eq. 0)) then
                        err = 1
                        print *, 'STATUS FTP2DE =', status
                        print *, 'COMB POSITION 42'
                        print *, 'Could not write the merged ',
     +                          'background image'
                        stop
                    endif
c
c  Close the output file
c
                    call ftclos(luna,status)
                    call ftclos(lunb,status)
                    if((status .ne. 0) .and. (err .eq. 0)) then
                        err = 1
                        print *, 'STATUS FTCLOS =', status
                        print *, 'COMB POSITION 43'
                        print *, 'Could not close the output file'
                        stop
                    endif
                endif
                call ftfiou (luna,status)
                call ftfiou (lunb,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTFIOU =', status
                    print *, 'COMB POSITION 44'
                    print *, 'Could not close the output file'
                    stop
                endif
            endif
        endif
c
c  Set up for the soft proton images
c  First, reset control parameters and zero the output images
c
        if(iprot .eq. 1) then
            status = 0
            doit = .TRUE.
            do i=1,900
                do ii=1,900
                    outim(i,ii) = 0.0
                enddo
            enddo
c
c  Read in the soft proton images
c
          do n=1,ndata
            do ib=1,nbands
                elow = iel(ib)
                ehigh = ieh(ib)
                if(doit .eqv. .TRUE.) then
                    prefi = prefix(n)
                    if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                        if(elow .ge. 1000) then
                            if(ehigh .ge. 10000) then
                                write(im_name,3091) prefix(n),
     +                                  elow, ehigh
 3091                           format('mos',a5,'-prot-im-sky-',i4,'-',
     +                                  i5,'.fits')
                            else
                                write(im_name,3092) prefix(n),
     +                                  elow, ehigh
 3092                           format('mos',a5,'-prot-im-sky-',i4,'-',
     +                                  i4,'.fits')
                            endif
                        elseif(ehigh .lt. 1000) then
                            write(im_name,3093) prefix(n), elow, ehigh
 3093                       format('mos',a5,'-prot-im-sky-',i3,'-',
     +                              i3,'.fits')
                        elseif(ehigh .ge. 10000) then
                            write(im_name,3094) prefix(n), elow, ehigh
 3094                       format('mos',a5,'-prot-im-sky-',i3,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3095) prefix(n), elow, ehigh
 3095                       format('mos',a5,'-prot-im-sky-',i3,'-',
     +                              i4,'.fits')
                        endif
                    else
                        do i=1,4
                            pr(i) = pre(i)
                        enddo
                        if(elow .ge. 1000) then
                            if(ehigh .ge. 10000) then
                                write(im_name,3096) prefix(n),
     +                                  elow, ehigh
 3096                           format('pn',a4,'-prot-im-sky-',i4,'-',
     +                                  i5,'.fits')
                            else
                                write(im_name,3097) prefix(n),
     +                                  elow, ehigh
 3097                           format('pn',a4,'-prot-im-sky-',i4,'-',
     +                                  i4,'.fits')
                            endif
                        elseif(ehigh .lt. 1000) then
                            write(im_name,3098) prefix(n), elow, ehigh
 3098                       format('pn',a4,'-prot-im-sky-',i3,'-',
     +                              i3,'.fits')
                        elseif(ehigh .ge. 10000) then
                            write(im_name,3099) prefix(n), elow, ehigh
 3099                       format('pn',a4,'-prot-im-sky-',i3,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3100) prefix(n), elow, ehigh
 3100                       format('pn',a4,'-prot-im-sky-',i3,'-',
     +                              i4,'.fits')
                        endif
                    endif
c
c                    print *, im_name
                    call retfit(im_name,image,i2array,i4array,
     +                      1,900,900,ctype,crval,cdelt,crpix,status)
                    if((status .ne. 0) .and. (err .eq. 0)) then
                         print *, 'Missing SP images'
                         print *, 'Not a problem but do not select'
                         print *, 'to include SP images in adapt-900'
                        doit = .FALSE.
                    endif
c
c  Combine the images
c
                    ttot = 0.0
                    do i=1,900
                        do ii=1,900
                            outim(i,ii) = outim(i,ii) +
     +                              image(i,ii)*mask(i,ii,n)
                            ttot = ttot + image(i,ii)
                        enddo
                    enddo
                    totprot = totprot + ttot
                    print *, 'SP counts', ttot
                endif
            enddo
          enddo
c
c  Now write out the merged soft proton file, first get two unused luns
c
          if(doit .eqv. .TRUE.) then
            call ftgiou(luna,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTGIOU =', status
                print *, 'COMB POSITION 45'
                stop
            endif
            call ftgiou(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTGIOU =', status
                print *, 'COMB POSITION 46'
                stop
            endif
c
c  Open the old image FITS file
c
            call ftopen (luna,im_name,0,block,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTOPEN =', status
                print *, 'COMB POSITION 47'
                print *, im_name
                stop
            endif
c
c  Create the output soft proton file name
c
            if(ebmin .ge. 1000) then
                if(ebmax .ge. 10000) then
                    write(imo_name,3101) ebmin, ebmax
 3101               format('comb-prot-im-sky-',i4,'-',i5,'.fits')
                else
                    write(imo_name,3102) ebmin, ebmax
 3102               format('comb-prot-im-sky-',i4,'-',i4,'.fits')
                endif
            elseif(ebmax .lt. 1000) then
                write(imo_name,3103) ebmin, ebmax
 3103           format('comb-prot-im-sky-',i3,'-',i3,'.fits')
            elseif(ebmax .ge. 10000) then
                write(imo_name,3104) ebmin, ebmax
 3104           format('comb-prot-im-sky-',i3,'-',i5,'.fits')
            else
                write(imo_name,3105) ebmin, ebmax
 3105           format('comb-prot-im-sky-',i3,'-',i4,'.fits')
            endif
            print *, ' '
            print *, 'Output file name'
            print *, imo_name
c
c  Check to see if there is an existing file
c
            call ftopen (lunb,imo_name,0,block,status)
            if(status .eq.  0) then
                print *, 'File exists with output file name'
                if(clobber .eq.  1) then
                    print *, 'Clobber the file and continue'
                    call ftdelt(lunb,status)
                else
                    print *, 'Will not clobber file'
                    print *, 'COMB POSITION 48'
                    stop
                endif
            endif
            status = 0
c
            call ftinit (lunb,imo_name,2880,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTINIT =', status
                print *, 'COMB POSITION 49'
                stop
            endif
c
c  Copy the fits header information from the old to new files
c
            call ftcphd (luna,lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTCPHD =', status
                print *, 'COMB POSITION 50'
                stop
            endif
c
            bitpix = -32
            naxis = 2
            naxes(1) = 900
            naxes(2) = 900
            pcount = 0
            gcount = 1
            group = 1
            call ftpdef (lunb,bitpix,naxis,naxes,pcount,
     +              gcount,.FALSE.,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTPDEF =', status
                print *, 'COMB POSITION 51'
                stop
            endif
            call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTMKYJ =', status
                print *, 'COMB POSITION 52'
                stop
            endif
            if(err .eq. 0) then
c
c  Write the output image
c
                call ftp2de (lunb,group,naxes(1),naxes(1),naxes(2),
     +                  outim,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTP2DE =', status
                    print *, 'COMB POSITION 53'
                    print *, 'Could not write the merged soft ',
     +                  'proton image'
                    stop
                endif
c
c  Close the output file
c
                call ftclos(luna,status)
                call ftclos(lunb,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTCLOS =', status
                    print *, 'COMB POSITION 54'
                    print *, 'Could not close the output file'
                    stop
                endif
            endif
            call ftfiou (luna,status)
            call ftfiou (lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTFIOU =', status
                print *, 'COMB POSITION 55'
                print *, 'Could not close the output file'
                stop
            endif
          endif
        endif
c
c  Set up for the swcx images
c  First, reset control parameters and zero the output images
c
        if(iswcx .eq. 1) then
            status = 0
            doit = .TRUE.
            do i=1,900
                do ii=1,900
                    outim(i,ii) = 0.0
                enddo
            enddo
c
c  Read in the swcx images
c
          do n=1,ndata
            do ib=1,nbands
                elow = iel(ib)
                ehigh = ieh(ib)
                if(doit .eqv. .TRUE.) then
                    prefi = prefix(n)
                    if((pre(1) .eq. '1') .or. (pre(1) .eq. '2')) then
                        if(elow .ge. 1000) then
                            if(ehigh .ge. 10000) then
                                write(im_name,3111) prefix(n),
     +                                  elow, ehigh
 3111                           format('mos',a5,'-swcx-im-sky-',i4,'-',
     +                                  i5,'.fits')
                            else
                                write(im_name,3112) prefix(n),
     +                                  elow, ehigh
 3112                           format('mos',a5,'-swcx-im-sky-',i4,'-',
     +                                  i4,'.fits')
                            endif
                        elseif(ehigh .lt. 1000) then
                            write(im_name,3113) prefix(n), elow, ehigh
 3113                       format('mos',a5,'-swcx-im-sky-',i3,'-',
     +                              i3,'.fits')
                        elseif(ehigh .ge. 10000) then
                            write(im_name,3114) prefix(n), elow, ehigh
 3114                       format('mos',a5,'-swcx-im-sky-',i3,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3115) prefix(n), elow, ehigh
 3115                       format('mos',a5,'-swcx-im-sky-',i3,'-',
     +                              i4,'.fits')
                        endif
                    else
                        do i=1,4
                            pr(i) = pre(i)
                        enddo
                        if(elow .ge. 1000) then
                            if(ehigh .ge. 10000) then
                                write(im_name,3116) prefix(n),
     +                                  elow, ehigh
 3116                           format('pn',a4,'-swcx-im-sky-',i4,'-',
     +                                  i5,'.fits')
                            else
                                write(im_name,3117) prefix(n),
     +                                  elow, ehigh
 3117                           format('pn',a4,'-swcx-im-sky-',i4,'-',
     +                                  i4,'.fits')
                            endif
                        elseif(ehigh .lt. 1000) then
                            write(im_name,3118) prefix(n), elow, ehigh
 3118                       format('pn',a4,'-swcx-im-sky-',i3,'-',
     +                              i3,'.fits')
                        elseif(ehigh .ge. 10000) then
                            write(im_name,3119) prefix(n), elow, ehigh
 3119                       format('pn',a4,'-swcx-im-sky-',i3,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3120) prefix(n), elow, ehigh
 3120                       format('pn',a4,'-swcx-im-sky-',i3,'-',
     +                              i4,'.fits')
                        endif
                    endif
c
c                    print *, im_name
                    call retfit(im_name,image,i2array,i4array,
     +                      1,900,900,ctype,crval,cdelt,crpix,status)
                    if((status .ne. 0) .and. (err .eq. 0)) then
                        print *, 'Missing SWCX images'
                        print *, 'Not a problem but do not select'
                        print *, 'to include SWCX images in adapt-900'
                        doit = .FALSE.
                    endif
c
c  Combine the images
c
                    ttot = 0.0
                    do i=1,900
                        do ii=1,900
                            outim(i,ii) = outim(i,ii) +
     +                              image(i,ii)*mask(i,ii,n)
                            ttot = ttot + image(i,ii)
                        enddo
                    enddo
                    totswcx = totswcx + ttot
                    print *, 'SWCX counts', ttot
                endif
            enddo
          enddo
c
c  Now write out the merged soft proton file, first get two unused luns
c
          if(doit .eqv. .TRUE.) then
            call ftgiou(luna,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTGIOU =', status
                print *, 'COMB POSITION 56'
                stop
            endif
            call ftgiou(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTGIOU =', status
                print *, 'COMB POSITION 57'
                stop
            endif
c
c  Open the old image FITS file
c
            call ftopen (luna,im_name,0,block,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTOPEN =', status
                print *, 'COMB POSITION 58'
                print *, im_name
                stop
            endif
c
c  Create the output soft proton file name
c
            if(ebmin .ge. 1000) then
                if(ebmax .ge. 10000) then
                    write(imo_name,3121) ebmin, ebmax
 3121               format('comb-swcx-im-sky-',i4,'-',i5,'.fits')
                else
                    write(imo_name,3122) ebmin, ebmax
 3122               format('comb-swcx-im-sky-',i4,'-',i4,'.fits')
                endif
            elseif(ebmax .lt. 1000) then
                write(imo_name,3123) ebmin, ebmax
 3123           format('comb-swcx-im-sky-',i3,'-',i3,'.fits')
            elseif(ebmax .ge. 10000) then
                write(imo_name,3124) ebmin, ebmax
 3124           format('comb-swcx-im-sky-',i3,'-',i5,'.fits')
            else
                write(imo_name,3125) ebmin, ebmax
 3125           format('comb-swcx-im-sky-',i3,'-',i4,'.fits')
            endif
            print *, 'Output file name'
            print *, imo_name
c
c  Check to see if there is an existing file
c
            call ftopen (lunb,imo_name,0,block,status)
            if(status .eq.  0) then
                print *, 'File exists with output file name'
                if(clobber .eq.  1) then
                    print *, 'Clobber the file and continue'
                    call ftdelt(lunb,status)
                else
                    print *, 'Will not clobber file'
                    print *, 'COMB POSITION 59'
                    stop
                endif
            endif
            status = 0
c
            call ftinit (lunb,imo_name,2880,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTINIT =', status
                print *, 'COMB POSITION 60'
                stop
            endif
c
c  Copy the fits header information from the old to new files
c
            call ftcphd (luna,lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTCPHD =', status
                print *, 'COMB POSITION 61'
                stop
            endif
c
            bitpix = -32
            naxis = 2
            naxes(1) = 900
            naxes(2) = 900
            pcount = 0
            gcount = 1
            group = 1
            call ftpdef (lunb,bitpix,naxis,naxes,pcount,
     +              gcount,.FALSE.,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTPDEF =', status
                print *, 'COMB POSITION 62'
                stop
            endif
            call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTMKYJ =', status
                print *, 'COMB POSITION 63'
                stop
            endif
            if(err .eq. 0) then
c
c  Write the output image
c
                call ftp2de (lunb,group,naxes(1),naxes(1),naxes(2),
     +                  outim,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTP2DE =', status
                    print *, 'COMB POSITION 64'
                    print *, 'Could not write the merged soft ',
     +                  'proton image'
                    stop
                endif
c
c  Close the output file
c
                call ftclos(luna,status)
                call ftclos(lunb,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTCLOS =', status
                    print *, 'COMB POSITION 65'
                    print *, 'Could not close the output file'
                    stop
                endif
            endif
            call ftfiou (luna,status)
            call ftfiou (lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTFIOU =', status
                print *, 'COMB POSITION 66'
                print *, 'Could not close the output file'
                stop
            endif
          endif
        endif
c
        print *, ' '
        print *, 'Total Observed Counts: ', totcou
        print *, 'Total Exposure: ', totexp
        print *, 'Total Particle Background Counts: ', totback
        print *, 'Total Soft Proton Counts: ', totprot
        print *, 'Total SWCX Counts: ', totswcx
c
        RETURN
        END SUBROUTINE comb_sub
