        subroutine  make_mask_merge_sub(srclist,prefix,inmask,flimtot,
     +          flimsoft,flimhard,scale,seper,maxlikelim)
C
C  Version 0.1 4 March 2010
C
C  Creates a cheese mask using the merged source list
C
C  MAKE_MASK_MERGE creates a cheese mask image from the merged
C  source list created by the program MERGE_SOURCE_LIST.  It creates
C  masks for three bands, soft, hard, and combined band.
C
C  Usage:
C      srclist: source list
C      prefix: exposure ID prefix
C      inmask: input mask file name
C      flimtot:  combined band source flux threshold (10^-14 cgs)
C      flimsoft: soft band source flux threshold (10^-14 cgs)
C      flimhard: hard band source flux threshold (10^-14 cgs)
C      scale: scale factor for W90 radius
C      seper: minimum allowed source separation in arc seconds
C      maxlikelim: minimum maximum likelihood source detection
C 
C  Example: 
C      make_mask_merge srclist=merged-source-list.fits prefix=1S002 
C              inmask=mos1S001-mask-im-750-1250.fits flimtot=0.5 
C              flimsoft=0.5 flimhard=0.5 scale=0.9 seper=40 maxlikelim=15.0
C
C  OUPUT:
C    Cheese mask
C
        IMPLICIT NONE
C
        REAL fl, flimtot, flimsoft, flimhard, 
     +       fluxh(100000), fluxs(100000), fluxt(100000), maxlikelim, 
     +       mlt(100000), r, rex, SCALE, sep(100000), seper, ts, w90
        DOUBLE PRECISION CDELT(2), CRPIX(2), CROT, DEC(100000), 
     +      RA(100000), CRVAL(2), EXPOSE, x, y
        INTEGER BITPIX, BLOCK, BLOCKL, CLOBBER, ERR, GCOUNT, GROUP,
     +      hdutype, I, icol, idec, IDET, idist, iflh, ifls, iflt, 
     +      iml, ira, j, j1, j2, jj, jj1, jj2, LUN, MASKH(900,900), 
     +      MASKS(900,900), MASKT(900,900), NAXES(10), NAXIS, nchan,  
     +      ncols, PCOUNT, STATUS, tfields, varidat
        CHARACTER*1  SDET
        CHARACTER*4  CTYP, PREFI
        CHARACTER*5  PREFIX
        CHARACTER*8  tform(300), ttype(300), tunit(300),  
     +      UNITS, CTYPE(2)
        CHARACTER*10 colnam(300)
        CHARACTER*20 extname
        CHARACTER*60 COM
        CHARACTER*80 inmask, outmaskh, outmasks, 
     +      outmaskt, srclist
        LOGICAL ANYF, EXTEND, SIMPLE
C
        DATA CLOBBER /1/
        DATA ERR /0/
        DATA STATUS /0/
C
C Determin program parameters
C
        READ(PREFIX,'(A1)') SDET
        IF((SDET .EQ. 'S') .OR. (SDET .EQ. 'U')) THEN
            IDET = 3
            READ(PREFIX,'(A4)') PREFI
        ELSE
            READ(PREFIX,'(I1)') IDET
        ENDIF
        FLIMTOT = 1.0e-14*FLIMTOT
        FLIMSOFT = 1.0e-14*FLIMSOFT
        FLIMHARD = 1.0e-14*FLIMHARD
c
        print *, 'Source List: ', srclist
        print *, 'Exposure ID: ', prefix
        print *, 'Input Mask: ', inmask
        print *, 'Combined Band Flux Limit (x1e-14): ', flimtot
        print *, 'Soft Band Flux Limit (x1e-14): ', flimsoft
        print *, 'Hard Band Flux Limit (x1e-14): ', flimhard
        print *, 'W90 Scale Factor: ', scale
        print *, 'Minimum Source Separation: ', seper
c
c  Create the file name for the output mask
c
        IF(IDET .LE. 2) THEN
            WRITE(OUTMASKS,3001) PREFIX
 3001       FORMAT('mos',A5,'-msl-cheese-s.fits')
            WRITE(OUTMASKH,3002) PREFIX
 3002       FORMAT('mos',A5,'-msl-cheese-h.fits')
            WRITE(OUTMASKT,3003) PREFIX
 3003       FORMAT('mos',A5,'-msl-cheese.fits')
        ELSE
            WRITE(OUTMASKS,3011) PREFIX
 3011       FORMAT('pn',A4,'-msl-cheese-s.fits')
            WRITE(OUTMASKH,3012) PREFIX
 3012       FORMAT('pn',A4,'-msl-cheese-h.fits')
            WRITE(OUTMASKT,3013) PREFIX
 3013       FORMAT('pn',A4,'-msl-cheese.fits')
        ENDIF
c
c  Get an unused lun
c
        call ftgiou(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'MAKE_MASK_MERGE POSITION 01'
            print *, 'STATUS FTGIOU =', status
        endif
C
C  Open the FITS file for the template
C
        CALL FTOPEN(lun,inmask,0,BLOCK,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 02'
            PRINT *, 'STATUS FTOPEN =', STATUS
            PRINT *, inmask
        ENDIF
C
C  Read the FITS file header information
C
        CALL FTGHPR (lun,10,SIMPLE,BITPIX,NAXIS,NAXES,
     +              PCOUNT,GCOUNT,EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 03'
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, inmask
        ENDIF
C
C  Get the useful keywords
C
        CALL FTGICS (lun,CRVAL(1),CRVAL(2),CRPIX(1),CRPIX(2),
     +          CDELT(1),CDELT(2),CROT,CTYP,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 04'
            PRINT *, 'STATUS FTGICS =', STATUS
            PRINT *, inmask
        ENDIF
C
C  And a few more
C
        CALL FTGKYS (lun,'CTYPE1',CTYPE(1),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 05'
            PRINT *, 'STATUS FTGKYS =', STATUS
            PRINT *, inmask
        ENDIF
        CALL FTGKYS (lun,'CTYPE2',CTYPE(2),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 06'
            PRINT *, 'STATUS FTGKYS =', STATUS
            PRINT *, inmask
        ENDIF
c        CALL FTGKYD (lun,'PA_PNT',CROT,COM,STATUS)
c        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
c            ERR = 1
c            PRINT *, 'MAKE_MASK_MERGE POSITION 07'
c            PRINT *, 'STATUS FTGKYD =', STATUS
c            PRINT *, inmask
c        ENDIF
        CALL FTGKYD (lun,'EXPOSURE',EXPOSE,COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 08'
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, inmask
        ENDIF
C
C  Read in the mask image
C
        CALL FTG2DJ (lun,0,0,NAXES(1),NAXES(1),NAXES(2),MASKT,
     +         ANYF,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 09a'
            PRINT *, 'STATUS FTG2DJ =', STATUS
            PRINT *, inmask
        ENDIF
        CALL FTG2DJ (lun,0,0,NAXES(1),NAXES(1),NAXES(2),MASKS,
     +         ANYF,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 09b'
            PRINT *, 'STATUS FTG2DJ =', STATUS
            PRINT *, inmask
        ENDIF
        CALL FTG2DJ (lun,0,0,NAXES(1),NAXES(1),NAXES(2),MASKH,
     +         ANYF,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 09c'
            PRINT *, 'STATUS FTG2DJ =', STATUS
            PRINT *, inmask
        ENDIF
C
C  Close the file
C
        CALL FTCLOS (lun,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 10'
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, inmask
        ENDIF
C
C  Print the details of the template image
C
        PRINT *, 'Template File'
        PRINT *, inmask
        PRINT *, 'Template image coordinate system: ', CTYP
        PRINT *, 'Template image coordinate ID: ',  
     +          CTYPE(1), '  ', CTYPE(2)
        PRINT *, 'Template image central coordinates: ',  
     +          CRVAL(1), CRVAL(2)
        PRINT *, 'Template image reference pixel: ',  
     +          CRPIX(1), CRPIX(2)
        PRINT *, 'Template image pixel sizes: ', 
     +          CDELT(1), CDELT(2)
        PRINT *, 'Template image NAXES, NAXIS: ', NAXIS, 
     +          (NAXES(I),I=1,NAXIS)
c
c  Get an unused lun
c
        call ftgiou(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'MAKE_MASK_MERGE POSITION 11'
            print *, 'STATUS FTGIOU =', status
        endif
c
c  Open and read in the source list
c
        call ftopen(lun,srclist,0,blockl,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'MAKE_MASK_MERGE POSITION 12'
            print *, 'STATUS FTOPEN =', status
        endif
c
c  Move to the source list extension
c
        call ftmrhd (lun,1,hdutype,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'MAKE_MASK_MERGE POSITION 13'
            print *, 'STATUS FTMRHD =', status
            print *, 'Could not find the source list extension'
            print *, srclist
        else
c
c  Read the FITS file header information
c
            call ftghbn (lun,300,nchan,tfields,ttype,tform,
     +              tunit,extname,varidat,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'MAKE_MASK_MERGE POSITION 14'
                print *, 'STATUS FTGHBN =', status
                print *, srclist
            endif
            if(extname .ne. 'SRCLIST') then
                print *, extname
                print *, 'This was supposed to be a source list ext'
                stop
            endif
c
c  Read in the column names
c
            call ftgkns (lun,'TTYPE',1,300,colnam,ncols,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'MAKE_MASK_MERGE POSITION 15'
                print *, 'STATUS FTGKNS =', status
                print *, srclist
            endif
c
c  Extract the column numbers for the desired columns
c
            ira = 0
            idec = 0
            iml = 0
            iflt = 0
            ifls = 0
            iflh = 0
            idist = 0
            do icol=1,ncols
                if(colnam(icol) .eq. 'RA') ira = icol
                if(colnam(icol) .eq. 'DEC') idec = icol
                if(colnam(icol) .eq. 'DET_ML') iml = icol
                if(colnam(icol) .eq. 'FLUX_TOT') iflt = icol
                if(colnam(icol) .eq. 'FLUX_S') ifls = icol
                if(colnam(icol) .eq. 'FLUX_H') iflh = icol
                if(colnam(icol) .eq. 'DIST_NN') idist = icol
            enddo
c
c  Now read in the data
c
            do i=1,nchan
                if (ira .ne. 0) 
     +              call ftgcvd(lun,ira,i,1,1,0,ra(i),anyf,status)
                if (idec .ne. 0) 
     +              call ftgcvd(lun,idec,i,1,1,0,
     +                      dec(i),anyf,status)
                if (iml .ne. 0) then
                    call ftgcve(lun,iml,i,1,1,-999,
     +                                  mlt(i),anyf,status)
                    if(anyf) mlt(i) = 0.0
                endif
                if (iflt .ne. 0) then
                    call ftgcve(lun,iflt,i,1,1,-999,
     +                      fluxt(i),anyf,status)
                    if(anyf) fluxt(i) = 0.0
                endif
                if (ifls .ne. 0) then
                    call ftgcve(lun,ifls,i,1,1,-999,
     +                      fluxs(i),anyf,status)
                    if(anyf) fluxs(i) = 0.0
                endif
                if (iflh .ne. 0) then
                    call ftgcve(lun,iflh,i,1,1,-999,
     +                      fluxh(i),anyf,status)
                    if(anyf) fluxh(i) = 0.0
                endif
                if (idist .ne. 0) call ftgcve(lun,idist,i,1,1,0,
     +                  sep(i),anyf,status)
c
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'MAKE_MASK_MERGE POSITION 16'
                    print *, 'STATUS FTGCV =', status
                endif
            enddo
        endif
c
c  Close the file
c
        call ftclos (lun,status)
c
c  Now start over the loop to mask sources
c
        do i=1,nchan
            if((sep(i) .gt. seper) .and. 
     +              (mlt(i) .gt. maxlikelim)) then
                call ftxypx(ra(i),dec(i),crval(1),crval(2),crpix(1),
     +              crpix(2),cdelt(1),cdelt(2),crot,ctyp,x,y,status)
c
c  Find the off-axis angle and scale the W90 radius.  This is a
c  very rough approximation to the psf variation at 1.5 keV
c     r is the off-axis angle in degrees
c     w90 is the 90% encircled energy radius in arc seconds
c     rex is the selected exclusion radius in pixels
c
                r = cdelt(2)*sqrt((x-crpix(1))**2 + (y-crpix(2))**2)
c
c  Do the combined band
c
                if(fluxt(i) .gt. flimtot) then 
                    if(idet .eq. 3) then
                        w90 = 53.0 + 1.0417*60.0*r + 
     +                          0.0903*60.0*60.0*r*r
                    else
                        w90 = 47.2 + 0.7667*60.0*r + 
     +                          0.01944*60.0*60.0*r*r
                    endif
c
c  Set the radius for the source masking - first determin the
c  exclusion radius as a function of off-axis angle
c
                    rex = scale*(w90/(3600.0*cdelt(2)))
                    fl = fluxt(i)
c
c  Second, scale the exclusion radius with the log of the
c  ratio of the source flux to threshold flux
c
                    ts = 1.0 + 1.2*alog10(fl/flimtot)
                    rex = ts*rex
c
c  Now, mask out the area
c
                    j1 = x - rex
                    if(j1 .lt. 1) j1 = 1
                    j2 = x + rex
                    if(j2 .gt. 900) j2 = 900
                    jj1 = y - rex
                    if(jj1 .lt. 1) jj1 = 1
                    jj2 = y + rex
                    if(jj2 .gt. 900) jj2 = 900
                    do j=j1,j2
                        do jj = jj1,jj2
                            r = sqrt((j-x)**2 + (jj-y)**2)
                            if (r .lt. rex) maskt(j,jj) = 0
                        enddo
                    enddo
                endif
c
c  Do the hard band
c
                if(fluxh(i) .gt. flimhard) then 
                    if(idet .eq. 3) then
                        w90 = 53.0 + 1.0417*60.0*r + 
     +                          0.0903*60.0*60.0*r*r
                    else
                        w90 = 47.2 + 0.7667*60.0*r + 
     +                          0.01944*60.0*60.0*r*r
                    endif
c
c  Set the radius for the source masking - first determin the
c  exclusion radius as a function of off-axis angle
c
                    rex = scale*(w90/(3600.0*cdelt(2)))
                    fl = fluxh(i)
c
c  Second, scale the exclusion radius with the log of the
c  ratio of the source flux to threshold flux
c
                    ts = 1.0 + 1.2*alog10(fl/flimhard)
                    rex = ts*rex
c
c  Now, mask out the area
c
                    j1 = x - rex
                    if(j1 .lt. 1) j1 = 1
                    j2 = x + rex
                    if(j2 .gt. 900) j2 = 900
                    jj1 = y - rex
                    if(jj1 .lt. 1) jj1 = 1
                    jj2 = y + rex
                    if(jj2 .gt. 900) jj2 = 900
                    do j=j1,j2
                        do jj = jj1,jj2
                            r = sqrt((j-x)**2 + (jj-y)**2)
                            if (r .lt. rex) maskh(j,jj) = 0
                        enddo
                    enddo
                endif
c
c  Do the soft band
c
                if(fluxs(i) .gt. flimsoft) then 
                    if(idet .eq. 3) then
                        w90 = 51.5 + 1.0*60.0*r + 
     +                          0.01389*60.0*60.0*r*r
                    else
                        w90 = 48.0 + 0.225*60.0*r + 
     +                          0.0125*60.0*60.0*r*r
                    endif
c
c  Set the radius for the source masking - first determin the
c  exclusion radius as a function of off-axis angle
c
                    rex = scale*(w90/(3600.0*cdelt(2)))
                    fl = fluxs(i)
c
c  Second, scale the exclusion radius with the log of the
c  ratio of the source flux to threshold flux
c
                    ts = 1.0 + 1.2*alog10(fl/flimsoft)
                    rex = ts*rex
c
c  Now, mask out the area
c
                    j1 = x - rex
                    if(j1 .lt. 1) j1 = 1
                    j2 = x + rex
                    if(j2 .gt. 900) j2 = 900
                    jj1 = y - rex
                    if(jj1 .lt. 1) jj1 = 1
                    jj2 = y + rex
                    if(jj2 .gt. 900) jj2 = 900
                    do j=j1,j2
                        do jj = jj1,jj2
                            r = sqrt((j-x)**2 + (jj-y)**2)
                            if (r .lt. rex) masks(j,jj) = 0
                        enddo
                    enddo
                endif
            endif
        enddo
c
c  Write out the new mask
c  Get an unused lun
c
        call ftgiou(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'MAKE_MASK_MERGE POSITION 17'
        endif
c
c  Check to see if there is an existing file
c
        call ftopen (lun,outmaskt,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                call ftdelt(lun,status)
            else
                print *, 'MAKE_MASK_MERGE 18'
                print *, 'Will not clobber file'
                print *, outmaskt
                stop
            endif
        endif
        status = 0
C
C  Create the FITS file for the output image
C
        GROUP = 1
        BITPIX = 32
        CALL FTINIT(lun,outmaskt,2880,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 19'
            PRINT *, 'STATUS FTINIT =', STATUS
            PRINT *, outmaskt
        ENDIF
C
C  Set the output file header
C
        CALL FTPHPR(lun,SIMPLE,BITPIX,NAXIS,NAXES,PCOUNT,GCOUNT,
     +              EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 20'
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, outmaskt
        ENDIF
C
C  Write some useful header keywords
C
        CALL FTPKYS(lun,'CONTENT','IMAGE','  ',STATUS)
        CALL FTPKYS(lun,'TELESCOP','XMM','mission name',STATUS)
        CALL FTPKYS(lun,'INSTRUME','EPIC','instrument name',STATUS)
        CALL FTPKYS(lun,'OBS_MODE','POINTING',
     +          'obs mode: POINTING,SLEW, OR SCAN',STATUS)
        CALL FTPKYS(lun,'RADECSYS','FK5',
     +          'Equatorial system reference',STATUS)
        CALL FTPKYJ(lun,'EQUINOX',2000,'Equinox',STATUS)
        CALL FTPKYD(lun,'EXPOSURE',EXPOSE,6,'Reference pixel',STATUS)
        CALL FTPKYF(lun,'BZERO',0.0,8,' ',STATUS)
        CALL FTPKYF(lun,'BSCALE',1.0,8,' ',STATUS)
        UNITS = 'counts'
        CALL FTPKYS(lun,'BUNIT',UNITS,'Units of data',STATUS)
        CALL FTPKYD(lun,'CRPIX1',CRPIX(1),8,'Reference pixel',STATUS)
        CALL FTPKYS(lun,'CTYPE1',CTYPE(1),'Projection',STATUS)
        CALL FTPKYD(lun,'CRVAL1',CRVAL(1),8,'Central longitude',STATUS)
        CALL FTPKYD(lun,'CDELT1',CDELT(1),8,'Pixel size',STATUS)
        CALL FTPKYS(lun,'CUNIT1','deg','Units of coordinate',STATUS)
C
        CALL FTPKYD(lun,'CRPIX2',CRPIX(2),8,'Reference pixel',STATUS)
        CALL FTPKYS(lun,'CTYPE2',CTYPE(2),'Projection',STATUS)
        CALL FTPKYD(lun,'CRVAL2',CRVAL(2),8,'Central latitude',STATUS)
        CALL FTPKYD(lun,'CDELT2',CDELT(2),8,'Pixel size',STATUS)
        CALL FTPKYS(lun,'CUNIT2','deg','Units of coordinate',STATUS)
C
        CALL FTPCOM(lun,
     +  'This file was produced using the XMM-ESAS software written by',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'S. L. Snowden, and written using the FITSIO package of ',
     +  STATUS)
        CALL FTPCOM(lun,'W. D. Pence.',STATUS)
        CALL FTPCOM(lun,
     +  'This is a source mask (Swiss cheese mask) created by the ',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'program make_mask_merge using a merged source list output ',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'from the SAS task merge_source_list',
     +  STATUS)
c
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 21'
            PRINT *, 'STATUS various keyword writing =', STATUS
            PRINT *, outmaskt
        ENDIF
C
C  Print the details of the output image
C
        PRINT *, 'Output image coordinate system: ', CTYP
        PRINT *, 'Output image coordinate ID: ',  
     +          CTYPE(1), '  ', CTYPE(2)
        PRINT *, 'Output image central coordinates: ',  
     +          CRVAL(1), CRVAL(2)
        PRINT *, 'Output image reference pixel: ',  
     +          CRPIX(1), CRPIX(2)
        PRINT *, 'Output image pixel sizes: ', 
     +          CDELT(1), CDELT(2)
c        PRINT *, 'Output image rotation angle: ', CROT
        PRINT *, 'Output image NAXES, NAXIS: ', NAXIS, 
     +          (NAXES(I),I=1,NAXIS)
C
C  Define the file format
C
        CALL FTPDEF(lun,BITPIX,NAXIS,NAXES,PCOUNT,GCOUNT,
     +              EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 22'
            PRINT *, 'STATUS FTPDEF =', STATUS
            PRINT *, outmaskt
        ENDIF
C
C  Write the file
C
        CALL FTP2DJ(lun,GROUP,NAXES(1),NAXES(1),NAXES(2),
     +          maskt,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 23'
            PRINT *, 'STATUS FTP2DJ =', STATUS
            PRINT *, outmaskt
        ENDIF
C
C  Close the file
C
        CALL FTCLOS(lun,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 24'
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, outmaskt
        ENDIF
c
c  Now process the soft band mask
c
c  Check to see if there is an existing file
c
        call ftopen (lun,outmasks,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                call ftdelt(lun,status)
            else
                print *, 'MAKE_MASK_MERGE 25'
                print *, 'Will not clobber file'
                print *, outmasks
                stop
            endif
        endif
        status = 0
C
C  Create the FITS file for the output image
C
        GROUP = 1
        BITPIX = 32
        CALL FTINIT(lun,outmasks,2880,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 26'
            PRINT *, 'STATUS FTINIT =', STATUS
            PRINT *, outmasks
        ENDIF
C
C  Set the output file header
C
        CALL FTPHPR(lun,SIMPLE,BITPIX,NAXIS,NAXES,PCOUNT,GCOUNT,
     +              EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 27'
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, outmasks
        ENDIF
C
C  Write some useful header keywords
C
        CALL FTPKYS(lun,'CONTENT','IMAGE','  ',STATUS)
        CALL FTPKYS(lun,'TELESCOP','XMM','mission name',STATUS)
        CALL FTPKYS(lun,'INSTRUME','EPIC','instrument name',STATUS)
        CALL FTPKYS(lun,'OBS_MODE','POINTING',
     +          'obs mode: POINTING,SLEW, OR SCAN',STATUS)
        CALL FTPKYS(lun,'RADECSYS','FK5',
     +          'Equatorial system reference',STATUS)
        CALL FTPKYJ(lun,'EQUINOX',2000,'Equinox',STATUS)
        CALL FTPKYD(lun,'EXPOSURE',EXPOSE,6,'Reference pixel',STATUS)
        CALL FTPKYF(lun,'BZERO',0.0,8,' ',STATUS)
        CALL FTPKYF(lun,'BSCALE',1.0,8,' ',STATUS)
        UNITS = 'counts'
        CALL FTPKYS(lun,'BUNIT',UNITS,'Units of data',STATUS)
        CALL FTPKYD(lun,'CRPIX1',CRPIX(1),8,'Reference pixel',STATUS)
        CALL FTPKYS(lun,'CTYPE1',CTYPE(1),'Projection',STATUS)
        CALL FTPKYD(lun,'CRVAL1',CRVAL(1),8,'Central longitude',STATUS)
        CALL FTPKYD(lun,'CDELT1',CDELT(1),8,'Pixel size',STATUS)
        CALL FTPKYS(lun,'CUNIT1','deg','Units of coordinate',STATUS)
C
        CALL FTPKYD(lun,'CRPIX2',CRPIX(2),8,'Reference pixel',STATUS)
        CALL FTPKYS(lun,'CTYPE2',CTYPE(2),'Projection',STATUS)
        CALL FTPKYD(lun,'CRVAL2',CRVAL(2),8,'Central latitude',STATUS)
        CALL FTPKYD(lun,'CDELT2',CDELT(2),8,'Pixel size',STATUS)
        CALL FTPKYS(lun,'CUNIT2','deg','Units of coordinate',STATUS)
C
        CALL FTPCOM(lun,
     +  'This file was produced using the XMM-ESAS software written by',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'S. L. Snowden, and written using the FITSIO package of ',
     +  STATUS)
        CALL FTPCOM(lun,'W. D. Pence.',STATUS)
        CALL FTPCOM(lun,
     +  'This is a source mask (Swiss cheese mask) created by the ',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'program make_mask_merge using a merged source list output ',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'from the SAS task merge_source_list',
     +  STATUS)
c
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 28'
            PRINT *, 'STATUS various keyword writing =', STATUS
            PRINT *, outmasks
        ENDIF
C
C  Print the details of the output image
C
        PRINT *, 'Output image coordinate system: ', CTYP
        PRINT *, 'Output image coordinate ID: ',  
     +          CTYPE(1), '  ', CTYPE(2)
        PRINT *, 'Output image central coordinates: ',  
     +          CRVAL(1), CRVAL(2)
        PRINT *, 'Output image reference pixel: ',  
     +          CRPIX(1), CRPIX(2)
        PRINT *, 'Output image pixel sizes: ', 
     +          CDELT(1), CDELT(2)
c        PRINT *, 'Output image rotation angle: ', CROT
        PRINT *, 'Output image NAXES, NAXIS: ', NAXIS, 
     +          (NAXES(I),I=1,NAXIS)
C
C  Define the file format
C
        CALL FTPDEF(lun,BITPIX,NAXIS,NAXES,PCOUNT,GCOUNT,
     +              EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 29'
            PRINT *, 'STATUS FTPDEF =', STATUS
            PRINT *, outmasks
        ENDIF
C
C  Write the file
C
        CALL FTP2DJ(lun,GROUP,NAXES(1),NAXES(1),NAXES(2),
     +          masks,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 30'
            PRINT *, 'STATUS FTP2DJ =', STATUS
            PRINT *, outmasks
        ENDIF
C
C  Close the file
C
        CALL FTCLOS(lun,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 31'
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, outmasks
        ENDIF
c
c  Now do the hard band
c
c  Check to see if there is an existing file
c
        call ftopen (lun,outmaskh,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                call ftdelt(lun,status)
            else
                print *, 'MAKE_MASK_MERGE 32'
                print *, 'Will not clobber file'
                print *, outmaskh
                stop
            endif
        endif
        status = 0
C
C  Create the FITS file for the output image
C
        GROUP = 1
        BITPIX = 32
        CALL FTINIT(lun,outmaskh,2880,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 33'
            PRINT *, 'STATUS FTINIT =', STATUS
            PRINT *, outmaskh
        ENDIF
C
C  Set the output file header
C
        CALL FTPHPR(lun,SIMPLE,BITPIX,NAXIS,NAXES,PCOUNT,GCOUNT,
     +              EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 34'
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, outmaskh
        ENDIF
C
C  Write some useful header keywords
C
        CALL FTPKYS(lun,'CONTENT','IMAGE','  ',STATUS)
        CALL FTPKYS(lun,'TELESCOP','XMM','mission name',STATUS)
        CALL FTPKYS(lun,'INSTRUME','EPIC','instrument name',STATUS)
        CALL FTPKYS(lun,'OBS_MODE','POINTING',
     +          'obs mode: POINTING,SLEW, OR SCAN',STATUS)
        CALL FTPKYS(lun,'RADECSYS','FK5',
     +          'Equatorial system reference',STATUS)
        CALL FTPKYJ(lun,'EQUINOX',2000,'Equinox',STATUS)
        CALL FTPKYD(lun,'EXPOSURE',EXPOSE,6,'Reference pixel',STATUS)
        CALL FTPKYF(lun,'BZERO',0.0,8,' ',STATUS)
        CALL FTPKYF(lun,'BSCALE',1.0,8,' ',STATUS)
        UNITS = 'counts'
        CALL FTPKYS(lun,'BUNIT',UNITS,'Units of data',STATUS)
        CALL FTPKYD(lun,'CRPIX1',CRPIX(1),8,'Reference pixel',STATUS)
        CALL FTPKYS(lun,'CTYPE1',CTYPE(1),'Projection',STATUS)
        CALL FTPKYD(lun,'CRVAL1',CRVAL(1),8,'Central longitude',STATUS)
        CALL FTPKYD(lun,'CDELT1',CDELT(1),8,'Pixel size',STATUS)
        CALL FTPKYS(lun,'CUNIT1','deg','Units of coordinate',STATUS)
C
        CALL FTPKYD(lun,'CRPIX2',CRPIX(2),8,'Reference pixel',STATUS)
        CALL FTPKYS(lun,'CTYPE2',CTYPE(2),'Projection',STATUS)
        CALL FTPKYD(lun,'CRVAL2',CRVAL(2),8,'Central latitude',STATUS)
        CALL FTPKYD(lun,'CDELT2',CDELT(2),8,'Pixel size',STATUS)
        CALL FTPKYS(lun,'CUNIT2','deg','Units of coordinate',STATUS)
C
        CALL FTPCOM(lun,
     +  'This file was produced using the XMM-ESAS software written by',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'S. L. Snowden, and written using the FITSIO package of ',
     +  STATUS)
        CALL FTPCOM(lun,'W. D. Pence.',STATUS)
        CALL FTPCOM(lun,
     +  'This is a source mask (Swiss cheese mask) created by the ',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'program make_mask_merge using a merged source list output ',
     +  STATUS)
        CALL FTPCOM(lun,
     +  'from the SAS task merge_source_list',
     +  STATUS)
c
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 35'
            PRINT *, 'STATUS various keyword writing =', STATUS
            PRINT *, outmaskh
        ENDIF
C
C  Print the details of the output image
C
        PRINT *, 'Output image coordinate system: ', CTYP
        PRINT *, 'Output image coordinate ID: ',  
     +          CTYPE(1), '  ', CTYPE(2)
        PRINT *, 'Output image central coordinates: ',  
     +          CRVAL(1), CRVAL(2)
        PRINT *, 'Output image reference pixel: ',  
     +          CRPIX(1), CRPIX(2)
        PRINT *, 'Output image pixel sizes: ', 
     +          CDELT(1), CDELT(2)
c        PRINT *, 'Output image rotation angle: ', CROT
        PRINT *, 'Output image NAXES, NAXIS: ', NAXIS, 
     +          (NAXES(I),I=1,NAXIS)
C
C  Define the file format
C
        CALL FTPDEF(lun,BITPIX,NAXIS,NAXES,PCOUNT,GCOUNT,
     +              EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 36'
            PRINT *, 'STATUS FTPDEF =', STATUS
            PRINT *, outmaskh
        ENDIF
C
C  Write the file
C
        CALL FTP2DJ(lun,GROUP,NAXES(1),NAXES(1),NAXES(2),
     +          maskh,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 36'
            PRINT *, 'STATUS FTP2DJ =', STATUS
            PRINT *, outmaskh
        ENDIF
C
C  Close the file
C
        CALL FTCLOS(lun,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'MAKE_MASK_MERGE POSITION 37'
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, outmaskh
        ENDIF
C
        return
        end subroutine make_mask_merge_sub

