         SUBROUTINE MERGE_COMP_XMM_SUB(xmmdir,dirfile,coord,crvaln,
     +       scale,compon,iel,ieh,maskcon,alpha)
C
c  SAS gvim Version 0.9.8
C  Version 4.1  22 March 2010
C
C  Merges various observations into one large mosaic
C
C  MERGE-COMP-XMM mosaics count, modeled background count, soft proton
C  count, and exposure images from multiple pointings into one image.  
C  The output projection is the zenith equal-area azimuthal, which can
C  be approximated for display purposes by using tangential-projection
C  software
C
C  INPUT:
C    xmmdir: Directory containing the ESAS calibration files
c    dirfile: Filename of directory list
C    coord: Coordinate Control:
C       1 => ecliptic
C       2 => equatorial
C       3 => galactic
C    crvaln: Central Coordinates, longitude and latitude
C    scale: Pixel Size (arc minutes)
C    compon: Component Selection
C       1 => count image
C       2 => exposure
C       3 => QPB counts
C       4 => SP counts
C       5 => SWCX counts
C       6 => Cheese masks from cheese or cheese-bands
C       7 => Cheese masks from make_mask_merge
C    iel: Lower energy limit for the energy band in eV
C    ieh: Upper energy limit for the energy band in eV
C    maskcon: Mask control
C       0 =>  No Masking
C       1 =>  Point Source Masking - Use either output from cheese or 
C             the combined band output from cheese-bands
C       11 => Point Source Masking - Use the soft band output from 
C             cheese-bands
C       12 => Point Source Masking - Use the hard band output from 
C             cheese-bands
C       2 =>  Good Area Masking
C       3 =>  Point Source Masking - Use the full band output from 
C             make-mask-merge
C       31 => Point Source Masking - Use the soft band output from 
C             make-mask-merge
C       32 => Point Source Masking - Use the hard band output from 
C             make-mask-merge
C     alpha: Spectral Scale Factor - Assumed spectrum for scaling 
C       exposure images.  1.0 < alpha < 2.4
C
C  Example: merge_comp_xmm caldb=/CalDB dirfile=dir.dat coord=2 
C                 crvaln1=194.6 crvaln2=27.7 pixelsize=0.0666667  
C                 component=1 elow=400 ehigh=750 maskcontrol=0
C                 alpha=1.7
C
C  OUTPUT:
C    Mosaicked image
C
        IMPLICIT NONE
C
        REAL ALPHA, BZERO, BSCALE, DUMMY, fscal, 
     +      INPUT(900,900), INPUTO(900,900), 
     +      MERG(2000,2000), MASK(900,900), OOTSCA, SCALE 
        DOUBLE PRECISION cdelt(2), CDELTN(2), CDELTO(2),
     +      crpix(2), CRPIXN(2), CRPIXO(2), CROTN, CROTO, CDEC, CRA,
     +      crval(2), CRVALN(2), CRVALO(2), DBIN, DBOUT, DDECCEN, 
     +      DELANG, DJUL, DLIN, DLOUT, DRACEN, DPDEC, DPRA, 
     +      DRAD, FIELD, LINN(19), PIXCRD(2), XPIXIN, YPIXIN
        INTEGER*2 INI2(900,900)
        INTEGER BITPIX, BLOCK, CLOBBER, COMPON, COORD, ERR, 
     +      GCOUNT, I, IADD, IDET, IEH, IEL, IERR, IFLAG, II, 
     +      IMED, INI4(900,900), IOS, IPIXCRD(2), IPNOBJ, ISIZE, 
     +      islow, ishigh, ISTAT, ITHICK, ITHIN, 
     +      ITOT, LUN, LUNO, MASKCON, 
     +      N, NAXES(10), NAXIS, PCOUNT, STATUS 
        CHARACTER*1  DIRSTR(80), INFI(132), INFIO(132), 
     +      COMPI(30), COMPIO(30), MASKI(30), OUTFI(30)
        CHARACTER*4  FILT, CTYPN, CTYPO
        CHARACTER*8  FILTER, UNITS, CTYPEN(2), CTYPEO(2)
        character*8  ctype(2)
        CHARACTER*25 SUBMODE
        CHARACTER*30 COMP, COMPO, MASKNA
        CHARACTER*60 COM, COMMENT
        CHARACTER*80 DIR, xmmdir
        CHARACTER*132 dirfile, INFILE, INFILEO, outfile
        LOGICAL ANYF, EXTEND, NOMASK, SIMPLE
C
        EQUIVALENCE (COMP,COMPI)
        EQUIVALENCE (COMPO,COMPIO)
        EQUIVALENCE (DIR,DIRSTR)
        EQUIVALENCE (FILT,FILTER)
        EQUIVALENCE (INFILE,INFI)
        EQUIVALENCE (INFILEO,INFIO)
        EQUIVALENCE (MASKNA,MASKI)
        EQUIVALENCE (OUTFILE,OUTFI)
C
        DATA CLOBBER /1/
        DATA DRAD /3.141592654D0/
        DATA ERR /0/
        DATA IPNOBJ /0/
        DATA OUTFILE /'  '/
        DATA STATUS /0/
        DATA MASKNA /'-cheese.fits'/
        DATA INFILE /'  '/
        DATA INFILEO /'  '/
        DATA ITHIN, IMED, ITHICK /0, 0, 0/
c
        DRAD = DRAD/180.D0
c
c  Get an unused lun
c
        call ftgiou(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'MERGE_COMP_XMM POSITION 01'
            print *, 'STATUS FTGIOU =', status
            stop
        endif
C
        call ftgiou(luno,status)
        if(status .ne. 0) then
            print *, 'MERGE-COMP-XMM POSITION 02'
            print *, 'STATUS FTGIOU =', status
        endif
c
c  List the program control parameters.
c
        print *, 'Assumed Spectral Index: ', alpha
        print *, 'Directory File: ', dirfile
        PRINT *, 'Coord System', COORD
        IF(COORD .EQ. 1) THEN
            CTYPEN(1) = 'ELON-TAN'
            CTYPEN(2) = 'ELAT-TAN'
        ELSEIF(COORD .EQ. 2) THEN
            CTYPEN(1) = 'RA---TAN'
            CTYPEN(2) = 'DEC--TAN'
        ELSEIF(COORD .EQ. 3) THEN
            CTYPEN(1) = 'GLON-TAN'
            CTYPEN(2) = 'GLAT-TAN'
        ENDIF
        CTYPN = '-TAN'
        print *, 'Central Coords: ', crvaln(1),crvaln(2)
        IF(COORD .EQ. 1) THEN
            DLIN = DRAD*CRVALN(1)
            DBIN = DRAD*CRVALN(2)
            CALL EQUECL(DJUL,.FALSE.,.FALSE.,
     +              DLIN,DBIN,DLOUT,DBOUT,ISTAT)
            IF(ISTAT .NE. 0) THEN
                print*, 'MERGE_COMP_XMM POSITION 07'
                print*,'MERGE_COMP_XMM: Error on return ',
     +                  'from EQUECL'
                print*,'ISTAT =', ISTAT
                IERR = 3
            ELSE
                DRACEN = DLOUT/DRAD
                DDECCEN = DBOUT/DRAD
            ENDIF
C
C  Leave in equatorial coordinates
C
        ELSEIF(COORD .EQ. 2) THEN
            DRACEN = CRVALN(1)
            DDECCEN = CRVALN(2)
C
C  Transform from galactic to equatorial coordinates
C
        ELSEIF(COORD .EQ. 3) THEN
            DLIN = DRAD*CRVALN(1)
            DBIN = DRAD*CRVALN(2)
            CALL EQUGAL(DJUL,.FALSE.,DLIN,DBIN,DLOUT,DBOUT,ISTAT)
            IF(ISTAT .NE. 0) THEN
                print*,'MERGE_COMP_XMM POSITION 08'
                print*,'MERGE_COMP_XMM: Error on return ',
     +                  'from EQUGAL'
                IERR = 3
            ELSE
                DRACEN = DLOUT/DRAD
                DDECCEN = DBOUT/DRAD
            ENDIF
        ENDIF
        DRACEN = DRAD*DRACEN
        DDECCEN = DRAD*DDECCEN
C
C Create output file name
C
        IF(COMPON .EQ. 1) THEN
            IF(IEL .GE. 1000) THEN
                IF(IEH .GE. 10000) THEN
                    WRITE(COMP,3105) IEL, IEH
 3105               FORMAT('obj-im-',I4,'-',I5,'.fits')
                ELSE
                    WRITE(COMP,3115) IEL, IEH
 3115               FORMAT('obj-im-',I4,'-',I4,'.fits')
                ENDIF
            ELSEIF(IEH .LT. 1000) THEN
                WRITE(COMP,3125) IEL, IEH
 3125           FORMAT('obj-im-',I3,'-',I3,'.fits')
            ELSEIF(IEH .GE. 10000) THEN
                WRITE(COMP,3135) IEL, IEH
 3135           FORMAT('obj-im-',I3,'-',I5,'.fits')
            ELSE
                WRITE(COMP,3145) IEL, IEH
 3145           FORMAT('obj-im-',I3,'-',I4,'.fits')
            ENDIF
        ELSEIF(COMPON .EQ. 2) THEN
            IF(IEL .GE. 1000) THEN
                IF(IEH .GE. 10000) THEN
                    WRITE(COMP,3205) IEL, IEH
 3205               FORMAT('exp-im-',I4,'-',I5,'.fits')
                ELSE
                    WRITE(COMP,3215) IEL, IEH
 3215               FORMAT('exp-im-',I4,'-',I4,'.fits')
                ENDIF
            ELSEIF(IEH .LT. 1000) THEN
                WRITE(COMP,3225) IEL, IEH
 3225           FORMAT('exp-im-',I3,'-',I3,'.fits')
            ELSEIF(IEH .GE. 10000) THEN
                WRITE(COMP,3235) IEL, IEH
 3235           FORMAT('exp-im-',I3,'-',I5,'.fits')
            ELSE
                WRITE(COMP,3245) IEL, IEH
 3245           FORMAT('exp-im-',I3,'-',I4,'.fits')
            ENDIF
        ELSEIF(COMPON .EQ. 3) THEN
            IF(IEL .GE. 1000) THEN
                IF(IEH .GE. 10000) THEN
                    WRITE(COMP,3305) IEL, IEH
 3305               FORMAT('back-im-',I4,'-',I5,'.fits')
                ELSE
                    WRITE(COMP,3315) IEL, IEH
 3315               FORMAT('back-im-',I4,'-',I4,'.fits')
                ENDIF
            ELSEIF(IEH .LT. 1000) THEN
                WRITE(COMP,3325) IEL, IEH
 3325           FORMAT('back-im-',I3,'-',I3,'.fits')
           ELSEIF(IEH .GE. 10000) THEN
                WRITE(COMP,3335) IEL, IEH
 3335           FORMAT('back-im-',I3,'-',I5,'.fits')
            ELSE
                WRITE(COMP,3345) IEL, IEH
 3345           FORMAT('back-im-',I3,'-',I4,'.fits')
            ENDIF
        ELSEIF(COMPON .EQ. 4) THEN
            IF(IEL .GE. 1000) THEN
                IF(IEH .GE. 10000) THEN
                    WRITE(COMP,3405) IEL, IEH
 3405               FORMAT('prot-im-',I4,'-',I5,'.fits')
                ELSE
                    WRITE(COMP,3415) IEL, IEH
 3415               FORMAT('prot-im-',I4,'-',I4,'.fits')
                ENDIF
            ELSEIF(IEH .LT. 1000) THEN
                WRITE(COMP,3425) IEL, IEH
 3425           FORMAT('prot-im-',I3,'-',I3,'.fits')
            ELSEIF(IEH .GE. 10000) THEN
                WRITE(COMP,3435) IEL, IEH
 3435           FORMAT('prot-im-',I3,'-',I5,'.fits')
            ELSE
                WRITE(COMP,3445) IEL, IEH
 3445           FORMAT('prot-im-',I3,'-',I4,'.fits')
            ENDIF
        ELSEIF(COMPON .EQ. 5) THEN
            IF(IEL .GE. 1000) THEN
                IF(IEH .GE. 10000) THEN
                    WRITE(COMP,3505) IEL, IEH
 3505               FORMAT('swcx-im-',I4,'-',I5,'.fits')
                ELSE
                    WRITE(COMP,3515) IEL, IEH
 3515               FORMAT('swcx-im-',I4,'-',I4,'.fits')
                ENDIF
            ELSEIF(IEH .LT. 1000) THEN
                WRITE(COMP,3525) IEL, IEH
 3525           FORMAT('swcx-im-',I3,'-',I3,'.fits')
            ELSEIF(IEH .GE. 10000) THEN
                WRITE(COMP,3535) IEL, IEH
 3535           FORMAT('swcx-im-',I3,'-',I5,'.fits')
            ELSE
                WRITE(COMP,3545) IEL, IEH
 3545           FORMAT('swcx-im-',I3,'-',I4,'.fits')
            ENDIF
        ELSEIF(COMPON .EQ. 6) THEN
            IF(IEL .GE. 1500) THEN
                COMP = 'cheese-im-h.fits'
            ELSEIF(IEH .LT. 1500) THEN
                COMP = 'cheese-im-s.fits'
            ELSE
                COMP = 'cheese-im.fits'
            ENDIF
        ELSEIF(COMPON .EQ. 7) THEN
            IF(IEL .GE. 1500) THEN
                COMP = 'msl-cheese-im-h.fits'
            ELSEIF(IEH .LT. 1500) THEN
                COMP = 'msl-cheese-im-s.fits'
            ELSE
                COMP = 'msl-cheese-im.fits'
            ENDIF 
        ENDIF
        OUTFILE = COMP
        print *, 'OUTFILE: ', outfile
C
C  Set the maximum separation for a pointing to still 
C  possibly be in the image
C
        FIELD = 0.0174533D0*(1.42*SCALE*2000.0/2.0 + 15.0)/60.0
C
        LINN(1) = 0.0D0
        LINN(2) = 2.0D0
        LINN(3) = 2.0D0
        CRPIXN(1) = 1000.5
        CRPIXN(2) = 1000.5
        CDELTN(1) = -SCALE/60.0
        CDELTN(2) = SCALE/60.0
        CROTN = 0.0
        PRINT *, 'Merged image coordinate system: ', CTYPN
        PRINT *, 'Merged image coordinate ID: ', 
     +                  CTYPEN(1), '  ', CTYPEN(2)
        PRINT *, 'Merged image central coordinates: ', 
     +                  CRVALN(1), CRVALN(2)
        PRINT *, 'Merged image reference pixel: ', 
     +                  CRPIXN(1), CRPIXN(2)
        PRINT *, 'Merged image pixel sizes: ', 
     +                  CDELTN(1), CDELTN(2)
        PRINT *, 'Merged image rotation angle: ', CROTN
C        PRINT *, 'Merged image NAXES, NAXIS: ', NAXIS, 
C     +              (NAXES(I),I=1,NAXIS)
c
        PRINT *, 'Cast Component = ', COMPON
        PRINT *, 'Energy Range = ', IEL, IEH
c
c  Set the band
c
        islow = (iel + 25)/50
        ishigh = (ieh + 25)/50
C
        PRINT *, 'Masking Control: ', maskcon
C
        IADD = 0
 1000   FORMAT(A80)
        OPEN(UNIT=77,STATUS='OLD',FORM='FORMATTED',FILE=dirfile)
        IOS = 0
        DO WHILE (IOS .EQ. 0)
            READ(77,1020,IOSTAT=IOS) DIR
 1020       FORMAT(A80)
            IF(IOS .EQ. 0) THEN
                IPNOBJ = 0
                PRINT *, ' '
                PRINT *, 'ADD NEW ARRAY'
                PRINT *, DIR
C
C  Set the input file name
C
                DO I=1,110
                    INFI(I) = ' '
                    INFIO(I) = ' '
                ENDDO
                I = 1
C
                DO WHILE (DIRSTR(I) .NE. ' ')
                    INFI(I) = DIRSTR(I)
                    INFIO(I) = DIRSTR(I)
                    I = I + 1
                ENDDO
                N = I - 1
                IF(DIRSTR(N-5) .EQ. 's') THEN
                    READ(DIRSTR(N-4),3900) IDET
 3900               FORMAT(I1)
                ELSEIF(DIRSTR(N-5) .EQ. 'p') THEN
                    IDET = 3
                ENDIF
C
                IF(COMPON .EQ. 1) THEN
                    IF(IEL .GE. 1000) THEN
                        IF(IEH .GE. 10000) THEN
                            WRITE(COMP,3100) IEL, IEH
 3100                       FORMAT('-obj-im-',I4,'-',I5,'.fits')
                        ELSE
                            WRITE(COMP,3110) IEL, IEH
 3110                       FORMAT('-obj-im-',I4,'-',I4,'.fits')
                        ENDIF
                    ELSEIF(IEH .LT. 1000) THEN
                        WRITE(COMP,3120) IEL, IEH
 3120                   FORMAT('-obj-im-',I3,'-',I3,'.fits')
                    ELSEIF(IEH .GE. 10000) THEN
                        WRITE(COMP,3130) IEL, IEH
 3130                   FORMAT('-obj-im-',I3,'-',I5,'.fits')
                    ELSE
                        WRITE(COMP,3140) IEL, IEH
 3140                   FORMAT('-obj-im-',I3,'-',I4,'.fits')
                    ENDIF
                    IF(IDET .EQ. 3) THEN
                        IPNOBJ = 1
                        IF(IEL .GE. 1000) THEN
                            IF(IEH .GE. 10000) THEN
                                WRITE(COMPO,3102) IEL, IEH
 3102                           FORMAT('-obj-im-',I4,'-',I5,'-oot.fits')
                            ELSE
                                WRITE(COMPO,3112) IEL, IEH
 3112                           FORMAT('-obj-im-',I4,'-',I4,'-oot.fits')
                            ENDIF
                        ELSEIF(IEH .LT. 1000) THEN
                            WRITE(COMPO,3122) IEL, IEH
 3122                       FORMAT('-obj-im-',I3,'-',I3,'-oot.fits')
                        ELSEIF(IEH .GE. 10000) THEN
                            WRITE(COMPO,3132) IEL, IEH
 3132                       FORMAT('-obj-im-',I3,'-',I5,'-oot.fits')
                        ELSE
                            WRITE(COMPO,3142) IEL, IEH
 3142                       FORMAT('-obj-im-',I3,'-',I4,'-oot.fits')
                        ENDIF
                    ENDIF
                ELSEIF(COMPON .EQ. 2) THEN
                    IF(IEL .GE. 1000) THEN
                        IF(IEH .GE. 10000) THEN
                            WRITE(COMP,3200) IEL, IEH
 3200                       FORMAT('-exp-im-',I4,'-',I5,'.fits')
                        ELSE
                            WRITE(COMP,3210) IEL, IEH
 3210                       FORMAT('-exp-im-',I4,'-',I4,'.fits')
                        ENDIF
                    ELSEIF(IEH .LT. 1000) THEN
                        WRITE(COMP,3220) IEL, IEH
 3220                   FORMAT('-exp-im-',I3,'-',I3,'.fits')
                    ELSEIF(IEH .GE. 10000) THEN
                        WRITE(COMP,3230) IEL, IEH
 3230                   FORMAT('-exp-im-',I3,'-',I5,'.fits')
                    ELSE
                        WRITE(COMP,3240) IEL, IEH
 3240                   FORMAT('-exp-im-',I3,'-',I4,'.fits')
                    ENDIF
                ELSEIF(COMPON .EQ. 3) THEN
                    IF(IEL .GE. 1000) THEN
                        IF(IEH .GE. 10000) THEN
                            WRITE(COMP,3300) IEL, IEH
 3300                       FORMAT('-back-im-sky-',I4,'-',I5,'.fits')
                        ELSE
                            WRITE(COMP,3310) IEL, IEH
 3310                       FORMAT('-back-im-sky-',I4,'-',I4,'.fits')
                        ENDIF
                    ELSEIF(IEH .LT. 1000) THEN
                        WRITE(COMP,3320) IEL, IEH
 3320                   FORMAT('-back-im-sky-',I3,'-',I3,'.fits')
                    ELSEIF(IEH .GE. 10000) THEN
                        WRITE(COMP,3330) IEL, IEH
 3330                   FORMAT('-back-im-sky-',I3,'-',I5,'.fits')
                    ELSE
                        WRITE(COMP,3340) IEL, IEH
 3340                   FORMAT('-back-im-sky-',I3,'-',I4,'.fits')
                    ENDIF
                ELSEIF(COMPON .EQ. 4) THEN
                    IF(IEL .GE. 1000) THEN
                        IF(IEH .GE. 10000) THEN
                            WRITE(COMP,3400) IEL, IEH
 3400                       FORMAT('-prot-im-sky-',I4,'-',I5,'.fits')
                        ELSE
                            WRITE(COMP,3410) IEL, IEH
 3410                       FORMAT('-prot-im-sky-',I4,'-',I4,'.fits')
                        ENDIF
                    ELSEIF(IEH .LT. 1000) THEN
                        WRITE(COMP,3420) IEL, IEH
 3420                   FORMAT('-prot-im-sky-',I3,'-',I3,'.fits')
                    ELSEIF(IEH .GE. 10000) THEN
                        WRITE(COMP,3430) IEL, IEH
 3430                   FORMAT('-prot-im-sky-',I3,'-',I5,'.fits')
                    ELSE
                        WRITE(COMP,3440) IEL, IEH
 3440                   FORMAT('-prot-im-sky-',I3,'-',I4,'.fits')
                    ENDIF
                ELSEIF(COMPON .EQ. 5) THEN
                    IF(IEL .GE. 1500) THEN
                        COMP = '-cheese-h.fits'
                    ELSEIF(IEH .LT. 1500) THEN
                        COMP = '-cheese-s.fits'
                    ELSE
                        COMP = '-cheese.fits'
                    ENDIF
                ELSEIF(COMPON .EQ. 6) THEN
                    IF(IEL .GE. 1500) THEN
                        COMP = '-msl-cheese-h.fits'
                    ELSEIF(IEH .LT. 1500) THEN
                        COMP = '-msl-cheese-s.fits'
                    ELSE
                        COMP = '-msl-cheese.fits'
                    ENDIF 
                ENDIF
C
                DO I=1,30
                    INFI(N+I) = COMPI(I)
                ENDDO
                PRINT *, INFILE
                IF(IPNOBJ .EQ. 1) THEN
                    DO I=1,30
                        INFIO(N+I) = COMPIO(I)
                    ENDDO
                    PRINT *, INFILEO
                ENDIF
C
C  Open the FITS file for the component
C
                CALL FTOPEN(LUN,INFILE,0,BLOCK,STATUS)
                IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                    ERR = 1
                    PRINT *, 'MERGE-COMP-XMM POSITION 09'
                    PRINT *, 'STATUS FTOPEN =', STATUS
                    PRINT *, INFILE
                ENDIF
                PRINT *, 'Input image: ', INFILE
C
C  Read the FITS file header information
C
                CALL FTGHPR (LUN,10,SIMPLE,BITPIX,NAXIS,NAXES,
     +                      PCOUNT,GCOUNT,EXTEND,STATUS)
                IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                    ERR = 1
                    PRINT *, 'MERGE-COMP-XMM POSITION 10'
                    PRINT *, 'STATUS FTGHPR =', STATUS
                    PRINT *, INFILE
                ENDIF
C
C  Get the useful keywords
C
                CALL FTGICS (LUN,CRVALO(1),CRVALO(2),
     +                  CRPIXO(1),CRPIXO(2),
     +                  CDELTO(1),CDELTO(2),CROTO,CTYPO,STATUS)
                IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                    ERR = 1
                    PRINT *, 'MERGE-COMP-XMM POSITION 11'
                    PRINT *, 'STATUS FTGICS =', STATUS
                    PRINT *, INFILE
                ENDIF
C
C  And a few more
C
                CALL FTGKYS (LUN,'CTYPE1',CTYPEO(1),COM,STATUS)
                IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                    ERR = 1
                    PRINT *, 'MERGE-COMP-XMM POSITION 12'
                    PRINT *, 'STATUS FTGKYS =', STATUS
                    PRINT *, INFILE
                ENDIF
                CALL FTGKYS (LUN,'CTYPE2',CTYPEO(2),COM,STATUS)
                IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                    ERR = 1
                    PRINT *, 'MERGE-COMP-XMM POSITION 13'
                    PRINT *, 'STATUS FTGKYS =', STATUS
                    PRINT *, INFILE
                ENDIF
C
C  Test to see how far the pointing is from the center of the mosaic
C
                DPRA = DRAD*CRVALO(1)
                DPDEC = DRAD*CRVALO(2)
C
                CALL ANGSEP(DRACEN,DDECCEN,DPRA,DPDEC,DELANG,IERR)
                IF(DELANG .LT. FIELD) THEN
C
C  Set the scale factor for the filter
C
                    fscal = 1.0
                    IF(COMPON .EQ. 2) THEN
                        CALL FTGKYS (LUN,'FILTER',FILTER,COM,STATUS)
                        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                            ERR = 1
                            PRINT *, 'MERGE-COMP-XMM POSITION 14'
                            PRINT *, 'STATUS FTGKYS =', STATUS
                            PRINT *, INFILE
                        ENDIF
                        ITOT = ITOT + 1
c
                        print *, 'Detector and Filter: ', idet, 
     +                      '  ', filt
                        call hard_scale (xmmdir,alpha,idet,
     +                          filt,islow,ishigh,fscal)
                        if(filt .eq. 'Thin') then
                            ithin = ithin + 1
                        elseif(filt .eq. 'Medi') then
                            imed = imed + 1
                        elseif(filt .eq. 'Thic') then
                            ithick = ithick + 1
                        endif
                    endif
                    print *, 'Filter scale factor: ', fscal
C
C  Print the central coords of the observation
C
                    PRINT *, 'Status: ', STATUS
                    PRINT *, 'Original image coordinate system: ', 
     +                      CTYPO
                    PRINT *, 'Original image coordinate ID: ', 
     +                      CTYPEO(1), '  ', CTYPEO(2)
                    PRINT *, 'Original image central coordinates: ', 
     +                      CRVALO(1), CRVALO(2)
                    PRINT *, 'Original image reference pixel: ', 
     +                      CRPIXO(1), CRPIXO(2)
                    PRINT *, 'Original image pixel sizes: ', 
     +                      CDELTO(1), CDELTO(2)
                    PRINT *, 'Original image rotation angle: ', CROTO
                    PRINT *, 'Original image NAXES, NAXIS: ', NAXIS, 
     +                  (NAXES(I),I=1,NAXIS)
C
C  Read in the X-ray image
C
                    CALL FTG2DE (LUN,0,0,NAXES(1),NAXES(1),NAXES(2),
     +                  INPUT,ANYF,STATUS)
                    IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                        ERR = 1
                        PRINT *, 'MERGE-COMP-XMM POSITION 15'
                        PRINT *, 'STATUS FTG2DE =', STATUS
                        PRINT *, INFILE
                    ENDIF
C
C  Close the FITS file
C
                    CALL FTCLOS(LUN,STATUS)
                    IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                        ERR = 1
                        PRINT *, 'MERGE-COMP-XMM POSITION 16'
                        PRINT *, 'STATUS FTCLOS =', STATUS
                        PRINT *, INFILE
                    ENDIF
C
C  Read in the OOT event file if pn data
C
                    IF(IPNOBJ .EQ. 1) THEN
                        CALL FTOPEN(LUNO,INFILEO,0,BLOCK,STATUS)
                        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                            ERR = 1
                            PRINT *, 'MERGE-COMP-XMM POSITION 17'
                            PRINT *, 'STATUS FTOPEN =', STATUS
                            PRINT *, INFILEO
                        ENDIF
                        PRINT *, 'Input image: ', INFILEO
C
C  Read the FITS file header information
C
                        CALL FTGHPR (LUNO,10,SIMPLE,BITPIX,NAXIS,NAXES,
     +                          PCOUNT,GCOUNT,EXTEND,STATUS)
                        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                            ERR = 1
                            PRINT *, 'MERGE-COMP-XMM POSITION 18'
                            PRINT *, 'STATUS FTGHPR =', STATUS
                            PRINT *, INFILEO
                        ENDIF
C
C  Get the SUBMODE keyword
C
                        CALL FTGKYS (LUNO,'SUBMODE',SUBMODE,COM,STATUS)
                        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                            ERR = 1
                            PRINT *, 'MERGE-COMP-XMM POSITION 19'
                            PRINT *, 'STATUS FTGKYS =', STATUS
                            PRINT *, INFILEO
                        ENDIF
                        IF(SUBMODE .EQ. 'PrimeFullWindow') 
     +                          OOTSCA = 0.063
                        IF(SUBMODE .EQ. 'PrimeFullWindowExtended') 
     +                          OOTSCA = 0.023
                        IF(SUBMODE .EQ. 'PrimeFullWindowExtended5') 
     +                          OOTSCA = 0.013
                        PRINT *, 'SUBMODE, OOT scale factor: ', 
     +                          SUBMODE, OOTSCA
C
C  Read in the X-ray image
C
                        CALL FTG2DE (LUNO,0,0,NAXES(1),NAXES(1),
     +                      NAXES(2),INPUTO,ANYF,STATUS)
                        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                            ERR = 1
                            PRINT *, 'MERGE-COMP-XMM POSITION 20'
                            PRINT *, 'STATUS FTG2DE =', STATUS
                            PRINT *, INFILEO
                        ENDIF
C
C  Close the FITS file
C
                        CALL FTCLOS(LUNO,STATUS)
                        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                            ERR = 1
                            PRINT *, 'MERGE-COMP-XMM POSITION 21'
                            PRINT *, 'STATUS FTCLOS =', STATUS
                            PRINT *, INFILEO
                        ENDIF
C
C  Combine the data
C
                        DO I=1,900
                            DO Ii=1,900
                                INPUT(I,II) = INPUT(I,II) - 
     +                                   OOTSCA*INPUTO(I,II) 
                            ENDDO
                        ENDDO
                        IPNOBJ = 0
                    ENDIF
C
C  Read in point source masks to go with the observation
C
                    if((maskcon .eq. 1) .or. (maskcon .eq. 11) .or.  
     +                      (maskcon .eq. 12)) then
                        if(maskcon .eq. 1) then
                            maskna = '-cheese.fits'
                        elseif(maskcon .eq. 11) then
                            maskna = '-cheese-s.fits'
                        elseif(maskcon .eq. 12) then
                            maskna = '-cheese-h.fits'
                        endif
c
                        do i=1,30
                            infi(n+i) = maski(i)
                        enddo
                        print *, infile
                        call retfit(infile,mask,ini2,
     +                          ini4,1,900,900,ctype,crval,
     +                          cdelt,crpix,status)
                        if((status .ne. 0) .and. (err .eq. 0)) then
                            err = 1
                            print *, 'MERGE-COMP-XMM POSITION 22'
                            print *, 'STATUS RETFIT =', status
                            print *, 'Missing a cheese mask'
                            print *, infile
                           stop
                        endif
                        nomask = .FALSE.
c
c  Read in good area masks
c
                    elseif(maskcon .eq. 2) then
                        if(iel .ge. 1000) then
                            write(maskna,3610) iel, ieh
 3610                       format('-mask-im-',i4,'-',i4,'.fits')
                        elseif(ieh .lt. 1000) then
                            write(maskna,3620) iel, ieh
 3620                       format('-mask-im-',i3,'-',i3,'.fits')
                        else
                            write(maskna,3630) iel, ieh
 3630                       format('-mask-im-',i3,'-',i4,'.fits')
                        endif
                        do i=1,30
                            infi(n+i) = maski(i)
                        enddo
                        print *, infile
                        call retfit(infile,mask,ini2,
     +                          ini4,1,900,900,ctype,crval,
     +                          cdelt,crpix,status)
                        if((status .ne. 0) .and. (err .eq. 0)) then
                            err = 1
                            print *, 'MERGE-COMP-XMM POSITION 23'
                            print *, 'STATUS RETFIT =', status
                            print *, 'Missing a normal mask'
                            print *, infile
                           stop
                        endif
                        nomask = .FALSE.
c
c  Read in the merged source list masks
c
                    elseif((maskcon .eq. 3) .or. (maskcon .eq. 31) 
     +                      .or. (maskcon .eq. 32)) then
                        if(maskcon .eq. 3) then
                            maskna = '-msl-cheese.fits'
                        elseif(maskcon .eq. 31) then
                            maskna = '-msl-cheese-s.fits'
                        elseif(maskcon .eq. 32) then
                            maskna = '-msl-cheese-h.fits'
                        endif
                        do i=1,30
                            infi(n+i) = maski(i)
                        enddo
                        print *, infile
                        call retfit(infile,mask,ini2,
     +                          ini4,1,900,900,ctype,crval,
     +                          cdelt,crpix,status)
                        if((status .ne. 0) .and. (err .eq. 0)) then
                            err = 1
                            print *, 'MERGE-COMP-XMM POSITION 24'
                            print *, 'STATUS RETFIT =', status
                            print *, 'Missing a merged mask'
                            print *, infile
                           stop
                        endif
                        nomask = .FALSE.
                    else

c
c  Make full-field masks
c
                        do i=1,900
                            do ii=1,900
                                mask(i,ii) = 1.0
                            enddo
                        enddo
                        nomask = .TRUE.
                    endif
C
C The coords are year 2000
C
                    DJUL = 2451544.5D0
C
C  Cast the new observation into the mosaic
C
                    DO I=1,900
                        XPIXIN = I
                        DO II=1,900
                            YPIXIN = II
                            IF((INPUT(I,II) .NE. 0.0) .AND.
     +                              (MASK(I,II) .GT. 0)) THEN
                                CALL FTWLDP (XPIXIN,YPIXIN,CRVALO(1),
     +                              CRVALO(2),CRPIXO(1),CRPIXO(2),
     +                              CDELTO(1),CDELTO(2),CROTO,
     +                              CTYPO,CRA,CDEC,STATUS)
c       print *, XPIXIN,YPIXIN,CRVALO(1),
c     +                              CRVALO(2),CRPIXO(1),CRPIXO(2),
c     +                              CDELTO(1),CDELTO(2),CROTO,
c     +                              CTYPO,CRA,CDEC,STATUS
                                IF((STATUS .NE. 0) .AND. 
     +                                  (ERR .EQ. 0)) THEN
                                    ERR = 1
                                    PRINT *, 
     +                                    'MERGE-COMP-XMM POSITION 25'
                                    PRINT *, 'STATUS FTWLDP =', STATUS
                                    PRINT *, INFILE
                                ENDIF
C
C  Transform from equatorial to ecliptic coordinates
C
                                IF(COORD .EQ. 1) THEN
                                    DLIN = DRAD*CRA
                                    DBIN = DRAD*CDEC
                                    CALL EQUECL(DJUL,.FALSE.,.TRUE.,
     +                                   DLIN,DBIN,DLOUT,DBOUT,ISTAT)
                                    IF(ISTAT .NE. 0) THEN
                                        PRINT *, 
     +                                    'MERGE-COMP-XMM POSITION 26'
                                        print *, 'ISTAT =', ISTAT
                                        print *, 'Error on return ',
     +                                      'from EQUECL'
                                        IERR = 3
                                    ELSE
                                        CRA = DLOUT/DRAD
                                        CDEC = DBOUT/DRAD
                                    ENDIF
C
C  Leave in equatorial coordinates
C
                                ELSEIF(COORD .EQ. 2) THEN
                                    CONTINUE
C
C  Transform from equatorial to galactic coordinates
C
                                ELSEIF(COORD .EQ. 3) THEN
                                    DLIN = DRAD*CRA
                                    DBIN = DRAD*CDEC
                                    CALL EQUGAL(DJUL,.TRUE.,DLIN,
     +                                      DBIN,DLOUT,DBOUT,ISTAT)
                                    IF(ISTAT .NE. 0) THEN
                                        print *, 
     +                                    'MERGE-COMP-XMM POSITION 27'
                                        print *, 'Error on return ',
     +                                      'from EQUGAL'
                                        IERR = 3
                                    ELSE
                                        CRA = DLOUT/DRAD
                                        CDEC = DBOUT/DRAD
                                    ENDIF
                                ENDIF
C
C  Transform into the merged system
C
                                CALL FTXYPX (CRA,CDEC,CRVALN(1),
     +                              CRVALN(2),CRPIXN(1),CRPIXN(2),
     +                              CDELTN(1),CDELTN(2),CROTN,CTYPN,
     +                              PIXCRD(1),PIXCRD(2),STATUS)
c                                PRINT *, CRVALN(1),CRVALN(2),
c     +                              CRPIXN(1),CRPIXN(2),
c     +                              CDELTN(1),CDELTN(2),CROTN,CTYPN,
c     +                              PIXCRD(1),PIXCRD(2),STATUS
c        stop
                                IPIXCRD(1) = NINT(PIXCRD(1))
                                IPIXCRD(2) = NINT(PIXCRD(2))
                                IF((STATUS .NE. 0) .AND. 
     +                                  (ERR .EQ. 0)) THEN
                                    ERR = 1
                                    PRINT *, 
     +                                  'MERGE-COMP-XMM POSITION 28'
                                    PRINT *, 'STATUS FTXYPX =', STATUS
                                    PRINT *, INFILE
                                ENDIF
C
                                IF((IPIXCRD(1) .GE. 1) .AND. 
     +                                  (IPIXCRD(1) .LE. 2000) .AND. 
     +                                  (IPIXCRD(2) .GE. 1) .AND. 
     +                                  (IPIXCRD(2) .LE. 2000)) THEN
                                    MERG(IPIXCRD(1),IPIXCRD(2)) = 
     +                              MERG(IPIXCRD(1),IPIXCRD(2)) + 
     +                                       fscal*INPUT(I,II)
                                ENDIF
                            ENDIF
                        ENDDO
                    ENDDO
                ELSE
C
C  Close the FITS file
C
                    CALL FTCLOS(LUN,STATUS)
                    IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
                        ERR = 1
                        PRINT *, 'MERGE-COMP-XMM POSITION 29'
                        PRINT *, 'STATUS FTCLOS =', STATUS
                        PRINT *, INFILE
                    ENDIF
                    PRINT *, 'Observation outside of cast image FOV'
                    PRINT *, 'Offset Angle: ', DELANG/DRAD
                ENDIF
            ENDIF
        ENDDO
C
C  Create the output file name
C
        PRINT *, OUTFILE
C
C  Write out the merged array
C
        UNITS = '        '
        COMMENT = '        '
        IFLAG = 1
        ISIZE = 2000
        BZERO = 0.0
        BSCALE = 1.0
        IF(STATUS .EQ. 0) THEN
            CALL PUTFIT(OUTFILE,MERG,DUMMY,DUMMY,IFLAG,UNITS,
     +          COMMENT,ISIZE,ISIZE,BZERO,BSCALE,CTYPEN,CRVALN,
     +          CDELTN,CRPIXN,CLOBBER,STATUS)
        ENDIF
C
        IF(COMPON .EQ. 2) THEN
            PRINT *, 'Total Observations: ', ITHIN+IMED+ITHICK
            PRINT *, 'Thin Filter Observations: ', ITHIN
            PRINT *, 'Medium Filter Observations: ', IMED
            PRINT *, 'Thick Filter Observations: ', ITHICK
        ENDIF
C
        RETURN
        END SUBROUTINE MERGE_COMP_XMM_SUB
