         SUBROUTINE mos_back_sub(prefix,xmmdir,xmmd,diag,el,eh,
     +    ccd1,ccd2,ccd3,ccd4,ccd5,ccd6,ccd7)
c
c  Version 4.0  1 March 2010
c
c  Creates particle background spectra and images
c
c  xmm-back is part of the XMM-ESAS package and it produces
c  model particle background spectra and images (in detector
c  coordinates) from the output files of the perl script mos-spectra.
c.
c  Input:
c    prefix: Exposure ID prefix - e.g., prefix=1S001
c    caldb: QPB data directory - e.g., caldb=/XMM/esas/caldb
c    diag: diagnostic flag - e.g., diag=1
c    elow: Lower energy limit for the energy band in eV, if only spectra
c        are desired set to 0 - e.g., elow=0 or elow=400
c    ehigh: Upper energy limit for the energy band in eV, if only spectra
c        are desired set to 0 - e.g., ehigh=0 or ehigh=1250
c    ccd1: CCD control for CCD#1, 1 to include, 0 to not - e.g.,
c        ccd1=0 or ccd1=1
c    ccd2: CCD control for CCD#2, 1 to include, 0 to not - e.g.,
c        ccd2=0 or ccd2=1
c    ccd3: CCD control for CCD#3, 1 to include, 0 to not - e.g.,
c        ccd3=0 or ccd3=1
c    ccd4: CCD control for CCD#4, 1 to include, 0 to not - e.g.,
c        ccd4=0 or ccd4=1
c    ccd5: CCD control for CCD#5, 1 to include, 0 to not - e.g.,
c        ccd5=0 or ccd5=1
c    ccd6: CCD control for CCD#6, 1 to include, 0 to not - e.g.,
c        ccd6=0 or ccd6=1
c    ccd7: CCD control for CCD#7, 1 to include, 0 to not - e.g.,
c        ccd7=0 or ccd7=1
c
c    Example: mos_back prefix=1S003 caldb=/XMM/esas/caldb diag=0 elow=0
c                 ehigh=0 ccd1=1 ccd2=1 ccd3=1 ccd4=1 ccd5=1 ccd6=1 ccd7=1
c
        implicit none

        integer*2 i2array(780,780)
        integer ccd(7), ccd1, ccd2, ccd3, ccd4, ccd5, ccd6, ccd7
        integer band(2), bitpix, block, chan(800), channel(800), 
     +      clobber, diag, eh, el, err, errr, gcount, group, 
     +      grup(800), hdutype, i4array(780,780), i, i1, i2,  
     +      ichan, ii, iii, ipix, it, itest, j, jj, luna, lunb,
     +      maxe(13), mine(13), mosnum, n, naxes(2),
     +      naxis, nchan, nels, n_real, n_sims, nord,
     +      obsid, out(2), pcount,
     +      pflag, plc_al(2), plc_alsi(2), plc_aua(2), plc_aub(2),
     +      plc_auc(2), plc_hi(2), plc_lo(2), qual(800),
     +      revl, sim_chips(4), status, tfields, varidat
c
        real area, aug_expo, aug_rate,
     +      aug_scal(3), aug_spec(800), aug_time, avtot,
     +      back, bandl, bandh, coef(10), c_val(3),
     +      detm(1000,800),
     +      emax(800), emin(800), ener(800), fc1(800), expo,
     +      fc_area(7), fc_exp(7), fc_spec(800,7),
     +      fc_uncr(800,7), fillin(800),
     +      hard, high, image(780,780),
     +      lim_area, low, mask(800), mk1(800), modl(800),
     +      ntot, obj_back, obj_cnts(800), obj_expo,
     +      oc_area(7), oc_exp_obs(7), oc_mask(800,7),
     +      oc_spec(800,7), oc_uncr(800,7), oc1(800),
     +      outim(780,780), rate, reg_area(7), reg_area_obs(7),
     +      reg_exp(7), reg_exp_fwc(7),
     +      reg_exp_obs(7), reg_mask(800,7),
     +      reg_rati(800,7), reg_spec(800,7), reg_uncr(800,7),
     +      smo_fact, soft, spec(800), stat(800),
     +      t, t1, t2, temp_bot(800), temp_top(800), tempe(800),
     +      temps(800), tempu(800), tmodcounts, tot,
     +      tot1, tot2, uc1(800), uncr(800), ymax, ymin
c
        double precision cdelt(2), crpix(2), crval(2)
c
        character*1 db_fi(80), mosnam, qpb_fi(25), xmmd(80)
        character*5 prefix
        character*8 ctype(2), tform(10), ttype(10), tunit(10)
        character*25 qpb_file
        character*20 extname
        character*24 title
        character*25 mode
        character*80 back_file, db_file,  fname, imo_name,
     +      obj_file, obj_rmf, spec_file, spec_name, xmmdir
        character*132 im_name
c
        equivalence (db_file,db_fi)
        equivalence (qpb_file,qpb_fi)
c
        data aug_scal /0.01,1.0,0.0/
c        data aug_scal /1.0, 1.0, 0.0/
        data aug_time /1.0e6/
        data band /0, 0/
        data clobber /1/
        data db_file /'    '/
        data ipix /1/
        data nels /13/
        data mine / 40,127,154,256,370,405,440,475,505,545,585,665,787/
        data maxe / 79,139,255,350,385,415,460,490,525,560,625,735,799/
        data pflag /1/
        data qpb_file /'/mos1-qpb.fits.gz'/
        data smo_fact /4/
        data status /0/
c
c  Zero a few arrays
c
        errr = 0
        do i=1,800
            fc1(i) = 0.0
            fillin(i) = 0.0
            mask(i) = 0.0
            mk1(i) = 0.0
            modl(i) = 0.0
            oc1(i) = 0.0
            spec(i) = 0.0
            uc1(i) = 0.0
            uncr(i) = 0.0
        enddo
        do i=1,780
            do ii=1,780
                outim(i,ii) = 0.0
            enddo
        enddo
c
c  Get the prefix and write out some file names
c
c        call getarg(1,prefix)
        read(prefix,2999) mosnum
 2999   format(i1)
        write(obj_file,2990) prefix
 2990   format('mos',a5,'-obj.pi')
        write(obj_rmf,2991) prefix
 2991   format('mos',a5,'.rmf')
        write(spec_file,2992) prefix
 2992   format('mos',a5,'-spec.qdp')
c
        ccd(1) = ccd1
        ccd(2) = ccd2
        ccd(3) = ccd3
        ccd(4) = ccd4
        ccd(5) = ccd5
        ccd(6) = ccd6
        ccd(7) = ccd7

        print *, 'xmmdir: ', xmmdir
        print *, 'diag: ', diag
        print *, 'prefix: ', prefix
        print *, 'mosnum: ', mosnum
        print *, 'obj_file: ', obj_file
        print *, 'obj_rmf: ', obj_rmf
        print *, 'el, eh: ', el, eh
        print *, 'CCD selection', ccd
c
c        print *, 'Enter the region area limit'
c        read *, lim_area
c
        lim_area = 0.0
c
        print *, 'WARNING: if chip 3, 4 or 6 are missing spurious '
        print *, 'gold features can arise in the 2.04-2.33, '
        print *, '9.38-9.98, 11.03-11.82 keV regions'
c
c  Check to see whether MOS1 CCD#6 is missing
c
        if(mosnum .eq. 1) then
            call read_pha (obj_file,800,nchan,channel,obj_cnts,stat,
     +          qual,grup,obj_expo,obj_back,area,revl,obsid,mode,err)
            if(revl .gt. 961) then
                print *, 'Observation took place after MOS1 CCD6 ',
     +                  'was lost'
                if(ccd(6) .eq. 1) then
                    print *, 'Set ccd(6) equal to 0'
                    ccd(6) = 0
                    print *, 'Revised CCD selection '
                    print *, 'CCD selection', ccd
                endif
            elseif(revl .eq. 961) then
                print *, 'Observation took place during the ',
     +              'observation where MOS1 CCD6 was lost.  '
                print *, 'Exposure U002 has CCD6 data, U003 does not'
            endif
        endif
c
c  Do some setup
c  This sets the outer CCDs which will be used as cognates
c  for the central CCD
c
        n = 0
        if(mosnum .eq. 1) then
            if(ccd(2) .eq. 1) then
                n = n + 1
                sim_chips(n) = 2
            endif
            if(ccd(3) .eq. 1) then
                n = n + 1
                sim_chips(n) = 3
            endif
            if(ccd(6) .eq. 1) then
                n = n + 1
                sim_chips(n) = 6
            endif
            if(ccd(7) .eq. 1) then
                n = n + 1
                sim_chips(n) = 7
            endif
            n_sims = n
            mosnam = '1'
            n = n + 1
            do while (n .le. 4)
                sim_chips(n) = 0
                n = n + 1
            enddo
        elseif(mosnum .eq. 2) then
            if(ccd(3) .eq. 1) then
                n = n + 1
                sim_chips(n) = 3
            endif
            if(ccd(4) .eq. 1) then
                n = n + 1
                sim_chips(n) = 4
            endif
            if(ccd(6) .eq. 1) then
                n = n + 1
                sim_chips(n) = 6
            endif
            n_sims = n
            mosnam = '2'
            n = n + 1
            do while (n .le. 4)
                sim_chips(n) = 0
                n = n + 1
            enddo
        else
            print *, 'Illegal mos number: ', mosnum
            stop
        endif
c
c  Set the CalDB file name
c
        ii = 1
        do while (xmmd(ii) .ne. ' ')
            db_fi(ii) = xmmd(ii)
            ii = ii + 1
        enddo
        print *,'CalDB Directory: ', db_fi
        print *,'mosnam ', mosnam
        print *,'qpb_fi ', qpb_fi
        qpb_fi(5) = mosnam
        do iii=0,20
            db_fi(ii+iii) = qpb_fi(iii+1)
        enddo
        print *,'CalDB QPB FIle: ', db_fi
c
        bandl = el/1000.0
        bandh = eh/1000.0
c
c  Get information about the object spectrum
c
        call read_pha (obj_file,800,nchan,channel,obj_cnts,stat,qual,
     +      grup,obj_expo,obj_back,area,revl,obsid,mode,err)
c
c  Get the channel to energy conversion
c
        call read_rmf (obj_rmf,800,detm,chan,emin,emax)
        do ichan=1,nchan
            ener(ichan) = (emin(ichan) + emax(ichan))/2.
        enddo
c
        do i=1,nchan-1
c
c  Set channel ranges for some energy bands
c
            if((ener(i) .lt. 0.3) .and. (ener(i+1) .ge. 0.3))
     +              plc_al(1) = i + 1
            if((ener(i) .le. 10.0) .and. (ener(i+1) .gt. 10.0))
     +              plc_al(2) = i
            if((ener(i) .lt. 0.4) .and. (ener(i+1) .ge. 0.4))
     +              plc_lo(1) = i + 1
            if((ener(i) .lt. 0.8) .and. (ener(i+1) .ge. 0.8))
     +              plc_lo(2) = i
            if((ener(i) .lt. 2.5) .and. (ener(i+1) .ge. 2.5))
     +              plc_hi(1) = i + 1
            if((ener(i) .lt. 5.0) .and. (ener(i+1) .ge. 5.0))
     +              plc_hi(2) = i
c
c  Set channel ranges for the gold contamination
c
            if((ener(i) .lt. 2.04) .and. (ener(i+1) .ge. 2.04))
     +              plc_aua(1) = i + 1
            if((ener(i) .le. 2.33) .and. (ener(i+1) .gt. 2.33))
     +              plc_aua(2) = i
            if((ener(i) .lt. 9.38) .and. (ener(i+1) .ge. 9.38))
     +              plc_aub(1) = i + 1
            if((ener(i) .le. 9.98) .and. (ener(i+1) .gt. 9.98))
     +              plc_aub(2) = i
            if((ener(i) .lt. 11.03) .and. (ener(i+1) .ge. 11.03))
     +              plc_auc(1) = i + 1
            if((ener(i) .le. 11.82) .and. (ener(i+1) .gt. 11.82))
     +              plc_auc(2) = i
c
c  Set channel ranges for the Al and Si Kalpha contamination
c
            if((ener(i) .lt. 1.2) .and. (ener(i+1) .ge. 1.2))
     +              plc_alsi(1) = i + 1
            if((ener(i) .le. 1.9) .and. (ener(i+1) .gt. 1.9))
     +              plc_alsi(2) = i
c
c  Set channel ranges for the energy band
c
            if((bandl .eq. 0.0) .and. (bandh .eq. 0.0)) then
                if((ener(i) .lt. 0.3) .and. (ener(i+1) .ge. 0.3))
     +                  band(1) = i + 1
                if((ener(i) .le. 8.0) .and. (ener(i+1) .gt. 8.0))
     +                  band(2) = i
            else
                if((ener(i) .lt. bandl) .and. (ener(i+1) .ge. bandl))
     +                  band(1) = i + 1
                if((ener(i) .le. bandh) .and. (ener(i+1) .gt. bandh))
     +                  band(2) = i
            endif
c
c  Set channel ranges for the out
c
            if((ener(i) .lt. 1.0) .and. (ener(i+1) .ge. 1.0))
     +              out(1) = i + 1
            if((ener(i) .le. 2.5) .and. (ener(i+1) .gt. 2.5))
     +              out(2) = i
        enddo
c
c  Read the observation chip spectra to get the exposure
c
c  The obj data are the observation data
c
        print *, 'Process the observation data'
        do i=1,7
            if(ccd(i) .eq. 1) then
                write(spec_name,3000) prefix, i
 3000           format('mos',a5,'-',i1,'obj.pi')
                call read_pha (spec_name,800,nchan,channel,spec,uncr,
     +                  qual,grup,expo,back,area,revl,obsid,mode,err)
                if(diag .ge. 1) print *, spec_name
                if(diag .ge. 2) print *, nchan,expo,back,area,revl,err
c
c  If err = 0 then the file exists
c
                if(err .eq. 0) then
                    reg_exp_obs(i) = expo
                    reg_area_obs(i) = back
                else
                    errr=1
                    print *,'Missing file: ', spec_name
                    print *,'     in XMM_BACK, noted on return from ',
     +                      'READ_PHA'
                    reg_exp_obs(i) = 0.0
                       reg_area_obs(i) = 0.0
                endif
            endif
        enddo
        print *, 'Backscale and exposure from the observation data'
        do i=1,7
            if(ccd(i) .eq. 1) then
                print *,'Chip ', i, ' backscale=', reg_area_obs(i),
     +              ' exposure =',reg_exp_obs(i)
            endif
        enddo
c
c  Read the fwc spectra from the object region
c  Figure out which chips are involved
c  Use reg_area as a vector describing which chips are in use
c
c  The ff data are the FWC data from the object region
c
        print *, 'Process the FWC data from the object region'
        do i=1,7
            if(ccd(i) .eq. 1) then
                write(spec_name,3005) prefix, i
 3005           format('mos',a5,'-',i1,'ff.pi')
                call read_pha (spec_name,800,nchan,channel,spec,uncr,
     +                  qual,grup,expo,back,area,revl,obsid,mode,err)
                if(diag .ge. 1) print *, spec_name
                if(diag .ge. 2) print *, nchan,expo,back,area,revl,err
                reg_exp_fwc(i) = expo
c
c  If err = 0 then the file exists
c
                if(err .eq. 0) then
                    if((back .ne. 0) .and. (expo .ne. 0)) then
c
c  There is active area on this chip, normalize the spectrum
c
                        do ichan=1,nchan
                            reg_spec(ichan,i) = spec(ichan)/back/expo
                            reg_uncr(ichan,i) = uncr(ichan)/back/expo
                        enddo
                        reg_area(i) = back
                    else
                        do ichan=1,nchan
                            reg_spec(ichan,i) = 0.0
                            reg_uncr(ichan,i) = 0.0
                        enddo
                        reg_area(i) = 0.0
                    endif
                else
                    do ichan=1,nchan
                        reg_spec(ichan,i) = 0.0
                        reg_uncr(ichan,i) = 0.0
                    enddo
                    reg_area(i) = 0.0
                endif
            endif
        enddo
        print *, 'Backscale and exposure from the FWC data'
        do i=1,7
            if(ccd(i) .eq. 1) then
                print *,'Chip ', i, ' backscale=', reg_area(i),
     +                  ' exposure =', reg_exp_fwc(i)
            endif
        enddo
c
c  Remove any chip that has less area than the limiting area, lim_area
c
        do i=1,7
            if(ccd(i) .eq. 1) then
                if((reg_area(i) .lt. lim_area) .or.
     +                      (reg_area(i) .eq. 0.0) .or.
     +                      (reg_area_obs(i) .eq. 0.0)) then
                    reg_area(i) = 0.0
                    do ichan=1,nchan
                        reg_spec(ichan,i) = 0.0
                        reg_uncr(ichan,i) = 0.0
                    enddo
                endif
            endif
        enddo
c
c  Read corner spectra from the observation
c  First set up the spectrum masks
c
        do i=1,7
            if(ccd(i) .eq. 1) then
                do ichan=1,nchan
                    oc_mask(ichan,i) = 1
                enddo
                do ichan=plc_aua(1),plc_aua(2)
                    oc_mask(ichan,2) = 0
                    oc_mask(ichan,7) = 0
                enddo
                do ichan=plc_aub(1),plc_aub(2)
                    oc_mask(ichan,2) = 0
                    oc_mask(ichan,7) = 0
                enddo
                do ichan=plc_auc(1),plc_auc(2)
                    oc_mask(ichan,2) = 0
                    oc_mask(ichan,7) = 0
                enddo
            endif
        enddo
c
c  Even if one of the outer chips is not being used
c  we still need the corner data if chip 1 is on
c
c  The oc data are observation data from the corners
c
        print *, 'Process the observation data from the corner regions'
        do i=2,7
            if(ccd(i) .eq. 1) then
                write(spec_name,3010) prefix, i
 3010           format('mos',a5,'-',i1,'oc.pi')
c
                call read_pha (spec_name,800,nchan,channel,spec,uncr,
     +                  qual,grup,expo,back,area,revl,obsid,mode,err)
                if(diag .ge. 1) print *, spec_name
                if(diag .ge. 2) print *, nchan,expo,back,area,revl,err
                if(err .ne. 1) then
                    oc_exp_obs(i) = expo
                    rate = 0.0
                    soft = 0.0
                    hard = 0.0
                    high = 0.0
                    low = 0.0
                    do ichan=plc_al(1),plc_al(2)
                        rate = rate + spec(ichan)
                    enddo
                    rate = rate/expo
                    do ichan=plc_hi(1),plc_hi(2)
                        high = high + spec(ichan)
                    enddo
                    do ichan=plc_lo(1),plc_lo(2)
                        low = low + spec(ichan)
                    enddo
                    hard = high/low
c
c  Augment the spectrum
c
                    c_val(1) = rate
                    c_val(2) = hard
                    c_val(3) = revl
                    print *, db_file
                    call aug_get_exp(db_file,c_val,aug_scal,aug_time,
     +                      emin,emax,pflag,aug_spec,aug_expo,
     +                      mosnum,i,800,obsid,prefix)
                    do ichan=1,nchan
                        spec(ichan) = spec(ichan) + aug_spec(ichan)
                    enddo
                    expo = expo + aug_expo
                    aug_rate = 0.0
                    do ichan=plc_al(1),plc_al(2)
                        aug_rate = aug_rate + spec(ichan)
                    enddo
                    aug_rate = aug_rate/expo
                    do ichan=1,nchan
                        spec(ichan) = spec(ichan)*rate/aug_rate
                    enddo
c
c  Normalize the spectrum
c
                    do ichan=1,nchan
                        uncr(ichan) = sqrt(spec(ichan))
                        oc_spec(ichan,i) = spec(ichan)/back/expo
                        oc_uncr(ichan,i) = uncr(ichan)/back/expo
                    enddo
                    print *, i, back, expo
                    oc_area(i) = back
                    reg_exp(i) = expo
                else
                    do ichan=1,nchan
                        oc_spec(ichan,i) = 0.0
                        oc_uncr(ichan,i) = 0.0
                    enddo
                    oc_area(i) = 0.0
                    if(reg_area(i) .ne.  0.0) then
                        errr = 1
                        do ichan=1,nchan
                            reg_spec(ichan,i) = 0.0
                            reg_uncr(ichan,i) = 0.0
                        enddo
                        reg_area(i) = 0.0
                        print *, 'missing file: ',spec_name
c
c  Will not kill but will not return, we will try to recover
c
                    endif
                endif
            endif
        enddo
        print *, 'Backscale and augmented exposure from the corners ',
     +              'of the observation data'
        do i=2,7
            if(ccd(i) .eq. 1) then
                print *,'Chip ', i, ' backscale=', oc_area(i),
     +                  ' exposure =', reg_exp(i)
            endif
        enddo
c
c        stop
c
c  Do the center chip if necessary
c
        if((reg_area(1) .ne. 0.0) .and. (ccd(1) .eq. 1)) then
c
c  The center chip is active
c    create a mask for normalizing the center chips spectrum
c    determine how many similar chips have data
c
            print *, 'Process the observation data from the center chip'
            n_real = n_sims
            do i=1,n_sims
                if(oc_area(sim_chips(i)) .eq. 0.0) then
                    n_real = n_real - 1
                    sim_chips(i) = 0
                endif
            enddo
c
            if(n_real .eq. 0) then
c
c  This is really an error from which we can not recover
c
                errr = 2
                print *, 'No corner data for chip 1 model'
                stop
            else
                n_sims = n_real
                it = 0
                do i=1,4
                    if(sim_chips(i) .ne. 0) then
                        it = it + 1
                        sim_chips(it) = sim_chips(i)
                    endif
                enddo
            endif
            print *, 'N_SIMS: ', n_sims
            print *, (sim_chips(i),i=1,n_sims)
c
c  Sum over the similar chips
c
            do i=1,n_sims
                do ichan=1,nchan
                    oc1(ichan) = oc1(ichan) +
     +                  oc_spec(ichan,sim_chips(i))*
     +                  oc_mask(ichan,sim_chips(i))
                    uc1(ichan) = uc1(ichan) +
     +                  (oc_spec(ichan,sim_chips(i))**2)*
     +                  oc_mask(ichan,sim_chips(i))
                    mk1(ichan) = mk1(ichan) +
     +                  oc_mask(ichan,sim_chips(i))
                enddo
            enddo
c
c  Check to see whether there are any data
c
            itest = 0
            do ichan=1,nchan
                if(mk1(ichan) .ne. 0) itest = 1
            enddo
            if(itest .eq. 0)then
                errr = 2
                print *, 'No data to create a spectrum for chip 1'
                stop
            endif
c
            do ichan=1,nchan
                if(mk1(ichan) .ne. 0.0) then
                    oc1(ichan) = oc1(ichan)/mk1(ichan)
                    uc1(ichan) = sqrt(uc1(ichan))/mk1(ichan)
                else
                    oc1(ichan) = 0.0
                    uc1(ichan) = 0.0
                endif
                oc_spec(ichan,1) = oc1(ichan)
                oc_uncr(ichan,1) = uc1(ichan)
            enddo
            do i=1,7
                if(ccd(i) .eq. 1) then
                    tot = 0.0
                    do ichan=band(1),band(2)
                        tot = tot + oc_spec(ichan,i)
                    enddo
                    print *, 'Chip',i,' observation corner total: ', tot
                endif
            enddo
        endif
c
c  Read FWC corner spectra
c
c  The fc data are the FWC data from the corners
c
        print *, 'Process the FWC corner data'
        do i=2,7
            if(ccd(i) .eq. 1) then
                write(spec_name,3030) prefix, i
 3030           format('mos',a5,'-',i1,'fc.pi')
                call read_pha (spec_name,800,nchan,channel,spec,uncr,
     +                  qual,grup,expo,back,area,revl,obsid,mode,err)
                if(diag .ge. 1) print *, spec_name
                if(diag .ge. 2) print *, nchan,expo,back,area,revl,err
                if(err .ne. 1) then
c
c  Normalize the spectrum
c
                    do ichan=1,nchan
                        fc_spec(ichan,i) = spec(ichan)/back/expo
                        fc_uncr(ichan,i) = uncr(ichan)/back/expo
                    enddo
                    fc_area(i) = back
                    fc_exp(i) = expo
                else
                    if((reg_area(i) .ne. 0.0) .or.
     +                      (oc_area(i) .ne. 0)) then
                        errr=1
                        print *, 'missing file: ',spec_name,
     +                      ' in xmm-back-image'
                        stop
                    endif
                endif
            endif
        enddo
        print *, 'Backscale and augmented exposure from the corners ',
     +              'of the FWC data'
        do i=2,7
            if(ccd(i) .eq. 1) then
                print *,'Chip ', i, ' backscale=', fc_area(i),
     +                  ' exposure =', fc_exp(i)
            endif
        enddo
c
c  Create a corner spectrum for the center chip
c
        if(ccd(1) .eq. 1) then
            do i=1,n_sims
                do ichan=1,nchan
                    fc1(ichan) = fc1(ichan) +
     +                      fc_spec(ichan,sim_chips(i))*
     +                      oc_mask(ichan,sim_chips(i))
                enddo
            enddo
c
            t = 0.0
            do ichan=1,nchan
                if(mk1(ichan) .ne. 0) then
                    fc1(ichan) = fc1(ichan)/mk1(ichan)
                endif
                fc_spec(ichan,1) = fc1(ichan)
                t = t + fc_spec(ichan,1)
            enddo
            if(t .eq. 0.0) then
                errr = 2
                print *, 'yet another problem'
                stop
            endif
        endif
c
c  Create the ratio of region/corner for FWC data
c
        do i=2,7
            if((reg_area(i) .ne. 0.0) .and. (ccd(i) .eq. 1)) then
                do ichan=1,nchan
                    i1 = ichan - smo_fact
                    if(i1 .lt. 1) i1 = 1
                    i2 = ichan + smo_fact
                    if(i2 .gt. nchan) i2 = nchan
                    t1 = 0.0
                    t2 = 0.0
                    it = 0
                    do ii=i1,i2
                        t1 = t1 + reg_spec(ii,i)
                        t2 = t2 + fc_spec(ii,i)
                        it = it + 1
                    enddo
                    temp_top(ichan) = t1/it
                    temp_bot(ichan) = t2/it
                enddo
                do ichan=1,nchan
                    if(temp_bot(ichan) .ne. 0) then
                        reg_mask(ichan,i) = 1.0
                        reg_rati(ichan,i) =
     +                          temp_top(ichan)/temp_bot(ichan)
                    else
                        reg_mask(ichan,i) = 0.0
                        reg_rati(ichan,i) = 0.0
                    endif
                enddo
            endif
        enddo
        if(diag .ge. 2) then
            print *, 'TEMP_TOP: ', temp_top
            print *, 'TEMP_BOT: ', temp_bot
        endif
c
c  Single out chip 1 for special treatment again
c
        if((reg_area(1) .ne. 0.0) .and. (ccd(1) .eq. 1)) then
c
c  Does the spectrum have gold gaps?
c
            itest = 1
            do ichan=plc_al(1),plc_al(2)
                if(oc_spec(ichan,1) .eq. 0.0) itest = 0
            enddo
            if(itest .eq. 1) then
                do ichan=1,nchan
                    i1 = ichan - smo_fact
                    if(i1 .lt. 1) i1 = 1
                    i2 = ichan + smo_fact
                    if(i2 .gt. nchan) i2 = nchan
                    t1 = 0.0
                    t2 = 0.0
                    it = 0
                    do ii=i1,i2
                        t1 = t1 + reg_spec(ii,1)
                        t2 = t2 + fc_spec(ii,1)
                        it = it + 1
                    enddo
                    temp_top(ichan) = t1/it
                    temp_bot(ichan) = t2/it
                enddo
                do ichan=1,nchan
                    if(temp_bot(ichan) .ne. 0) then
                        reg_mask(ichan,1) = 1.0
                        reg_rati(ichan,1) =
     +                          temp_top(ichan)/temp_bot(ichan)
                    else
                        reg_mask(ichan,1) = 0.0
                        reg_rati(ichan,1) = 0.0
                    endif
                enddo
            else
                errr=3
                print *, 'You are scrod, your chip 1 background ',
     +                  'has goldgaps'
                stop
            endif
        endif
c
c  Print out some diagnostic information
c
        if(diag .ge. 1) then
            print *, 'Backscale for the FWC corner ',
     +              'and FWC region data'
            do i=1,7
                print *,'Chip ', i, ' backscale=', fc_area(i),
     +                  ' backscale =', reg_area(i)
            enddo
        endif
        t1 = 0.0
        t2 = 0.0
        do i=1,7
            t1 = t1 + fc_area(i)
            t2 = t2 + reg_area(i)
        enddo
        if(diag .ge. 1) then
            print *, 'FC_AREA, REG_AREA, RATIO: ', t1, t2, t1/(t1 + t2)
        endif
c
c  Create the masks to remove strong instrumental lines
c  Remove the Al-Si line from all spectra
c
        do ichan=plc_alsi(1),plc_alsi(2)
            do i=1,7
                oc_mask(ichan,i) = 0
            enddo
        enddo
c
c  Sum the background over all active chips and make an image
c
        if(diag .ge. 2) then
            write(fname,3035) prefix
 3035       format('mos',a5,'-back-accum.qdp')
            open(89,form='formatted',status='unknown',file=fname)
            write(89,*) 'viewport 0.2 0.2 0.95 0.9'
            write(89,*) 'read serr 2'
            write(89,*) 'font roman'
            write(89,*) 'cs 1.5'
            write(89,*) 'log y'
            write(89,*) 'r y 1.e-2 1.e7'
            write(89,*) 'la y Scaled Counts'
            write(89,*) 'la x Channel'
        endif
        do ichan=1,800
             spec(ichan) = 0.0
             uncr(ichan) = 0.0
        enddo
        do i=1,7
            if((reg_area(i) .ne. 0) .and. (ccd(i) .eq. 1)) then
                do ichan=1,nchan
                    if((reg_mask(ichan,i) .ne. 0.0) .and.
     +                      (oc_mask(ichan,i) .ne. 0.0)) then
                        spec(ichan) = spec(ichan) + oc_spec(ichan,i)*
     +                          reg_rati(ichan,i)*reg_area(i)
                        uncr(ichan) = uncr(ichan) + (oc_uncr(ichan,i)*
     +                          reg_rati(ichan,i)*reg_area(i))**2
                        mask(ichan) = mask(ichan) + reg_area(i)
                    endif
                    if((diag .ge. 2) .and. (mask(ichan) .gt. 0.0)) then
                        write(89,*) ichan,
     +                      1.e10*(10.0**i)*
     +                              spec(ichan)/mask(ichan),
     +                      1.e10*(10.0**i)*
     +                              sqrt(uncr(ichan))/mask(ichan)
                    endif
                enddo
                tmodcounts = 0.0
                tot1 = 0.0
                tot2 = 0.0
                do ichan=band(1),band(2)
                    tmodcounts = tmodcounts + oc_spec(ichan,i)*
     +                  reg_rati(ichan,i)*reg_area_obs(i)*
     +                  reg_exp_obs(i)
                    tot1 = tot1 + oc_spec(ichan,i)
                    tot2 = tot2 + reg_rati(ichan,i)
                enddo
                if(diag .ge. 2) then
                    print *, i, tot1, tot2, reg_area(i),
     +                      reg_area_obs(i), reg_exp_obs(i)
                endif
c
c  Read in the fwc image
c
c		print *, 'test1112'
                if(eh .gt. 0) then
                    if(el .ge. 10000) then
                        write(im_name,3040) prefix, i, el, eh
 3040                   format('mos',a5,'-im',i1,'-',i5,'-',i5,'.fits')
                    elseif(el .ge. 1000) then
                        if(eh .ge. 10000) then
                            write(im_name,3041) prefix, i, el, eh
 3041                       format('mos',a5,'-im',i1,'-',i4,'-',
     +                              i5,'.fits')
                        else
                            write(im_name,3042) prefix, i, el, eh
 3042                       format('mos',a5,'-im',i1,'-',i4,'-',
     +                              i4,'.fits')
                        endif
                    else
                        if(eh .ge. 10000) then
                            write(im_name,3043) prefix, i, el, eh
 3043                       format('mos',a5,'-im',i1,'-',i3,'-',
     +                              i5,'.fits')
                        elseif(eh .ge. 1000) then
                            write(im_name,3044) prefix, i, el, eh
 3044                       format('mos',a5,'-im',i1,'-',i3,'-',
     +                              i4,'.fits')
                        else
                            write(im_name,3045) prefix, i, el, eh
 3045                       format('mos',a5,'-im',i1,'-',i3,'-',
     +                              i3,'.fits')
                        endif
                    endif
                    print *, im_name
                    call retfit(im_name,image,i2array,i4array,
     +                  1,780,780,ctype,crval,cdelt,crpix,status)
                    if(status .eq. 0) then
c
c  Check for bright pixels
c

                        tot = 0.0
                        ntot = 0.0
                        do j=1,780
                            do jj=1,780
                                if(image(j,jj) .gt. 0) then
                                    tot = tot + image(j,jj)
                                    ntot = ntot + 1.0
                                endif
                            enddo
                        enddo
                        if(ntot .gt. 0.0) then
                            avtot = tot/ntot
                            print *, 'Average non-zero value of FWC ',
     +                              'image: ', avtot
                            tot = 5.0*avtot
                            do j=1,780
                                do jj=1,780
                                    if(image(j,jj) .gt. tot) then
                                        image(j,jj) = avtot
                                    endif
                                enddo
                            enddo
c
                            tot = 0.0
                            do j=1,780
                                do jj=1,780
                                    tot = tot + image(j,jj)
                                enddo
                            enddo
                            print *, 'FWC image scaling for chip: ', i,
     +                              tmodcounts, tot, tmodcounts/tot
                            do j=1,780
                                do jj=1,780
                                    outim(j,jj) = outim(j,jj) +
     +                                      image(j,jj)*tmodcounts/tot
                                enddo
                            enddo
                        endif
                    endif
                endif
            endif
            if(diag .gt. 2) then
                write(89,*) 'no no no'
            endif
        enddo
c
        if(diag .gt. 1) then
            print *, 'Exposure for the FWC and observation data'
            do i=1,7
                if(ccd(i) .eq. 1) then
                    print *,'Chip ', i, ' exposure=', reg_exp_fwc(i),
     +                      ' exposure =', reg_exp_obs(i)
                endif
            enddo
        endif
c
c  Search for and eliminate hot pixels
c
        if(eh .gt. 0) then
            if(ipix .eq. 1) then
                tot1 = 0.0
                tot2 = 0.0
                do i=1,780
                    do ii=1,780
                        if(outim(i,ii) .gt. 0.0) then
                            tot1 = tot1 + outim(i,ii)
                        tot2 = tot2 + 1.0
                        endif
                    enddo
                enddo
                tot1 = 2.0*tot1/tot2
                do i=1,780
                    do ii=1,780
                        if(outim(i,ii) .gt. tot1) then
                            outim(i,ii) = tot1
                        endif
                    enddo
                enddo
                tot1 = 0.0
                tot2 = 0.0
            endif
        endif
c
c  Write out some more diagnostic information
c
        if(diag .ge. 2) then
            write(fname,3055) prefix
 3055       format('mos',a5,'-back.qdp')
            open(89,form='formatted',status='unknown',file=fname)
            write(89,*) 'viewport 0.2 0.2 0.95 0.9'
            write(89,*) 'read serr 2'
            write(89,*) 'font roman'
            write(89,*) 'cs 1.5'
            write(89,*) 'log y'
            write(89,*) 'la y Model Background Counts'
            write(89,*) 'la x Channel'
        endif
        do ichan=1,nchan
            if(mask(ichan) .ne. 0.0) then
                spec(ichan) = spec(ichan)/mask(ichan)
                uncr(ichan) = sqrt(uncr(ichan))/mask(ichan)
                if(diag .ge. 2) then
                    write(89,*) ichan, spec(ichan), uncr(ichan)
                endif
            else
                spec(ichan) = 0.0
                uncr(ichan) = 0.0
            endif
        enddo
        if(diag .ge. 2) then
            close(89)
        endif
c
c  Read in the observation image in detector coordinates
c
c  First create the file name
c

        if(eh .gt. 0) then
            if(el .ge. 10000) then
                write(im_name,3060) prefix, el, eh
 3060           format('mos',a5,'-obj-im-det-',i5,'-',i5,'.fits')
            elseif(el .ge. 1000) then
                if(eh .ge. 10000) then
                    write(im_name,3061) prefix, el, eh
 3061               format('mos',a5,'-obj-im-det-',i4,'-',i5,'.fits')
                else
                    write(im_name,3062) prefix, el, eh
 3062               format('mos',a5,'-obj-im-det-',i4,'-',i4,'.fits')
                endif
            else
                if(eh .ge. 10000) then
                    write(im_name,3063) prefix, el, eh
 3063               format('mos',a5,'-obj-im-det-',i3,'-',i5,'.fits')
                elseif(eh .ge. 1000) then
                    write(im_name,3064) prefix, el, eh
 3064               format('mos',a5,'-obj-im-det-',i3,'-',i4,'.fits')
                else
                    write(im_name,3065) prefix, el, eh
 3065               format('mos',a5,'-obj-im-det-',i3,'-',i3,'.fits')
                endif
            endif
c
c  Get an unused lun
c
            call ftgiou(luna,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 1'
                print *, 'STATUS FTGIOU =', status
            endif
c
            call retfit(im_name,image,i2array,i4array,
     +              1,780,780,ctype,crval,cdelt,crpix,status)
            if(status .ne. 0) then
                print *, 'Cant find observation image in detector ',
     +                  'coords'
                print *, im_name
                stop
            endif
c
            tot1 = 0.0
            tot2 = 0.0
            do j=1,780
                do jj=1,780
                    tot1 = tot1 + image(j,jj)
                    tot2 = tot2 + outim(j,jj)
                enddo
            enddo
            print *,'Total observation counts in band ',tot1
            print *,'Total background counts in band ',tot2
c
c  Write out the background image
c
c  First get an unused lun
c
            call ftgiou(luna,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 2'
                print *, 'STATUS FTGIOU =', status
            endif
            call ftgiou(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 3'
                print *, 'STATUS FTGIOU =', status
            endif
c
c  Create the output file name
c
            if(el .ge. 10000) then
                write(imo_name,3080) prefix, el, eh
 3080           format('mos',a5,'-back-im-det-',i5,'-',i5,'.fits')
            elseif(el .ge. 1000) then
                if(eh .ge. 10000) then
                    write(imo_name,3081) prefix, el, eh
 3081               format('mos',a5,'-back-im-det-',i4,'-',i5,'.fits')
                else
                    write(imo_name,3082) prefix, el, eh
 3082               format('mos',a5,'-back-im-det-',i4,'-',i4,'.fits')
                endif
            else
                if(eh .ge. 10000) then
                    write(imo_name,3083) prefix, el, eh
 3083               format('mos',a5,'-back-im-det-',i3,'-',i5,'.fits')
                elseif(eh .ge. 1000) then
                    write(imo_name,3084) prefix, el, eh
 3084               format('mos',a5,'-back-im-det-',i3,'-',i4,'.fits')
                else
                    write(imo_name,3085) prefix, el, eh
 3085               format('mos',a5,'-back-im-det-',i3,'-',i3,'.fits')
                endif
            endif
c
c  Open the old image FITS file
c
            call ftopen (luna,im_name,0,block,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 4a'
                print *, 'STATUS FTOPEN =', status
                print *, im_name
            endif
c
c  Check to see if there is an existing file
c
            call ftopen (lunb,imo_name,0,block,status)
            if(status .eq.  0) then
                print *, 'File exists with output file name'
                if(clobber .eq.  1) then
                    print *, 'Clobber the file and continue'
                    call ftdelt(lunb,status)
                else
                    print *, 'XMM-BACK POSITION 4b'
                    print *, 'Will not clobber file'
                    stop
                endif
            endif
            status = 0
c
c  Create the output FITS file using the original file as a template
c
            call ftinit (lunb,imo_name,2880,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 5'
                print *, 'STATUS FTINIT =', status
                print *, imo_name
            endif
c
            call ftcphd (luna,lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 6'
                print *, 'STATUS FTCPHD =', status
            endif
c
            bitpix = -32
            naxis = 2
            naxes(1) = 780
            naxes(2) = 780
            pcount = 0
            gcount = 1
            group = 1
            call ftpdef (lunb,bitpix,naxis,naxes,pcount,
     +              gcount,.FALSE.,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 7'
                print *, 'STATUS FTPDEF =', status
            endif
            call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'XMM-BACK POSITION 8'
                print *, 'STATUS FTMKYJ =', status
            endif
            if(err .eq. 0) then
c
c  Write the output image
c
                call ftp2de (lunb,group,naxes(1),naxes(1),naxes(2),
     +                  outim,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTP2DE =', status
                    print *, 'XMM-BACK POSITION 9'
                    print *, 'Could not write the background image'
                endif
c
c  Close the output file
c
                call ftclos(lunb,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTCLOS =', status
                    print *, 'XMM-BACK POSITION 10'
                    print *, 'Could not close the output file'
                endif
            endif
            call ftfiou (luna,status)
            call ftfiou (lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTFIOU =', status
                print *, 'XMM-BACK POSITION 11'
                print *, 'Could not close the output file'
            endif
        endif
c
c  Bridge the Al-Si gap
c    Set a number of line-free windows
c    Extract the data from those windows
c    Fit a simple polynomial
c    Use to interpolate over the Al-Si gap
c
c  The following two lines need to be converted to energies
c
        n = 0
        do i=1,nels
            do ichan=mine(i),maxe(i)
                if((ener(ichan) .gt. 0.1) .and.
     +                  (spec(ichan) .gt. 0.0)) then
                    n = n + 1
                    tempe(n) = alog(ener(ichan))
                    temps(n) = alog(spec(ichan))
                    tempu(n) = 0.2
                endif
            enddo
        enddo
c
        nord=5
        call poly_fit(tempe,temps,tempu,n,nord,coef)
        if(diag .ge. 2) then
            write(fname,3105) prefix
 3105       format('mos',a5,'-bridge-fit.qdp')
            open(89,form='formatted',status='unknown',file=fname)
            write(89,*) 'viewport 0.2 0.2 0.95 0.9'
            write(89,*) 'read serr 2'
            write(89,*) 'font roman'
            write(89,*) 'cs 1.5'
            write(89,*) 'la y Arbitrary'
            write(89,*) 'la x Log(E) (keV)'
        endif
        do ichan=1,nchan
            do i=0,nord
                modl(ichan) = modl(ichan) +
     +                  coef(i+1)*(alog(ener(ichan))**i)
            enddo
            if((diag .ge. 2) .and. (ener(ichan) .gt. 0.1)) then
                 write(89,*) alog(ener(ichan)), alog(spec(ichan)),
     +              0.05*(alog(spec(ichan))), modl(ichan)
            endif
        enddo
c
        if(diag .ge. 2) then
            close(89)
        endif
c
c  Finish the bridge
c
        do ichan = plc_alsi(1),plc_alsi(2)
            fillin(ichan) = exp(modl(ichan))
            spec(ichan) = spec(ichan) + fillin(ichan)
        enddo
        ymin = 1.e8
        ymax = 0
        do ichan = 7,nchan
            if (obj_cnts(ichan)-stat(ichan) .lt. ymin)
     +              ymin = obj_cnts(ichan)-stat(ichan)
            if (obj_cnts(ichan)+stat(ichan) .gt. ymax)
     +              ymax = obj_cnts(ichan)+stat(ichan)
            if (obj_expo*obj_back*(spec(ichan)-uncr(ichan)) .lt. ymin)
     +              ymin = obj_expo*obj_back*(spec(ichan)-uncr(ichan))
            if (obj_expo*obj_back*(spec(ichan)+uncr(ichan)) .gt. ymax)
     +              ymax = obj_expo*obj_back*(spec(ichan)+uncr(ichan))
        enddo
        open(89,form='formatted',status='unknown',file=spec_file)
        write(89,*) 'viewport 0.2 0.2 0.9 0.85'
        write(89,*) 'la f'
        write(title,3110) obsid, prefix
 3110   format('"',i10,' -- MOS',a5,'"')
        write(89,*) 'la t ', title
        write(89,*) 'la x Energy (keV)'
        write(89,*) 'la y Counts'
        i = 0.75*ymax
        write(89,*) 'la 1 p 3 ', i, ' just left ',
     + '"Observed (red), Particle Background (green)"'
        write(89,*) 'log y'
        write(89,*) 'r x 0 12'
        write(89,*) 'r y ', ymin, ymax
        write(89,*) 'read serr 2'
        write(89,*) 'read serr 3'
        write(89,*) 'read serr'
        write(89,*) 'font roman'
        write(89,*) 'cs 1.8'
        do ichan = 1,nchan
            write(89,*) ener(ichan), obj_cnts(ichan), stat(ichan),
     +                  obj_expo*obj_back*spec(ichan),
     +                  obj_expo*obj_back*uncr(ichan)
        enddo
        close(89)
c
c  Get two unused luna
c
        call ftgiou(luna,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'XMM-BACK POSITION 12'
        endif
        call ftgiou(lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'XMM-BACK POSITION 13'
        endif
c
c  Open the spectrum FITS file
c
        call ftopen (luna,obj_file,0,block,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTOPEN =', status
            print *, 'XMM-BACK POSITION 14'
            print *, spec_name
        endif
c
c  Create the output FITS file using the original file as a template
c
        write(back_file,3100) prefix
 3100   format('mos',a5,'-back.pi')
        call fttplt (lunb,back_file,obj_file,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            if(status .eq. 105) then
                print *, 'The file already exists ',back_file
                stop
            else
                err = 1
                print *, 'STATUS FTINIT =', status
                print *, 'XMM-BACK POSITION 15'
            endif
        endif
c
        if(err .eq. 0) then
c
c  Move to the input file spectrum extension
c
            call ftmahd (lunb,2,hdutype,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTMHD =', status
                print *, 'XMM-BACK POSITION 16'
                print *, 'Could not find the spectrum extension'
            endif
c
c  Check to make sure that we have the spectrum extension
c
            call ftghbn (lunb,10,nchan,tfields,ttype,tform,
     +          tunit,extname,varidat,status)
            if(extname .ne. 'SPECTRUM') then
                print *, 'XMM-BACK POSITION 17'
                print *, extname
                print *, 'This was supposed to be a spectrum ext'
                stop
            endif
c
c  Get rid of extra extensions
c  Move to the next extension
c
            call ftmrhd (lunb,1,hdutype,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTMHD =', status
                print *, 'XMM-BACK POSITION 18'
                print *, 'No more extensions'
                status = 0
c
c  Move to the input file spectrum extension
c
                call ftmahd (lunb,2,hdutype,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'STATUS FTMHD =', status
                    print *, 'XMM-BACK POSITION 19'
                    print *, 'Could not find the spectrum extension'
                endif
            endif
c
c  Check to make sure that we have the spectrum extension
c
            call ftghbn (lunb,10,nchan,tfields,ttype,tform,
     +          tunit,extname,varidat,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTGHBN =', status
                print *, 'XMM-BACK POSITION 20'
                print *, 'Could not read extension info'
            endif
c
            if(extname .ne. 'SPECTRUM') then
                do while (extname .ne. 'SPECTRUM')
                    call ftdhdu (lunb,hdutype,status)
                    if((status .ne. 0) .and. (err .eq. 0)) then
                        err = 1
                        print *, 'STATUS FTDHDU =', status
                        print *, 'XMM-BACK POSITION 21'
                        print *, 'Could not delete an extension'
                    endif
                    call ftghbn (lunb,10,nchan,tfields,ttype,tform,
     +                  tunit,extname,varidat,status)
                    if((status .ne. 0) .and. (err .eq. 0)) then
                        err = 1
                        print *, 'STATUS FTGHBN =', status
                        print *, 'XMM-BACK POSITION 22'
                        print *, 'Could not read extension info'
                    endif
                enddo
            endif
c
c  Close the input lun
c
            call ftclos(luna,status)
c
c  Write the output spectrum
c
            call ftukye(lunb,'EXPOSURE',obj_expo,4,
     +              'Background exposure',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 23'
                print *, 'Could not write the exposure keyword'
            endif
            call ftukye(lunb,'BACKSCAL',obj_back,4,
     +              'Scaling factor for background',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 24'
                print *, 'Could not write the backscale keyword'
            endif
c
c  Delete the existing column information
c
            call ftdcol(lunb,2,status)
            call ftdcol(lunb,1,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 25'
                print *, 'Could not delete the existing column info'
            endif
c
c  Create the new columns
c
            call fticol(lunb,1,'CHANNEL','1J',status)
            call fticol(lunb,2,'COUNTS','1E',status)
            call fticol(lunb,3,'STAT_ERR','1E',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 26'
                print *, 'Could not the new columns'
            endif
c
c  Update a few keywords
c
            call ftukys(lunb,'TUNIT1','channel',
     +              'physical unit of field',status)
            call ftukys(lunb,'TUNIT2','count',
     +              'physical unit of field',status)
            call ftukys(lunb,'TUNIT3','count',
     +              'physical unit of field',status)
            call ftukyl(lunb,'POISSERR',.FALSE.,
     +              'physical unit of field',status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 27'
                print *, 'Could not write the various keywords'
            endif
c
c  Prepare the spectrum data
c
            do ichan=1,nchan
                chan(ichan) = ichan - 1
                spec(ichan) = spec(ichan)*obj_expo*obj_back
                uncr(ichan) = uncr(ichan)*obj_expo*obj_back
c                spec(ichan) = spec(ichan)*expo*back
c                uncr(ichan) = uncr(ichan)*expo*back
            enddo
c
c  Write the column data
c
            call ftpclj(lunb,1,1,1,nchan,chan,status)
            call ftpcle(lunb,2,1,1,nchan,spec,status)
            call ftpcle(lunb,3,1,1,nchan,uncr,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 28'
                print *, 'Could not write the column information'
            endif
c
c  Close the output file
c
            call ftclos(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'STATUS FTUKYE =', status
                print *, 'XMM-BACK POSITION 29'
                print *, 'Could not close the output file'
            endif
c
        endif
        call ftfiou (luna,status)
        call ftfiou (lunb,status)
c
        RETURN
        END SUBROUTINE mos_back_sub
