        subroutine proton_scale_sub(xmmdir,xmmd,mode,num,maskfile,
     +      specfile,spfile)
c
c  Version 3.0: 20 August 2008
c
c  Returns the average SP flux and BACKSCAL keyword for a region
c
c  proton-scale uses a mask image created by mos-spectra to find
c  the average SP flare intensity for that region, and returns the
c  BACKSCAL keyword from the spectrum for that region.
c
c Usage:
c   data directory
c   mode: 1 -> single region
c         2 -> multiple regions
c   mode = 1
c       MOS1: 1, MOS2: 2, pn: 3
c       region image file name
c       region spectrum file name
c       Example: 
c             proton-scale /path/qpb 1 1
c                  region-image.fits region-spec.fits
c   mode = 2
c       filename with region information
c       Example:  proton-scale /path/qpb 2 spregion.txt
c
        implicit none
c
        integer err, i, ios, lun, mode, num, n, status
c
        real back, backl(100), c, cl(100)
c
        character*1 xmmd(80)
        character*60 maskfile, specfile
        character*80 spfile, xmmdir
c
        data err /0/
        data status /0/
c
        print *,'xmmd: ',xmmd
        print *, 'xmmdir: ', xmmdir
c
        if(mode .eq. 1) then
            print *, 'nam: ', num
            print *, 'maskfile: ', maskfile
            print *, 'specfile: ', specfile
c
            call spscale(xmmdir,xmmd,num,maskfile,
     +              specfile,back,c)
c
            print *, 'Area: ', back
            print *, 'Ave Flux: ', c
            print *, 'Scaled Ave Flux: ', 1.0e5*c*back
c
        elseif(mode .eq. 2) then
            print *, 'spfile: ', spfile
c
c  Get an unused lun for the spectrum
c
            call ftgiou(lun,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'PROTON-SCALE STATUS FTGIOU =', status
                print *, 'POSITION 01'
            endif
c
            open(unit=lun,form='formatted',status='old',file=spfile)
            ios = 0
            i = 1
            do while (ios .eq. 0)
                read(lun,2010,iostat=ios) maskfile
                read(lun,2010,iostat=ios) specfile
 2010           format(a60)
                if(ios .eq. 0) then
c                    print *, num, maskfile, specfile
c
                    call spscale(xmmdir,xmmd,num,maskfile,
     +                       specfile,backl(i),cl(i))
                    i = i + 1
                endif
            enddo
c
            n = i - 1
            print *, '  '
            print *, '         Solid   Soft Proton'
            print *, '         Angle     Scaling'
            print *, '  '
            do i=1,n
                print 2000, i, backl(i),
     +                  backl(i)*cl(i)/(backl(1)*cl(1))
 2000           format(1x,i5,2f10.4)
            enddo
        endif
c
        RETURN
        END SUBROUTINE proton_scale_sub
