        subroutine proton_sub(prefixin,xmmdir,xmmd,ccd1,ccd2,ccd3,
     +          ccd4,ccd5,ccd6,ccd7,elow,ehigh,ispec,
     +          pindex,pnorm,bindl,break,bindh,bnorm)
c
c  Version 4.0  3 March 2010
c
c  Casts a map of the soft proton background using the fitted
c  spectral parameters for a power law (works) and broken power
c  law (in progress).  Soft proton detector maps developed by
c  K. Kuntz are used for the distributions
c
c  Usage:
c     prefix - exposure ID prefix
c     xmmdir - ESAS CCF directory 
c     ccd1-ccd7 - MOS ccd#1 - ccd#7 or PN quad#1 - quad #4 inclusion control
c     elow - lower energy band limit in eV
c     ehigh - upper energy band limit in eV
c     spectrumcontrol - spectrum control
c           1 - power law,  2 - broken power law
c     spectral parameters from Xspec
c     spectrumcontrol=1
c         pindex - power law index
c         pnorm - power law normalization
c     spectrumcontrol=2
c         bindl - soft power law index
c         break - power law break energy (in keV)
c         bindh - hard power law index
c         bnorm - broken power law normalization
c
c     Examples:
c         proton prefix=1S001 caldb=/CalDB elow=400 ehigh=1250 ccd1=1 
c               ccd2=1 ccd3=1 ccd1=4 ccd5=1 ccd6=0 ccd1=7 spectrumcontrol=1 
c               pindex=0.8 pnorm=0.1
c         proton prefix=1S001 caldb=/CalDB elow=400 ehigh=1250 ccd1=1 
c               ccd2=1 ccd3=1 ccd1=4 ccd5=1 ccd6=0 ccd1=7 spectrumcontrol=1 
c               bindl=0.8 break=3.0 bindh=0.3 pnorm=0.1
c
        implicit none

        integer ccd(7), ccd1, ccd2, ccd3, ccd4, ccd5, ccd6, ccd7
        integer bitpix, bitpixn, block, clobber, ehigh, elow, err,
     +      gcount, gcountn, group, hdutype, i, i1, i2, ib, ibb(7), 
     +      idet, iext, ih, ii, ii1, ii2, iii,
     +      il, ispec, j, jj, jjj, k, kk, lun, luna, lunb,
     +      n, naxes(2), naxesn(2), naxis, naxisn,
     +      pcount, pcountn, revl, status
c
        real bnorm, bindh, bindl, break, eh, el, elim(7),
     +      fb(7), inarr(780,780), pindex, pnorm, prot, rind, rn, 
     +      scale, spmap(780,780), temp
c
        double precision exposen
c
        character*1 db_fi(80), detnam, sp_fi(19), xmmd(80)
        character*4 prefi
        character*5 prefix, prefixin
        character*8 extname
        character*19 sp_file
        character*60 com
        character*80 db_file, objfile, outfile, xmmdir
c
        logical anyf, extend, extendn, simple, simplen
c
        equivalence (db_file,db_fi)
        equivalence (sp_file,sp_fi)
        equivalence (prefix,prefi)
c
        data clobber /1/
        data elim /300.0, 750.0, 1250.0, 2000.0, 4000.0,
     +      8000.0, 12000.0/
        data err /0/
        data status /0/
c
        prefix = prefixin
c
        do i=1,780
            do ii=1,780
                spmap(i,ii) = 0.0
            enddo
        enddo
c
c  Get the input parameters
c
c  Get the prefix
c
        read(prefix,2998) detnam
 2998   format(a1)
        if((detnam .eq. '1') .or. (detnam .eq. '2')) then
            read(prefix,2999) idet
 2999       format(i1)
            if(idet .eq. 1) then
                sp_file = '/mos1-flare.fits.gz'
            else
                sp_file = '/mos2-flare.fits.gz'
            endif
        else
            idet = 3
            sp_file = '/pn-flare.fits.gz  '
            detnam = 'p'
        endif
c
        ccd(1) = ccd1
        ccd(2) = ccd2
        ccd(3) = ccd3
        ccd(4) = ccd4
        ccd(5) = ccd5
        ccd(6) = ccd6
        ccd(7) = ccd7
c
        print *, 'xmmdir: ', xmmdir
        print *, 'prefix: ', prefix
        if(idet .lt. 3) then
            print *, 'CCD selection', ccd(1), ccd(2), ccd(3), ccd(4),
     +              ccd(5), ccd(6), ccd(7)
        else
            print *, 'Quad selection', ccd(1), ccd(2), ccd(3), ccd(4)
        endif
        print *, 'elow, ehigh: ', elow, ehigh
        print *, 'idet: ', idet
        print *, 'ispec: ', ispec
        if(ispec .eq. 1) then
            print *, 'Photon Index and Norm: ', pindex, pnorm
        elseif(ispec .eq. 2) then
            print *, 'Low E Index, Break Energy, High E Index, Norm: '
            print *, bindl, break, bindh, bnorm
        endif
c
c  Set the bands to be included
c
        il = 1
        do while ((elow .gt. elim(il)) .and. (il .le. 7))
            il = il + 1
        enddo
        if(il .eq. 8) then
            print *, 'Low energy bound out of range'
            stop
        endif
        ih = il
        do while ((ehigh .gt. elim(ih)) .and. (ih .lt. 7))
            ih = ih + 1
        enddo
c
        if(il .eq. ih) then
            ibb(1) = il - 1
            if(ibb(1) .eq. 0) ibb(1) = 1
            fb(1) = 1.0
            n = 1
        else
            if(il .lt. 2) il = 2
            do ib=il,ih
                ibb(ib-il+1) = ib - 1
                if(ib .eq. il) then
                    fb(ib-il+1) = (elim(ib) - elow)/
     +                      (elim(ib) - elim(ib-1))
                    if(fb(ib-il+1) .gt. 1.0) fb(ib-il+1) = 1.0
                elseif(ib .eq. ih) then
                    fb(ib-il+1) = (ehigh - elim(ib-1))/
     +                      (elim(ib) - elim(ib-1))
                    if(fb(ib-il+1) .gt. 1.0) fb(ib-il+1) = 1.0
                else
                    fb(ib-il+1) = 1.0
                endif
            enddo
            n = ih - il + 1
        endif
c
        print *, 'Bands and scale factors for the SP maps'
        do i=1,n
            print *, ibb(i), fb(i)
        enddo
c
c  Create the SP map template
c
        ii = 1
        do while (xmmd(ii) .ne. ' ')
            db_fi(ii) = xmmd(ii)
            ii = ii + 1
        enddo
        do iii=0,18
            db_fi(ii+iii) = sp_fi(iii+1)
        enddo
        do iii=ii+19,80
            db_fi(iii) = ' '
        enddo
        print *, db_file
c
c  Get an unsed LUN
c
        call ftgiou(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 01'
            print *, 'Status FTGIOU =', status
        endif
c
c  Open the FITS file for the SP image
c
        call ftopen (lun,db_file,0,block,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 02'
            print *, 'Status FTOPEN =', status
            print *, db_file
        endif
c
c  Loop through the selected SP bands
c
        do j=1,n
c
c  Co-add the data from all filters
c
            do jj=0,2
                iext = ibb(j) + 2 + jj*7
                print *, ibb(j), iext
c
c  Move to the correct extension
c
                call ftmahd (lun,iext,hdutype,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'PROTON Position 03'
                    print *, 'Status FTGHPR =', status
                    print *, db_file
                    stop
                endif
c
c  Read the extension header information
c
                call ftghpr (lun,10,simple,bitpix,naxis,naxes,
     +              pcount,gcount,extend,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'PROTON Position 04'
                    print *, 'Status FTGHPR =', status
                    print *, db_file
                    stop
                endif
c
c  Read and print out the extension name
c
                call ftgkys (lun,'EXTNAME',extname,com,status)
                if(status .ne. 0) then
                    print *, 'PROTON POSITION 05'
                    print *, 'Missing EXTNAME keyword'
                    print *, 'Status FTGKYS =', status
                    print *, db_file
                    stop
                endif
                print *, extname
c
c  Return the SP image
c
                call ftg2de (lun,0,0,naxes(1),naxes(1),naxes(2),
     +              inarr,anyf,status)
                if((status .ne. 0) .and. (err .eq. 0)) then
                    err = 1
                    print *, 'PROTON Position 06'
                    print *, 'Status FTG2DE =', status
                    print *, db_file
                endif
c
c  Add data to the array
c
                do k=1,780
                    do kk=1,780
                        spmap(k,kk) = spmap(k,kk) + fb(j)*inarr(k,kk)
                    enddo
                enddo
            enddo
        enddo
c
c  Close the file
c
        call ftclos(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 05'
            print *, 'Status FTCLOS =', status
            print *, db_file
        endif
c
c  Mask chips if necessary
c
        if(ccd(1) .eq. 0) then
            if(idet .eq. 1) then
                i1 = 259
                i2 = 522
                ii1 = 259
                ii2 = 522
            elseif(idet .eq. 2) then
                i1 = 259
                i2 = 522
                ii1 = 259
                ii2 = 522
            else
                i1 = 23
                i2 = 346
                ii1 = 368
                ii2 = 684
            endif
            do i=i1,i2
                do ii=ii1,ii2
                    spmap(i,ii) = 0.0
                enddo
            enddo
        endif
        if(ccd(2) .eq. 0) then
            if(idet .eq. 1) then
                i1 = 392
                i2 = 652
                ii1 = 1
                ii2 = 251
            elseif(idet .eq. 2) then
                i1 = 392
                i2 = 652
                ii1 = 1
                ii2 = 251
            else
                i1 = 346
                i2 = 669
                ii1 = 368
                ii2 = 684
            endif
            do i=i1,i2
                do ii=ii1,ii2
                    spmap(i,ii) = 0.0
                enddo
            enddo
        endif
        if(ccd(3) .eq. 0) then
            if(idet .eq. 1) then
                i1 = 524
                i2 = 780
                ii1 = 253
                ii2 = 516
            elseif(idet .eq. 2) then
                i1 = 524
                i2 = 780
                ii1 = 253
                ii2 = 516
            else
                i1 = 346
                i2 = 670
                ii1 = 53
                ii2 = 368
            endif
            do i=i1,i2
                do ii=ii1,ii2
                    spmap(i,ii) = 0.0
                enddo
            enddo
        endif
        if(ccd(4) .eq. 0) then
            if(idet .eq. 1) then
                i1 = 394
                i2 = 654
                ii1 = 521
                ii2 = 780
            elseif(idet .eq. 2) then
                i1 = 394
                i2 = 654
                ii1 = 521
                ii2 = 780
            else
                i1 = 23
                i2 = 347
                ii1 = 54
                ii2 = 368
            endif
            do i=i1,i2
                do ii=ii1,ii2
                    spmap(i,ii) = 0.0
                enddo
            enddo
        endif
        if(idet .lt. 3) then
            if(ccd(5) .eq. 0) then
                if(idet .eq. 1) then
                    i1 = 130
                    i2 = 393
                    ii1 = 521
                    ii2 = 780
                else
                    i1 = 128
                    i2 = 390
                    ii1 = 523
                    ii2 = 780
                endif
                do i=i1,i2
                    do ii=ii1,ii2
                        spmap(i,ii) = 0.0
                    enddo
                enddo
            endif
            if(ccd(6) .eq. 0) then
                if(idet .eq. 1) then
                    i1 = 1
                    i2 = 258
                    ii1 = 257
                    ii2 = 520
                else
                    i1 = 1
                    i2 = 257
                    ii1 = 258
                    ii2 = 521
                endif
                do i=i1,i2
                    do ii=ii1,ii2
                        spmap(i,ii) = 0.0
                    enddo
                enddo
            endif
            if(ccd(7) .eq. 0) then
                if(idet .eq. 1) then
                    i1 = 129
                    i2 = 391
                    ii1 = 1
                    ii2 = 253
                else
                    i1 = 125
                    i2 = 388
                    ii1 = 1
                    ii2 = 254
                endif
                do i=i1,i2
                    do ii=ii1,ii2
                        spmap(i,ii) = 0.0
                    enddo
                enddo
            endif
        endif
c
c  Find the number of counts in the detector map
c
        rn = 0.0
        do i=1,780
            do ii=1,780
                rn = rn + spmap(i,ii)
            enddo
        enddo
c
c  Determine the number of SP counts in the band
c
        eh = ehigh/1000.0
        el = elow/1000.0
        if(ispec .eq. 1) then
            rind = 1.0 - pindex
            prot = pnorm*(eh**rind - el**rind)/rind
        elseif(ispec .eq. 2) then
            if(eh .le. break) then
                rind = 1.0 - bindl
                prot = bnorm*(eh**rind - el**rind)/rind
            elseif(el .ge. break) then
                rind = 1.0 - bindh
                prot = bnorm*(eh**rind - el**rind)/rind
            else
                rind = 1.0 - bindl
                temp = bnorm*(break**rind - el**rind)/rind
                rind = 1.0 - bindh
                prot = temp + bnorm*(eh**rind - break**rind)/rind
            endif
        else
            print *, 'Error in spectral type for SP background'
            print *, 'ispec: ', ispec
            stop
        endif
        print *, 'Soft Proton Event Rate: ', prot
c
c  Open up a template event image
c
c  First get an unused lun
c
        call ftgiou(luna,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 08'
            print *, 'STATUS FTGIOU =', status
        endif
c
c  Create the file name
c
        if(elow .ge. 1000) then
            if(ehigh .ge. 10000) then
                if(idet .lt. 3) then
                    write(objfile,3000) prefix, elow, ehigh
 3000               format('mos',a5,'-obj-im-det-',i4,'-',i5,'.fits')
                else
                    write(objfile,3002) prefi, elow, ehigh
 3002               format('pn',a4,'-obj-im-det-',i4,'-',i5,'.fits')
                endif
            else
                if(idet .lt. 3) then
                    write(objfile,3004) prefix, elow, ehigh
 3004               format('mos',a5,'-obj-im-det-',i4,'-',i4,'.fits')
                else
                    write(objfile,3006) prefi, elow, ehigh
 3006               format('pn',a4,'-obj-im-det-',i4,'-',i4,'.fits')
                endif
            endif
        elseif(ehigh .lt. 1000) then
            if(idet .lt. 3) then
                write(objfile,3010) prefix, elow, ehigh
 3010           format('mos',a5,'-obj-im-det-',i3,'-',i3,'.fits')
            else
                write(objfile,3012) prefi, elow, ehigh
 3012           format('pn',a4,'-obj-im-det-',i3,'-',i3,'.fits')
            endif
        else
            if(ehigh .ge. 10000) then
                if(idet .lt. 3) then
                    write(objfile,3020) prefix, elow, ehigh
 3020               format('mos',a5,'-obj-im-det-',i3,'-',i5,'.fits')
                else
                    write(objfile,3022) prefi, elow, ehigh
 3022               format('pn',a4,'-obj-im-det-',i3,'-',i5,'.fits')
                endif
            else
                if(idet .lt. 3) then
                    write(objfile,3024) prefix, elow, ehigh
 3024               format('mos',a5,'-obj-im-det-',i3,'-',i4,'.fits')
                else
                    write(objfile,3026) prefi, elow, ehigh
 3026               format('pn',a4,'-obj-im-det-',i3,'-',i4,'.fits')
                endif
            endif
        endif
        print *, 'Template image'
        print *, objfile
c
c  Open the FITS file
c
        call ftopen (luna,objfile,0,block,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 09'
            print *, 'STATUS FTOPEN =', status
            print *, objfile
        endif
c
c  Read the FITS file header information
c
        call ftghpr (luna,10,simplen,bitpixn,naxisn,naxesn,
     +      pcountn,gcountn,extendn,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 10'
            print *, 'Status FTGHPR =', status
            print *, objfile
        endif
c
c  Get the exposure keyword
c
        call ftgkyd (luna,'EXPOSURE',exposen,com,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 11a'
            print *, 'Status FTGKY =', status
            print *, objfile
        endif
c
c  Get the revolution
c
        call ftgkyj (luna,'REVOLUT',revl,com,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 11b'
            print *, 'Status FTGKY =', status
            print *, objfile
        endif
c
c  Check to see whether MOS1 CCD#6 is missing
c
        if((idet .eq. 1) .and. (revl .gt. 961)) then
            print *, 'Observation took place after MOS1 CCD6 ',
     +                  'was lost'
            if(ccd(6) .eq. 1) then
                print *, 'Set ccd(6) equal to 0'
                ccd(6) = 0
                print *, 'Revised CCD selection: ', ccd(1), ccd(2), 
     +                  ccd(3), ccd(4), ccd(5), ccd(6), ccd(7)
                i1 = 1
                i2 = 258
                ii1 = 257
                ii2 = 520
                do i=i1,i2
                    do ii=ii1,ii2
                        spmap(i,ii) = 0.0
                    enddo
                enddo
                rn = 0.0
                do i=1,780
                    do ii=1,780
                        rn = rn + spmap(i,ii)
                    enddo
                enddo
            endif
            if(revl .eq. 961) then
                print *, 'Observation took place during the ',
     +              'observation where MOS1 CCD6 was lost.  '
                print *, 'Exposure U002 has CCD6 data, U003 does not'
            endif
        endif

c
c  Set the scale factor
c
        prot = exposen*prot
        print *, 'Observation exposure: ', exposen
        print *, 'Detector map counts', rn
        print *, 'Proton flaring events: ', prot
        scale = prot/rn
        do i=1,780
            do ii=1,780
                spmap(i,ii) = scale*spmap(i,ii)
            enddo
        enddo
c
c  Write out the SP detector map
c
c  First get an unused lun
c
        call ftgiou(lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 12'
            print *, 'STATUS FTGIOU =', status
        endif
c
c  Create the file name
c
        if(elow .ge. 1000) then
            if(ehigh .ge. 10000) then
                if(idet .lt. 3) then
                    write(outfile,3100) prefix, elow, ehigh
 3100               format('mos',a5,'-prot-im-det-',i4,'-',i5,'.fits')
                else
                    write(outfile,3102) prefi, elow, ehigh
 3102               format('pn',a4,'-prot-im-det-',i4,'-',i5,'.fits')
                endif
            else
                if(idet .lt. 3) then
                    write(outfile,3104) prefix, elow, ehigh
 3104               format('mos',a5,'-prot-im-det-',i4,'-',i4,'.fits')
                else
                    write(outfile,3106) prefi, elow, ehigh
 3106               format('pn',a4,'-prot-im-det-',i4,'-',i4,'.fits')
                endif
            endif
        elseif(ehigh .lt. 1000) then
            if(idet .lt. 3) then
                write(outfile,3110) prefix, elow, ehigh
 3110           format('mos',a5,'-prot-im-det-',i3,'-',i3,'.fits')
            else
                write(outfile,3112) prefi, elow, ehigh
 3112           format('pn',a4,'-prot-im-det-',i3,'-',i3,'.fits')
            endif
        else
            if(ehigh .ge. 10000) then
                if(idet .lt. 3) then
                    write(outfile,3120) prefix, elow, ehigh
 3120               format('mos',a5,'-prot-im-det-',i3,'-',i5,'.fits')
                else
                    write(outfile,3122) prefi, elow, ehigh
 3122               format('pn',a4,'-prot-im-det-',i3,'-',i5,'.fits')
                endif
            else
                if(idet .lt. 3) then
                    write(outfile,3124) prefix, elow, ehigh
 3124               format('mos',a5,'-prot-im-det-',i3,'-',i4,'.fits')
                else
                    write(outfile,3126) prefi, elow, ehigh
 3126               format('pn',a4,'-prot-im-det-',i3,'-',i4,'.fits')
                endif
            endif
        endif
        print *, 'Output file name'
        print *, outfile
c
c  Check to see if there is an existing file
c
        call ftopen (lunb,outfile,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                call ftdelt(lunb,status)
            else
                print *, 'PROTON Position 13'
                print *, 'Will not clobber file'
                stop
            endif
        endif
        status = 0
c
c  Create the output FITS file using the original file as a template
c
        call ftinit (lunb,outfile,2880,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 14'
            print *, 'STATUS FTINIT =', status
            print *, outfile
        endif
c
c  Copy the header information from the old to the new file
c
        call ftcphd (luna,lunb,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 15'
            print *, 'STATUS FTCPHD =', status
        endif
c
        call ftpdef (lunb,bitpixn,naxisn,naxesn,pcountn,
     +              gcountn,.FALSE.,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 16'
            print *, 'STATUS FTPDEF =', status
        endif
        call ftmkyj(lunb,'BITPIX',bitpix,'Bitpix',status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'PROTON Position 17'
            print *, 'STATUS FTMKYJ =', status
        endif
        if(err .eq. 0) then
c
c  Write the output image
c
            group = 1
            call ftp2de (lunb,group,naxes(1),naxes(1),naxes(2),
     +                  spmap,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'PROTON Position 18'
                print *, 'STATUS FTP2DE =', status
                print *, 'Could not write the background image'
            endif
c
c  Close the output file
c
            call ftclos(lunb,status)
            if((status .ne. 0) .and. (err .eq. 0)) then
                err = 1
                print *, 'PROTON Position 19'
                print *, 'STATUS FTCLOS =', status
                print *, 'Could not close the output file'
            endif
        endif
c
        RETURN
        END SUBROUTINE proton_sub
