        subroutine ROT_DET_SKY_SUB(MODE,PREFIX,PREF,IEL,IEH,
     +      DXCEN,DYCEN,SKYX,SKYY,INFILE)
C
C  Version 3.0  20 August 2008
C
C  Rotates images in detector coordinates into sky coordinates
C
C  ROT_COMP rotates images in detector coordinates into sky
C  coordinates provided by a template image.  This is used
C  in the XMM-ESAS package to rotate the model particle
C  background images, which are created by the program
C  xmm-back-image in detector coordinates, into sky
C  coordinates.
C
C  INPUT:
C    Mode: 1 - QPB background map
C          2 - SP background map
C    Exposure identification prefix, e.g., 1S001
C    Lower energy limit for the energy band in eV
C    Upper energy limit for the energy band in eV
C    DETX central coord
C    DETY central coord
C    X reference pixel
C    Y reference pixel
C    Mask file name (missing or "none" defaults to no masking,
C        same size as the template)
C
C    Example: rot-back 1 1S001 350 1250 -1406.1 -1368.6
C              450.9 450.9 mask.fits
C
C    Template image file name (hardwired to 900x900 pixels)
C    Detector image file name (hardwired to 780x780 pixels)
C
C  OUPUT:
C    Tranformed image image (same size as the template)
C
        IMPLICIT NONE
C
        REAL alpha, beta, INPUT(780,780),
     +      ROTARR(900,900), MASK(900,900), MASKIT(900,900),
     +      RN, skyx, skyy, theta, x, y
        DOUBLE PRECISION CDELTN(2), CDELTO(2), 
     +      CRPIXN(2), CRPIXO(2), CROTN, CROTO, 
     +      CRVALN(2), CRVALO(2),
     +      DUM1(2), DUM2(2), DUM3(2),
     +      DXCEN, DYCEN, EXPOSEN, EXPOSEO
        INTEGER*2 INI2(780,780)
        INTEGER BITPIX, BITPIXN, BLOCK, CLOBBER, ERR, GCOUNT, GCOUNTN, 
     +      GROUPN, I, IDET, IEH, II, IEL, INI4(780,780), IOS, 
     +      ix, iy, LUN, MODE, N, NARGS, NAXES(10), NAXESN(10),
     +      NAXIS, NAXISN, PCOUNT, PCOUNTN, STATUS
        CHARACTER*1  IDE, PRE(4), PREF(5)
        CHARACTER*4  CTYPN, CTYPO, PREFI
        CHARACTER*5  PREFIX
        CHARACTER*8  UNITS, CTYPEN(2), CTYPEO(2), DUM(2)
        CHARACTER*60 COM
        CHARACTER*132 INBCK, INFILE, MASKST, OBJFIL, OUTBCK
        LOGICAL ANYF, EXTEND, EXTENDN, NOMASK, SIMPLE, SIMPLEN
C
C FIX ME!!
C        EQUIVALENCE (PREFIX,PREF), (PREFI,PRE)
        EQUIVALENCE(PREFI,PRE)
C
        DATA CLOBBER /1/
        DATA ERR /0/
        DATA STATUS /0/
C
C		call message(3,1,'RRRRRRR')
C		call readColumns("P0212480201M2S002MIEVLI0000.FIT", pha_col, pi_col)
C		phamin = int32Attribute(pha_col,"TDMIN")

C		call warning('XXXXXXXXX','YYYY')
        N = 0
        RN = 0
C
        DO I=1,900
            DO II=1,900
                ROTARR(I,II) = 0
            ENDDO
        ENDDO
C
C  Get the number of arguments from the command line
C
!		FIX ME! For compiling purposes
!        NARGS = IARGC()
        NARGS = 8
        PRINT *, 'Number of command line arguments: ', NARGS
        IF ((NARGS .NE. 8) .AND. (NARGS .NE. 9)) THEN
            PRINT *, 'Usage:'
            PRINT *, '  mode'
            PRINT *, '  exposure ID prefix'
            PRINT *, '  lower energy band limit in eV'
            PRINT *, '  upper energy band limit in eV'
            PRINT *, '  detx central coord'
            PRINT *, '  dety central coord'
            PRINT *, '  sky x reference pixel'
            PRINT *, '  sky y reference pixel'
            PRINT *, '  additional mask file name, nonexistent file'
            PRINT *, '      or missing parameter yield no masking'
            PRINT *, ' '
            PRINT *, 'Example: '
            PRINT *, 'rot-det-sky 1 1S001 350 1250 -1406.1 -1368.6 ',
     +             '450.9 450.9 mask.fits'
            STOP
        ENDIF
C
C Determin program parameters
C
        READ(PREFIX,'(A1)') IDE
        IF(PREF(1) .EQ. '1') THEN
            IDET = 1
        ELSEIF(PREF(1) .EQ. '2') THEN
            IDET = 2
        ELSE
            DO I=1,4
                PRE(I) = PREF(I)
            ENDDO
            IDET = 3
        ENDIF
        if(skyx .lt. 100.0) skyx = 100.0*skyx
        if(skyy .lt. 100.0) skyy = 100.0*skyy
c
        IF(INFILE .EQ. 'none') INFILE = '     '
C
        IF(MODE .EQ. 1) THEN
            IF(IDET .LE. 2) THEN
                IF(IEL .GE. 1000) THEN
                    IF(IEH .GE. 10000) THEN
                        WRITE(OBJFIL,3001) PREFIX, IEL, IEH
 3001                   FORMAT('mos',A5,'-obj-im-',I4,'-',I5,'.fits')
                        WRITE(INBCK,3002) PREFIX, IEL, IEH
 3002                   FORMAT('mos',A5,'-back-im-det-',I4,'-',
     +                          I5,'.fits')
                        WRITE(OUTBCK,3003) PREFIX, IEL, IEH
 3003                   FORMAT('mos',A5,'-back-im-sky-',I4,'-',
     +                          I5,'.fits')
                    ELSE
                        WRITE(OBJFIL,3004) PREFIX, IEL, IEH
 3004                   FORMAT('mos',A5,'-obj-im-',I4,'-',I4,'.fits')
                        WRITE(INBCK,3005) PREFIX, IEL, IEH
 3005                   FORMAT('mos',A5,'-back-im-det-',I4,'-',
     +                          I4,'.fits')
                        WRITE(OUTBCK,3006) PREFIX, IEL, IEH
 3006                   FORMAT('mos',A5,'-back-im-sky-',I4,'-',
     +                          I4,'.fits')
                    ENDIF
                ELSEIF(IEH .LT. 1000) THEN
                    WRITE(OBJFIL,3007) PREFIX, IEL, IEH
 3007               FORMAT('mos',A5,'-obj-im-',I3,'-',I3,'.fits')
                    WRITE(INBCK,3008) PREFIX, IEL, IEH
 3008               FORMAT('mos',A5,'-back-im-det-',I3,'-',I3,'.fits')
                    WRITE(OUTBCK,3009) PREFIX, IEL, IEH
 3009               FORMAT('mos',A5,'-back-im-sky-',I3,'-',I3,'.fits')
                ELSEIF(IEH .GE. 10000) THEN
                    WRITE(OBJFIL,3010) PREFIX, IEL, IEH
 3010               FORMAT('mos',A5,'-obj-im-',I3,'-',I5,'.fits')
                    WRITE(INBCK,3011) PREFIX, IEL, IEH
 3011               FORMAT('mos',A5,'-back-im-det-',I3,'-',I5,'.fits')
                    WRITE(OUTBCK,3012) PREFIX, IEL, IEH
 3012               FORMAT('mos',A5,'-back-im-sky-',I3,'-',I5,'.fits')
                ELSE
                    WRITE(OBJFIL,3013) PREFIX, IEL, IEH
 3013               FORMAT('mos',A5,'-obj-im-',I3,'-',I4,'.fits')
                    WRITE(INBCK,3014) PREFIX, IEL, IEH
 3014               FORMAT('mos',A5,'-back-im-det-',I3,'-',I4,'.fits')
                    WRITE(OUTBCK,3015) PREFIX, IEL, IEH
 3015               FORMAT('mos',A5,'-back-im-sky-',I3,'-',I4,'.fits')
                ENDIF
            ELSE
                IF(IEL .GE. 1000) THEN
                    IF(IEH .GE. 10000) THEN
                        WRITE(OBJFIL,3016) PREFIX, IEL, IEH
 3016                   FORMAT('pn',A4,'-obj-im-',I4,'-',I5,'.fits')
                        WRITE(INBCK,3017) PREFIX, IEL, IEH
 3017                   FORMAT('pn',A4,'-back-im-det-',I4,'-',
     +                          I5,'.fits')
                        WRITE(OUTBCK,3018) PREFIX, IEL, IEH
 3018                   FORMAT('pn',A4,'-back-im-sky-',I4,'-',
     +                          I5,'.fits')
                    ELSE
                        WRITE(OBJFIL,3019) PREFIX, IEL, IEH
 3019                   FORMAT('pn',A4,'-obj-im-',I4,'-',I4,'.fits')
                        WRITE(INBCK,3020) PREFIX, IEL, IEH
 3020                   FORMAT('pn',A4,'-back-im-det-',I4,'-',
     +                          I4,'.fits')
                        WRITE(OUTBCK,3021) PREFIX, IEL, IEH
 3021                   FORMAT('pn',A4,'-back-im-sky-',I4,'-',
     +                          I4,'.fits')
                    ENDIF
                ELSEIF(IEH .LT. 1000) THEN
                    WRITE(OBJFIL,3022) PREFIX, IEL, IEH
 3022               FORMAT('pn',A4,'-obj-im-',I3,'-',I3,'.fits')
                    WRITE(INBCK,3023) PREFIX, IEL, IEH
 3023               FORMAT('pn',A4,'-back-im-det-',I3,'-',I3,'.fits')
                    WRITE(OUTBCK,3024) PREFIX, IEL, IEH
 3024               FORMAT('pn',A4,'-back-im-sky-',I3,'-',I3,'.fits')
                ELSEIF(IEH .GE. 10000) THEN
                    WRITE(OBJFIL,3025) PREFIX, IEL, IEH
 3025               FORMAT('pn',A4,'-obj-im-',I3,'-',I5,'.fits')
                    WRITE(INBCK,3026) PREFIX, IEL, IEH
 3026               FORMAT('pn',A4,'-back-im-det-',I3,'-',I5,'.fits')
                    WRITE(OUTBCK,3027) PREFIX, IEL, IEH
 3027               FORMAT('pn',A4,'-back-im-sky-',I3,'-',I5,'.fits')
                ELSE
                    WRITE(OBJFIL,3028) PREFIX, IEL, IEH
 3028               FORMAT('pn',A4,'-obj-im-',I3,'-',I4,'.fits')
                    WRITE(INBCK,3029) PREFIX, IEL, IEH
 3029               FORMAT('pn',A4,'-back-im-det-',I3,'-',I4,'.fits')
                    WRITE(OUTBCK,3030) PREFIX, IEL, IEH
 3030               FORMAT('pn',A4,'-back-im-sky-',I3,'-',I4,'.fits')
                ENDIF
            ENDIF
        ELSEIF(MODE .EQ. 2) THEN
            IF(IDET .LE. 2) THEN
                IF(IEL .GE. 1000) THEN
                    IF(IEH .GE. 10000) THEN
                        WRITE(OBJFIL,3101) PREFIX, IEL, IEH
 3101                   FORMAT('mos',A5,'-obj-im-',I4,'-',I5,'.fits')
                        WRITE(INBCK,3102) PREFIX, IEL, IEH
 3102                   FORMAT('mos',A5,'-prot-im-det-',I4,'-',
     +                          I5,'.fits')
                        WRITE(OUTBCK,3103) PREFIX, IEL, IEH
 3103                   FORMAT('mos',A5,'-prot-im-sky-',I4,'-',
     +                          I5,'.fits')
                    ELSE
                        WRITE(OBJFIL,3104) PREFIX, IEL, IEH
 3104                   FORMAT('mos',A5,'-obj-im-',I4,'-',I4,'.fits')
                        WRITE(INBCK,3105) PREFIX, IEL, IEH
 3105                   FORMAT('mos',A5,'-prot-im-det-',I4,'-',
     +                          I4,'.fits')
                        WRITE(OUTBCK,3106) PREFIX, IEL, IEH
 3106                   FORMAT('mos',A5,'-prot-im-sky-',I4,'-',
     +                          I4,'.fits')
                    ENDIF
                ELSEIF(IEH .LT. 1000) THEN
                    WRITE(OBJFIL,3107) PREFIX, IEL, IEH
 3107               FORMAT('mos',A5,'-obj-im-',I3,'-',I3,'.fits')
                    WRITE(INBCK,3108) PREFIX, IEL, IEH
 3108               FORMAT('mos',A5,'-prot-im-det-',I3,'-',I3,'.fits')
                    WRITE(OUTBCK,3109) PREFIX, IEL, IEH
 3109               FORMAT('mos',A5,'-prot-im-sky-',I3,'-',I3,'.fits')
                ELSEIF(IEH .GE. 10000) THEN
                    WRITE(OBJFIL,3110) PREFIX, IEL, IEH
 3110               FORMAT('mos',A5,'-obj-im-',I3,'-',I5,'.fits')
                    WRITE(INBCK,3111) PREFIX, IEL, IEH
 3111               FORMAT('mos',A5,'-prot-im-det-',I3,'-',I5,'.fits')
                    WRITE(OUTBCK,3112) PREFIX, IEL, IEH
 3112               FORMAT('mos',A5,'-prot-im-sky-',I3,'-',I5,'.fits')
                ELSE
                    WRITE(OBJFIL,3113) PREFIX, IEL, IEH
 3113               FORMAT('mos',A5,'-obj-im-',I3,'-',I4,'.fits')
                    WRITE(INBCK,3114) PREFIX, IEL, IEH
 3114               FORMAT('mos',A5,'-prot-im-det-',I3,'-',I4,'.fits')
                    WRITE(OUTBCK,3115) PREFIX, IEL, IEH
 3115               FORMAT('mos',A5,'-prot-im-sky-',I3,'-',I4,'.fits')
                ENDIF
            ELSE
                IF(IEL .GE. 1000) THEN
                    IF(IEH .GE. 10000) THEN
                        WRITE(OBJFIL,3121) PREFIX, IEL, IEH
 3121                   FORMAT('pn',A4,'-obj-im-',I4,'-',I5,'.fits')
                        WRITE(INBCK,3122) PREFIX, IEL, IEH
 3122                   FORMAT('pn',A4,'-prot-im-det-',I4,'-',
     +                          I5,'.fits')
                        WRITE(OUTBCK,3123) PREFIX, IEL, IEH
 3123                   FORMAT('pn',A4,'-prot-im-sky-',I4,'-',
     +                          I5,'.fits')
                    ELSE
                        WRITE(OBJFIL,3124) PREFIX, IEL, IEH
 3124                   FORMAT('pn',A4,'-obj-im-',I4,'-',I4,'.fits')
                        WRITE(INBCK,3125) PREFIX, IEL, IEH
 3125                   FORMAT('pn',A4,'-prot-im-det-',I4,'-',
     +                          I4,'.fits')
                        WRITE(OUTBCK,3126) PREFIX, IEL, IEH
 3126                   FORMAT('pn',A4,'-prot-im-sky-',I4,'-',
     +                          I4,'.fits')
                    ENDIF
                ELSEIF(IEH .LT. 1000) THEN
                    WRITE(OBJFIL,3127) PREFIX, IEL, IEH
 3127               FORMAT('pn',A4,'-obj-im-',I3,'-',I3,'.fits')
                    WRITE(INBCK,3128) PREFIX, IEL, IEH
 3128               FORMAT('pn',A4,'-prot-im-det-',I3,'-',I3,'.fits')
                    WRITE(OUTBCK,3129) PREFIX, IEL, IEH
 3129               FORMAT('pn',A4,'-prot-im-sky-',I3,'-',I3,'.fits')
                ELSEIF(IEH .GE. 10000) THEN
                    WRITE(OBJFIL,3130) PREFIX, IEL, IEH
 3130               FORMAT('pn',A4,'-obj-im-',I3,'-',I5,'.fits')
                    WRITE(INBCK,3131) PREFIX, IEL, IEH
 3131               FORMAT('pn',A4,'-prot-im-det-',I3,'-',I5,'.fits')
                    WRITE(OUTBCK,3132) PREFIX, IEL, IEH
 3132               FORMAT('pn',A4,'-prot-im-sky-',I3,'-',I5,'.fits')
                ELSE
                    WRITE(OBJFIL,3133) PREFIX, IEL, IEH
 3133               FORMAT('pn',A4,'-obj-im-',I3,'-',I4,'.fits')
                    WRITE(INBCK,3134) PREFIX, IEL, IEH
 3134               FORMAT('pn',A4,'-prot-im-det-',I3,'-',I4,'.fits')
                    WRITE(OUTBCK,3135) PREFIX, IEL, IEH
 3135               FORMAT('pn',A4,'-prot-im-sky-',I3,'-',I4,'.fits')
                ENDIF
            ENDIF
        ELSEIF(MODE .EQ. 3) THEN
            IF(IDET .LE. 2) THEN
                IF(IEL .GE. 1000) THEN
                    IF(IEH .GE. 10000) THEN
                        WRITE(OBJFIL,3136) PREFIX, IEL, IEH
 3136                   FORMAT('mos',A5,'-obj-im-',I4,'-',I5,'.fits')
                        WRITE(INBCK,3137) PREFIX, IEL, IEH
 3137                   FORMAT('mos',A5,'-swcx-im-det-',I4,'-',
     +                          I5,'.fits')
                        WRITE(OUTBCK,3138) PREFIX, IEL, IEH
 3138                   FORMAT('mos',A5,'-swcx-im-sky-',I4,'-',
     +                          I5,'.fits')
                    ELSE
                        WRITE(OBJFIL,3139) PREFIX, IEL, IEH
 3139                   FORMAT('mos',A5,'-obj-im-',I4,'-',I4,'.fits')
                        WRITE(INBCK,3140) PREFIX, IEL, IEH
 3140                   FORMAT('mos',A5,'-swcx-im-det-',I4,'-',
     +                          I4,'.fits')
                        WRITE(OUTBCK,3141) PREFIX, IEL, IEH
 3141                   FORMAT('mos',A5,'-swcx-im-sky-',I4,'-',
     +                          I4,'.fits')
                    ENDIF
                ELSEIF(IEH .LT. 1000) THEN
                    WRITE(OBJFIL,3142) PREFIX, IEL, IEH
 3142               FORMAT('mos',A5,'-obj-im-',I3,'-',I3,'.fits')
                    WRITE(INBCK,3143) PREFIX, IEL, IEH
 3143               FORMAT('mos',A5,'-swcx-im-det-',I3,'-',I3,'.fits')
                    WRITE(OUTBCK,3144) PREFIX, IEL, IEH
 3144               FORMAT('mos',A5,'-swcx-im-sky-',I3,'-',I3,'.fits')
                ELSEIF(IEH .GE. 10000) THEN
                    WRITE(OBJFIL,3145) PREFIX, IEL, IEH
 3145               FORMAT('mos',A5,'-obj-im-',I3,'-',I5,'.fits')
                    WRITE(INBCK,3146) PREFIX, IEL, IEH
 3146               FORMAT('mos',A5,'-swcx-im-det-',I3,'-',I5,'.fits')
                    WRITE(OUTBCK,3147) PREFIX, IEL, IEH
 3147               FORMAT('mos',A5,'-swcx-im-sky-',I3,'-',I5,'.fits')
                ELSE
                    WRITE(OBJFIL,3148) PREFIX, IEL, IEH
 3148               FORMAT('mos',A5,'-obj-im-',I3,'-',I4,'.fits')
                    WRITE(INBCK,3149) PREFIX, IEL, IEH
 3149               FORMAT('mos',A5,'-swcx-im-det-',I3,'-',I4,'.fits')
                    WRITE(OUTBCK,3150) PREFIX, IEL, IEH
 3150               FORMAT('mos',A5,'-swcx-im-sky-',I3,'-',I4,'.fits')
                ENDIF
            ELSE
                IF(IEL .GE. 1000) THEN
                    IF(IEH .GE. 10000) THEN
                        WRITE(OBJFIL,3151) PREFIX, IEL, IEH
 3151                   FORMAT('pn',A4,'-obj-im-',I4,'-',I5,'.fits')
                        WRITE(INBCK,3152) PREFIX, IEL, IEH
 3152                   FORMAT('pn',A4,'-swcx-im-det-',I4,'-',
     +                          I5,'.fits')
                        WRITE(OUTBCK,3153) PREFIX, IEL, IEH
 3153                   FORMAT('pn',A4,'-swcx-im-sky-',I4,'-',
     +                          I5,'.fits')
                    ELSE
                        WRITE(OBJFIL,3154) PREFIX, IEL, IEH
 3154                   FORMAT('pn',A4,'-obj-im-',I4,'-',I4,'.fits')
                        WRITE(INBCK,3155) PREFIX, IEL, IEH
 3155                   FORMAT('pn',A4,'-swcx-im-det-',I4,'-',
     +                          I4,'.fits')
                        WRITE(OUTBCK,3156) PREFIX, IEL, IEH
 3156                   FORMAT('pn',A4,'-swcx-im-sky-',I4,'-',
     +                          I4,'.fits')
                    ENDIF
                ELSEIF(IEH .LT. 1000) THEN
                    WRITE(OBJFIL,3157) PREFIX, IEL, IEH
 3157               FORMAT('pn',A4,'-obj-im-',I3,'-',I3,'.fits')
                    WRITE(INBCK,3158) PREFIX, IEL, IEH
 3158               FORMAT('pn',A4,'-swcx-im-det-',I3,'-',I3,'.fits')
                    WRITE(OUTBCK,3159) PREFIX, IEL, IEH
 3159               FORMAT('pn',A4,'-swcx-im-sky-',I3,'-',I3,'.fits')
                ELSEIF(IEH .GE. 10000) THEN
                    WRITE(OBJFIL,3160) PREFIX, IEL, IEH
 3160               FORMAT('pn',A4,'-obj-im-',I3,'-',I5,'.fits')
                    WRITE(INBCK,3161) PREFIX, IEL, IEH
 3161               FORMAT('pn',A4,'-swcx-im-det-',I3,'-',I5,'.fits')
                    WRITE(OUTBCK,3162) PREFIX, IEL, IEH
 3162               FORMAT('pn',A4,'-swcx-im-sky-',I3,'-',I5,'.fits')
                ELSE
                    WRITE(OBJFIL,3163) PREFIX, IEL, IEH
 3163               FORMAT('pn',A4,'-obj-im-',I3,'-',I4,'.fits')
                    WRITE(INBCK,3164) PREFIX, IEL, IEH
 3164               FORMAT('pn',A4,'-swcx-im-det-',I3,'-',I4,'.fits')
                    WRITE(OUTBCK,3165) PREFIX, IEL, IEH
 3165               FORMAT('pn',A4,'-swcx-im-sky-',I3,'-',I4,'.fits')
                ENDIF
            ENDIF
        ELSE
            PRINT *, 'Bad value for mode in ROT-DET-SKY'
            STOP
        ENDIF
C
C  Read in the standard mask to go with the observation
C
        IF(IDET .LE. 2) THEN
            WRITE(MASKST,3600) PREFIX
 3600       FORMAT('mos',A5,'-mask-im.fits')
        ELSE
            WRITE(MASKST,3601) PREFI
 3601       FORMAT('pn',A4,'-mask-im.fits')
        ENDIF
        OPEN(90,FILE=MASKST,IOSTAT=IOS,STATUS='OLD')
        CLOSE(90)
        IF(IOS .EQ. 0) THEN
C
C  Return the array
C
            CALL RETFIT (MASKST,MASKIT,INI2,INI4,1,900,
     +              900,DUM,DUM1,DUM2,DUM3,STATUS)
        ELSE
            PRINT *, 'Standard mask is missing'
            PRINT *, MASKST
            STOP
        ENDIF
C
C  Open the FITS file for the template
C
        CALL FTOPEN(90,OBJFIL,0,BLOCK,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTOPEN =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 01'
            PRINT *, OBJFIL
            STOP
        ENDIF
C
C  Read the FITS file header information
C
        CALL FTGHPR (90,10,SIMPLEN,BITPIXN,NAXISN,NAXESN,
     +              PCOUNTN,GCOUNTN,EXTENDN,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 02'
            PRINT *, OBJFIL
        ENDIF
C
C  Get the useful keywords
C
        CALL FTGICS (90,CRVALN(1),CRVALN(2),CRPIXN(1),CRPIXN(2),
     +          CDELTN(1),CDELTN(2),CROTN,CTYPN,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGICS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 03'
            PRINT *, OBJFIL
        ENDIF
C
C  And a few more
C
        CALL FTGKYS (90,'CTYPE1',CTYPEN(1),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 04'
            PRINT *, OBJFIL
        ENDIF
        CALL FTGKYS (90,'CTYPE2',CTYPEN(2),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 05'
            PRINT *, OBJFIL
        ENDIF
        CALL FTGKYD (90,'PA_PNT',CROTN,COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 06'
            PRINT *, OBJFIL
        ENDIF
        CALL FTGKYD (90,'EXPOSURE',EXPOSEN,COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 07'
            PRINT *, OBJFIL
        ENDIF
C
C  Close the file
C
        CALL FTCLOS(90,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 08'
            PRINT *, OBJFIL
        ENDIF
C
C  Print the details of the template image
C
        PRINT *, 'Template File'
        PRINT *, OBJFIL
        PRINT *, 'Template image coordinate system: ', CTYPN
        PRINT *, 'Template image coordinate ID: ',
     +          CTYPEN(1), '  ', CTYPEN(2)
        PRINT *, 'Template image central coordinates: ',
     +          CRVALN(1), CRVALN(2)
        PRINT *, 'Template image reference pixel: ',
     +          CRPIXN(1), CRPIXN(2)
        PRINT *, 'Template image pixel sizes: ',
     +          CDELTN(1), CDELTN(2)
        PRINT *, 'Template image rotation angle: ', CROTN
        PRINT *, 'Template image NAXES, NAXIS: ', NAXISN,
     +          (NAXESN(I),I=1,NAXISN)
        IF(IDET .EQ. 2) THEN
            CROTN = CROTN + 90.0
        ELSEIF(IDET .EQ. 3) THEN
            CROTN = CROTN - 90.0
        ENDIF
C
C  Enter the file to be cast
C
        PRINT *, 'Recast Image = ', INBCK
C
C  Open the FITS file for the detector coord background image
C
        CALL FTOPEN(90,INBCK,0,BLOCK,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTOPEN =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 09'
            PRINT *, INBCK
            STOP
        ENDIF
C
C  Read the FITS file header information
C
        CALL FTGHPR (90,10,SIMPLE,BITPIX,NAXIS,NAXES,
     +              PCOUNT,GCOUNT,EXTEND,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 10'
            PRINT *, INBCK
        ENDIF
C
C  Get the useful keywords
C
        CALL FTGICS (90,CRVALO(1),CRVALO(2),CRPIXO(1),CRPIXO(2),
     +          CDELTO(1),CDELTO(2),CROTO,CTYPO,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGICS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 11'
            PRINT *, INBCK
        ENDIF
C
C  And a few more
C
        CALL FTGKYS (90,'CTYPE1',CTYPEO(1),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 12'
            PRINT *, INBCK
        ENDIF
        CALL FTGKYS (90,'CTYPE2',CTYPEO(2),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 13'
            PRINT *, INBCK
        ENDIF
        CALL FTGKYD (90,'RA_NOM',CRVALO(1),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 14'
            PRINT *, INBCK
        ENDIF
        CALL FTGKYD (90,'DEC_NOM',CRVALO(2),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 15'
            PRINT *, INBCK
        ENDIF
        CALL FTGKYD (90,'CRPIX1',CRPIXO(1),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 16'
            PRINT *, INBCK
        ENDIF
        CALL FTGKYD (90,'CRPIX2',CRPIXO(2),COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 17'
            PRINT *, INBCK
        ENDIF
        CALL FTGKYD (90,'EXPOSURE',EXPOSEO,COM,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGKYD =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 18'
            PRINT *, INBCK
        ENDIF
        CTYPEO(1) = CTYPEN(1)
        CTYPEO(2) = CTYPEN(2)
        CDELTO(1) = CDELTN(1)
        CDELTO(2) = CDELTN(2)
        CTYPO = CTYPN
c
        print *, DXCEN, DYCEN
        CRPIXO(1) = (-DXCEN + 19499.0)/50.0 - 0.5
        CRPIXO(2) = (DYCEN + 19499.0)/50.0 + 0.5
c        print *, CRPIXO(1), CRPIXO(2)
C
C  Print the central coords of the observation
C
        PRINT *, 'Original image coordinate system: ', CTYPO
        PRINT *, 'Original image coordinate ID: ',
     +          CTYPEO(1), '  ', CTYPEO(2)
        PRINT *, 'Original image central coordinates: ',
     +          CRVALO(1), CRVALO(2)
        PRINT *, 'Original image reference pixel: ',
     +          CRPIXO(1), CRPIXO(2)
        PRINT *, 'Original image pixel sizes: ',
     +          CDELTO(1), CDELTO(2)
        PRINT *, 'Original image rotation angle: ', CROTO
        PRINT *, 'Original image NAXES, NAXIS: ', NAXIS,
     +          (NAXES(I),I=1,NAXIS)
C
C  Read in the X-ray image
C
        CALL FTG2DE (90,0,0,NAXES(1),NAXES(1),NAXES(2),INPUT,
     +         ANYF,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTG2DE =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 19'
            PRINT *, INBCK
        ENDIF
C
C  Close the FITS file
C
        CALL FTCLOS(90,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 20'
            PRINT *, INBCK
        ENDIF
C
C  Read in the mask to go with the observation
C
        IF(INFILE .NE. '      ') THEN
            OPEN(90,FILE=INFILE,IOSTAT=IOS,STATUS='OLD')
            CLOSE(90)
            IF(IOS .EQ. 0) THEN
C
C  Return the array
C
                CALL RETFIT (INFILE,MASK,INI2,INI4,1,900,
     +                  900,DUM,DUM1,DUM2,DUM3,STATUS)
                IF(STATUS .EQ. 0) THEN
                    NOMASK = .FALSE.
                ELSE
                    NOMASK = .TRUE.
                    STATUS = 0
                ENDIF
            ELSE
                NOMASK = .TRUE.
            ENDIF
        ELSE
            NOMASK = .TRUE.
        ENDIF
C
C  Cast the new observation into the mosaic
C

        dxcen = (dxcen + 19499.0)/50.0 + 0.5
        dycen = (dycen + 19499.0)/50.0 + 0.5
        theta = -0.01745329*crotn
c        print *, dxcen, dycen

        alpha =  skyx + dxcen*cos(theta) - dycen*sin(theta)
        beta = skyy - dycen*cos(theta) - dxcen*sin(theta)
c        print *, alpha, beta

        x = alpha - dxcen*cos(theta) + dycen*sin(theta)
        y = beta + dycen*cos(theta) + dxcen*sin(theta)
c        print *, x, y

        do i=1,780
            do ii=1,780
                if(input(i,ii) .ne. 0) then
                    x = alpha - i*cos(theta) + ii*sin(theta)
                    y = beta + ii*cos(theta) + i*sin(theta)
                    ix = nint(x)
                    iy = nint(y)
                    if((ix .ge. 1) .and. (ix .le. 900) .and.
     +                      (iy .ge. 1) .and. (iy .le. 900)) then
                        rotarr(ix,iy) = rotarr(ix,iy) + input(i,ii)
                        n = n + 1
                        rn = rn + input(i,ii)
                    endif
                endif
            enddo
        enddo
        PRINT *, N, ' non-zero input pixels'
        PRINT *, RN, ' cast counts'
c
c  Do the standard masking
c
        n = 0
        rn = 0.0
        do i=1,900
            do ii=1,900
                if(maskit(i,ii) .eq. 0) then
                    rotarr(i,ii) = 0.0
                else
                    n = n + 1
                    rn = rn + rotarr(i,ii)
                endif
            enddo
        enddo
        PRINT *, 'Values after soft proton standard masking'
        PRINT *, N, ' non-zero input pixels'
        PRINT *, RN, ' cast counts'
c
c  Mask the image
c
        if(.not.nomask) then
            n = 0
            rn = 0.0
            do i=1,900
                do ii=1,900
                    if(mask(i,ii) .eq. 0) then
                        rotarr(i,ii) = 0.0
                    else
                        n = n + 1
                        rn = rn + rotarr(i,ii)
                    endif
                enddo
            enddo
            PRINT *, 'Values after additional masking'
            PRINT *, N, ' non-zero input pixels'
            PRINT *, RN, ' cast counts'
        endif
C
C  Create the output file name
C
        PRINT *, OUTBCK
c
c  Get an unused lun
c
        call ftgiou(lun,status)
        if((status .ne. 0) .and. (err .eq. 0)) then
            err = 1
            print *, 'STATUS FTGIOU =', status
            print *, 'ROT-DET-SKY POSITION 21'
        ENDIF
c
c  Check to see if there is an existing file
c
        call ftopen (lun,outbck,0,block,status)
        if(status .eq.  0) then
            print *, 'File exists with output file name'
            if(clobber .eq.  1) then
                print *, 'Clobber the file and continue'
                call ftdelt(lun,status)
            else
                print *, 'Will not clobber file'
                print *, 'ROT-DET-SKY POSITION 22'
                stop
            endif
        endif
        status = 0
C
C  Create the FITS file for the output image
C
        GROUPN = 1
        BITPIXN = -32
        CALL FTINIT(90,OUTBCK,2880,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTINIT =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 23'
            PRINT *, OUTBCK
        ENDIF
C
C  Set the output file header
C
        CALL FTPHPR(90,SIMPLEN,BITPIXN,NAXISN,NAXESN,PCOUNTN,GCOUNTN,
     +              EXTENDN,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTGHPR =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 24'
            PRINT *, OUTBCK
        ENDIF
C
C  Write some useful header keywords
C
        CALL FTPKYS(90,'CONTENT','IMAGE','  ',STATUS)
        CALL FTPKYS(90,'TELESCOP','XMM','mission name',STATUS)
        CALL FTPKYS(90,'INSTRUME','EPIC','instrument name',STATUS)
        CALL FTPKYS(90,'OBS_MODE','POINTING',
     +          'obs mode: POINTING,SLEW, OR SCAN',STATUS)
        CALL FTPKYS(90,'RADECSYS','FK5',
     +          'Equatorial system reference',STATUS)
        CALL FTPKYJ(90,'EQUINOX',2000,'Equinox',STATUS)
        CALL FTPKYD(90,'EXPOSURE',EXPOSEO,6,'Reference pixel',STATUS)
        CALL FTPKYF(90,'BZERO',0.0,8,' ',STATUS)
        CALL FTPKYF(90,'BSCALE',1.0,8,' ',STATUS)
        UNITS = 'counts'
        CALL FTPKYS(90,'BUNIT',UNITS,'Units of data',STATUS)
        CALL FTPKYD(90,'CRPIX1',CRPIXN(1),8,'Reference pixel',STATUS)
        CALL FTPKYS(90,'CTYPE1',CTYPEN(1),'Projection',STATUS)
        CALL FTPKYD(90,'CRVAL1',CRVALN(1),8,'Central longitude',STATUS)
        CALL FTPKYD(90,'CDELT1',CDELTN(1),8,'Pixel size',STATUS)
        CALL FTPKYS(90,'CUNIT1','deg','Units of coordinate',STATUS)
C
        CALL FTPKYD(90,'CRPIX2',CRPIXN(2),8,'Reference pixel',STATUS)
        CALL FTPKYS(90,'CTYPE2',CTYPEN(2),'Projection',STATUS)
        CALL FTPKYD(90,'CRVAL2',CRVALN(2),8,'Central latitude',STATUS)
        CALL FTPKYD(90,'CDELT2',CDELTN(2),8,'Pixel size',STATUS)
        CALL FTPKYS(90,'CUNIT2','deg','Units of coordinate',STATUS)
C
        CALL FTPCOM(90,
     +  'This file was produced using the XMM-ESAS software written by',
     +  STATUS)
        CALL FTPCOM(90,
     +  'S. L. Snowden, and written using the FITSIO package of ',
     +  STATUS)
        CALL FTPCOM(90,'W. D. Pence.',STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS various keyword writing =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 25'
            PRINT *, OUTBCK
        ENDIF
C
C  Print the details of the output image
C
        PRINT *, 'Output image coordinate system: ', CTYPN
        PRINT *, 'Output image coordinate ID: ',
     +          CTYPEN(1), '  ', CTYPEN(2)
        PRINT *, 'Output image central coordinates: ',
     +          CRVALN(1), CRVALN(2)
        PRINT *, 'Output image reference pixel: ',
     +          CRPIXN(1), CRPIXN(2)
        PRINT *, 'Output image pixel sizes: ',
     +          CDELTN(1), CDELTN(2)
        PRINT *, 'Output image rotation angle: ', CROTN
        PRINT *, 'Output image NAXES, NAXIS: ', NAXISN,
     +          (NAXESN(I),I=1,NAXISN)
C
C  Define the file format
C
        CALL FTPDEF(90,BITPIXN,NAXISN,NAXESN,PCOUNTN,GCOUNTN,
     +              EXTENDN,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTPDEF =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 26'
            PRINT *, OUTBCK
        ENDIF
C
C  Write the file
C
        CALL FTP2DE(90,GROUPN,NAXESN(1),NAXESN(1),NAXESN(2),
     +          ROTARR,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTP2DE =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 27'
            PRINT *, OUTBCK
        ENDIF
C
C  Close the file
C
        CALL FTCLOS(90,STATUS)
        IF((STATUS .NE. 0) .AND. (ERR .EQ. 0)) THEN
            ERR = 1
            PRINT *, 'STATUS FTCLOS =', STATUS
            PRINT *, 'ROT-DET-SKY POSITION 28'
            PRINT *, OUTBCK
        ENDIF
C
        RETURN
        END SUBROUTINE ROT_DET_SKY_SUB
