         SUBROUTINE SP_PARTIAL_SUB(xmmdir,xmmd,mosnum,fullimage,
     +        fullspec,regionimage,regionspec,rnorm)
c
c  Version 4.0: 23 June 2010
c
c  Returns the average SP flux and BACKSCAL keyword for a region
c
c  sp_partial uses the results from a spectral fit of a limited
c  region of the FOV to better determine the contribution of
c  SP contamination.  This is to avoid the effect of a bright
c  extended region skewing the SP component fit.  It uses the
c  SP templates from the limited region and the full region plus
c  the fitted SP normalization from the limited region to find
c  the SP normalization for the full FOV.
c
c  Input:
c    CalDB data directory
c    MOS number
c    full region image file name
c    full region spectrum file name
c    selected region image file name
c    selected region spectrum file name
c    selected region SP normalization
c
c    Example: sp-partial /path/qpb 1 full-image.fits full-spec.fits
c                   sel-image.fits sel-spec.fits norm
c
c Usage:
c   data directory
c   MOS number
c   full region image file name
c   full region spectrum file name
c   selected region image file name
c   selected region spectrum file name
c   selected region SP normalization
c 
c   Example: 
c     sp-partial /path/qpb 1 full-image.fits 
c                     full-spec.fits sel-image.fits 
c                     sel-spec.fits norm
c
        implicit none
c
        integer mosnum
c
        real backfull, backsel, cfull, csel, rnorm, rrnorm
c
        character*1 xmmd(80)
        character*60 fullimage, fullspec, regionimage, regionspec
        character*80 xmmdir
c
        print *, 'xmmdir: ', xmmdir
        print *, 'mosnum: ', mosnum
c
        call spscale(xmmdir,xmmd,mosnum,fullimage,
     +              fullspec,backfull,cfull)
c
        call spscale(xmmdir,xmmd,mosnum,regionimage,
     +              regionspec,backsel,csel)
c
c  Determine the old normalization
c
        rrnorm = rnorm*(backfull/backsel)*(cfull/csel)
        print *, rrnorm
c
        RETURN
        end subroutine SP_PARTIAL_SUB
